@@ -2,7 +2,7 @@
 /*!	\file adjust_window.cpp
 **	\brief Adjustment Window Implementation File
 **
-**	$Id: adjust_window.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: adjust_window.cpp 1500 2008-01-26 11:46:04Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -32,6 +32,8 @@
 #include "adjust_window.h"
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -84,7 +86,8 @@ void Adjust_Window::set_child_adjustment(Gtk::Adjustment *child)
 
 	adj_child = child;
 
-	synfig::info("Adjust: connecting to child signals");
+	// synfig::info("Adjust: connecting to child signals");
+
 	if(child)
 	{
 		childchanged = child->signal_changed().connect(sigc::mem_fun(*this,&Adjust_Window::update_fromchild));
