@@ -2,11 +2,11 @@
 /*!	\file app.h
 **	\brief writeme
 **
-**	$Id: app.h 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: app.h 1802 2008-02-23 01:25:55Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -28,7 +28,6 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <sigc++/compatibility.h>
 #include <sigc++/bind.h>
 
 #include <gtkmm/main.h>
@@ -44,10 +43,16 @@
 #include <gtkmm/uimanager.h>
 
 #include <synfigapp/instance.h>
-#include "iconcontroler.h"
+#include "iconcontroller.h"
 
 /* === M A C R O S ========================================================= */
 
+#define MISC_DIR_PREFERENCE			"misc_dir"
+#define ANIMATION_DIR_PREFERENCE	"animation_dir"
+#define IMAGE_DIR_PREFERENCE		"image_dir"
+#define SKETCH_DIR_PREFERENCE		"sketch_dir"
+#define RENDER_DIR_PREFERENCE		"render_dir"
+
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
@@ -71,6 +76,7 @@ namespace studio {
 
 typedef Gtk::UIManager UIManager;
 
+class About;
 class Toolbox;
 class Instance;
 class CanvasView;
@@ -99,9 +105,9 @@ class IPC;
 class Module;
 
 class StateManager;
-class IconControler;
+class IconController;
 
-class App : public Gtk::Main, private IconControler
+class App : public Gtk::Main, private IconController
 {
 	friend class Preferences;
 	friend class Dialog_Setup;
@@ -176,6 +182,7 @@ public:
 
 	static synfig::Gamma gamma;
 
+	static About *about;
 	static Toolbox *toolbox;
 
 	static std::list<etl::handle<Instance> > instance_list;
@@ -184,6 +191,14 @@ public:
 
 	static bool use_colorspace_gamma;
 
+#ifdef SINGLE_THREADED
+	static bool single_threaded;
+#endif
+
+	static bool restrict_radius_ducks;
+
+	static synfig::String browser_command;
+
 	/*
  -- ** -- S I G N A L S -------------------------------------------------------
 	*/
@@ -238,6 +253,7 @@ public:
 	*/
 
 private:
+	static void add_recent_file(const std::string &filename, const std::string &window_size = std::string());
 
 	/*
  -- ** -- P U B L I C   M E T H O D S -----------------------------------------
@@ -258,7 +274,8 @@ public:
 
 	static Glib::RefPtr<UIManager>& ui_manager() { return ui_manager_; }
 
-	static void add_recent_file(const std::string &filename);
+	static void set_recent_file_window_size(etl::handle<Instance> instance);
+	static void add_recent_file(const etl::handle<Instance> instance);
 
 	static synfig::String get_base_path();
 	static void save_settings();
@@ -284,7 +301,7 @@ public:
 
 	static void new_instance();
 
-	static void dialog_open();
+	static void dialog_open(std::string filename = "");
 
 	static void dialog_about();
 
@@ -306,8 +323,8 @@ public:
 
 //	static bool dialog_file(const std::string &title, std::string &filename);
 
-	static bool dialog_open_file(const std::string &title, std::string &filename);
-	static bool dialog_save_file(const std::string &title, std::string &filename);
+	static bool dialog_open_file(const std::string &title, std::string &filename, std::string preference);
+	static bool dialog_save_file(const std::string &title, std::string &filename, std::string preference);
 
 	static void dialog_error_blocking(const std::string &title, const std::string &message);
 
@@ -321,10 +338,16 @@ public:
 
 	static void dialog_not_implemented();
 
+	static void dialog_help();
+
+	static void open_url(const std::string &url);
+
 	static synfig::String get_user_app_directory();
 	static synfig::String get_config_file(const synfig::String& file);
 }; // END of class App
 
+	void delete_widget(Gtk::Widget *widget);
+
 }; // END namespace studio
 
 /* === E N D =============================================================== */
