@@ -2,10 +2,11 @@
 /*!	\file asyncrenderer.h
 **	\brief Template Header
 **
-**	$Id: asyncrenderer.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: asyncrenderer.h 1801 2008-02-23 01:25:23Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,6 +43,12 @@
 
 /* === M A C R O S ========================================================= */
 
+// uncomment to use a single thread, and hopefully get more stability
+// #define SINGLE_THREADED
+#ifdef SINGLE_THREADED
+#  define single_threaded()	App::single_threaded
+#endif
+
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
@@ -83,6 +90,10 @@ public:
 	void stop();
 	void pause();
 	void resume();
+#ifdef SINGLE_THREADED
+	void rendering_progress();
+	bool updating;
+#endif
 
 	bool has_error()const { return error; }
 	bool has_success()const { return success; }
