@@ -2,7 +2,7 @@
 /*!	\file audiocontainer.cpp
 **	\brief Audio Container implementation File
 **
-**	$Id: audiocontainer.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: audiocontainer.cpp 1205 2007-12-17 09:43:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -54,6 +54,8 @@
 #include <fmod.h>
 #endif
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -851,7 +853,7 @@ studio::AudioContainer::~AudioContainer()
 	if(imp) delete (imp);
 }
 
-bool studio::AudioContainer::load(const string &filename,const string &filedirectory)
+bool studio::AudioContainer::load(const std::string &filename,const std::string &filedirectory)
 {
 	if(!imp)
 	{
@@ -1187,9 +1189,9 @@ void studio::AudioContainer::AudioImp::clear()
 }
 
 #ifdef WITH_FMOD
-void AudioContainer::AudioImp::start_scrubbing(double t)
+void studio::AudioContainer::AudioImp::start_scrubbing(double t)
 #else
-void AudioContainer::AudioImp::start_scrubbing(double /*t*/)
+void studio::AudioContainer::AudioImp::start_scrubbing(double /*t*/)
 #endif
 {
 	//synfig::info("Start scrubbing: %lf", t);
@@ -1241,7 +1243,7 @@ void AudioContainer::AudioImp::start_scrubbing(double /*t*/)
 	#endif
 }
 
-void AudioContainer::AudioImp::stop_scrubbing()
+void studio::AudioContainer::AudioImp::stop_scrubbing()
 {
 	//synfig::info("Stop scrubbing");
 
@@ -1263,9 +1265,9 @@ void AudioContainer::AudioImp::stop_scrubbing()
 }
 
 #ifdef WITH_FMOD
-void AudioContainer::AudioImp::scrub(double t)
+void studio::AudioContainer::AudioImp::scrub(double t)
 #else
-void AudioContainer::AudioImp::scrub(double /*t*/)
+void studio::AudioContainer::AudioImp::scrub(double /*t*/)
 #endif
 {
 	#ifdef WITH_FMOD
@@ -1284,7 +1286,7 @@ void AudioContainer::AudioImp::scrub(double /*t*/)
 
 		curscrubpos = newpos;
 
-		//Ok the sound is running, now we need to tweek it
+		//Ok the sound is running, now we need to tweak it
 		if(newpos > oldpos)
 		{
 			//Outside so completely stopped...
