@@ -2,10 +2,11 @@
 /*!	\file autorecover.h
 **	\brief Template Header
 **
-**	$Id: autorecover.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: autorecover.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,7 +43,7 @@ namespace studio {
 class AutoRecover
 {
 	int timeout;
-	SigC::Connection auto_backup_connect;
+	sigc::connection auto_backup_connect;
 public:
 	AutoRecover();
 	~AutoRecover();
@@ -60,7 +61,7 @@ public:
 	static synfig::String get_shadow_directory();
 
 	bool recovery_needed()const;
-	bool recover();
+	bool recover(int& number_recovered);
 
 	void normal_shutdown();
 
