@@ -2,7 +2,7 @@
 /*!	\file canvasoptions.cpp
 **	\brief Template File
 **
-**	$Id: canvasoptions.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: canvasoptions.cpp 1757 2008-02-19 15:34:02Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -38,6 +38,8 @@
 #include "canvasview.h"
 #include "workarea.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -55,7 +57,7 @@ using namespace studio;
 
 /* === M E T H O D S ======================================================= */
 
-CanvasOptions::CanvasOptions(loose_handle<studio::CanvasView> canvas_view):
+CanvasOptions::CanvasOptions(etl::loose_handle<CanvasView> canvas_view):
 	Gtk::Dialog(_("Canvas Options"),*canvas_view,false,true),
 	canvas_view_(canvas_view),
 	toggle_grid_snap(_("_Snap to grid"), true),
@@ -183,11 +185,13 @@ CanvasOptions::on_grid_show_toggle()
 void
 CanvasOptions::on_apply_pressed()
 {
+	canvas_view_->set_grid_snap_toggle(toggle_grid_snap.get_active());
 	if(toggle_grid_snap.get_active())
 		canvas_view_->work_area->enable_grid_snap();
 	else
 		canvas_view_->work_area->disable_grid_snap();
 
+	canvas_view_->set_grid_show_toggle(toggle_grid_show.get_active());
 	if(toggle_grid_show.get_active())
 		canvas_view_->work_area->enable_grid();
 	else
