@@ -2,10 +2,11 @@
 /*!	\file canvasproperties.cpp
 **	\brief Template File
 **
-**	$Id: canvasproperties.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: canvasproperties.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -40,6 +41,8 @@
 #include <gtkmm/scrolledwindow.h>
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -57,7 +60,7 @@ using namespace studio;
 
 /* === M E T H O D S ======================================================= */
 
-CanvasProperties::CanvasProperties(Gtk::Window& parent,handle<synfigapp::CanvasInterface> canvas_interface):
+CanvasProperties::CanvasProperties(Gtk::Window& parent,etl::handle<synfigapp::CanvasInterface> canvas_interface):
 	Gtk::Dialog(_("Canvas Properties"),parent,false,true),
 	canvas_interface_(canvas_interface)
 {
@@ -175,7 +178,7 @@ void
 CanvasProperties::on_button_meta_data_add()
 {
 	synfig::String key;
-	if(App::dialog_entry("New MetaData Entry", "Please enter the name of the key",key) && !key.empty())
+	if(App::dialog_entry(_("New MetaData Entry"), _("Please enter the name of the key"),key) && !key.empty())
 	{
 		canvas_interface_->set_meta_data(key," ");
 	}
@@ -219,14 +222,14 @@ CanvasProperties::on_rend_desc_changed()
 void
 CanvasProperties::on_apply_pressed()
 {
-	if(dirty_rend_desc)
-		canvas_interface_->set_rend_desc(widget_rend_desc.get_rend_desc());
-	if(entry_id.get_text()!=canvas_interface_->get_canvas()->get_id())
+	if(entry_id.get_text()!=canvas_interface_->get_canvas()->get_id() && !entry_id.get_text().empty())
 		canvas_interface_->set_id(entry_id.get_text());
 	if(entry_name.get_text()!=canvas_interface_->get_canvas()->get_name())
 		canvas_interface_->set_name(entry_name.get_text());
 	if(entry_description.get_text()!=canvas_interface_->get_canvas()->get_description())
 		canvas_interface_->set_description(entry_description.get_text());
+	if(dirty_rend_desc)			// do this last, because it causes the dialog to be refreshed with currently set values
+		canvas_interface_->set_rend_desc(widget_rend_desc.get_rend_desc());
 
 	dirty_rend_desc=false;
 }
