@@ -2,11 +2,11 @@
 /*!	\file canvasview.h
 **	\brief Template Header
 **
-**	$Id: canvasview.h 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: canvasview.h 1757 2008-02-19 15:34:02Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -98,6 +98,10 @@
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
+namespace synfig {
+	class TransformStack;
+}
+
 namespace studio {
 
 class CanvasViewUIInterface;
@@ -121,7 +125,6 @@ class Widget_Time;
 class Dialog_SoundSelect;
 class Dialog_Preview;
 
-class synfig::TransformStack;
 class Dock_Layers;
 class Dock_Children;
 class Dock_Keyframes;
@@ -155,7 +158,7 @@ public:
 	typedef ChildrenTreeStore::Model ChildrenTreeModel;
 
 	//! Create an instance of this class whenever doing a longer task.
-	/*! Make sure that you check the bool value of this class occasionaly
+	/*! Make sure that you check the bool value of this class occasionally
 	**	to make sure the action has not been canceled. */
 	class IsWorking
 	{
@@ -170,6 +173,9 @@ public:
 
 	typedef synfigapp::CanvasInterface::Mode Mode;
 
+	void set_grid_snap_toggle(bool flag) { grid_snap_toggle->set_active(flag); }
+	void set_grid_show_toggle(bool flag) { grid_show_toggle->set_active(flag); }
+
 	/*
  -- ** -- P R I V A T E   D A T A ---------------------------------------------
 	*/
@@ -185,31 +191,31 @@ private:
 
 	synfig::Rect bbox;
 
-	DEBUGPOINT_CLASS(1);
+	// DEBUGPOINT_CLASS(1);
 
 	//! State Machine
 	Smach smach_;
 
-	DEBUGPOINT_CLASS(2);
+	// DEBUGPOINT_CLASS(2);
 
 	etl::loose_handle<Instance> instance_;
 	etl::handle<synfigapp::CanvasInterface> canvas_interface_;
 
-	DEBUGPOINT_CLASS(3);
+	// DEBUGPOINT_CLASS(3);
 
 	//! Sound and information to play it
 	etl::handle<AudioContainer>		audio;
 	studio::Widget_Sound			*disp_audio; //should this be put into thing too?
 
-	SigC::Connection				playcon;
-	SigC::Connection				stopcon;
+	sigc::connection				playcon;
+	sigc::connection				stopcon;
 
 	std::auto_ptr<UniversalScrubber> universal_scrubber;
 
-	//! Tooltip controler
+	//! Tooltip controller
 	Gtk::Tooltips tooltips;
 
-	DEBUGPOINT_CLASS(4);
+	// DEBUGPOINT_CLASS(4);
 
 	//! TreeModel for the layers
 	LayerTreeModel layer_tree_model;
@@ -223,13 +229,12 @@ private:
 
 	//Glib::RefPtr<KeyframeTreeStore> keyframe_tree_store_;
 
-	DEBUGPOINT_CLASS(5);
+	// DEBUGPOINT_CLASS(5);
 
 	//std::map<synfig::String,Glib::RefPtr<Gtk::TreeModel> > tree_model_book_;
 	std::map<synfig::String,Glib::RefPtr<Glib::ObjectBase> > ref_obj_book_;
 	std::map<synfig::String,Gtk::Widget*> ext_widget_book_;
 
-
 	//! The time adjustment's scope is defined by the time_window adjustment
 	Gtk::Adjustment time_adjustment_;
 
@@ -237,7 +242,6 @@ private:
 	//Gtk::Adjustment time_window_adjustment_;
 	studio::Adjust_Window time_window_adjustment_;
 
-
 	LayerTree *layer_tree;
 
 	ChildrenTree *children_tree;
@@ -265,8 +269,6 @@ private:
 
 	std::list<sigc::connection> duck_changed_connections;
 
-
-
 	Gtk::Button *animatebutton;
 	Gtk::Button *keyframebutton;
 
@@ -308,19 +310,14 @@ private:
 */
 	Gtk::Menu parammenu;
 
-
-	Glib::RefPtr<Gtk::ToggleAction> duck_mask_position;
-	Glib::RefPtr<Gtk::ToggleAction> duck_mask_vertex;
-	Glib::RefPtr<Gtk::ToggleAction> duck_mask_tangent;
-	Glib::RefPtr<Gtk::ToggleAction> duck_mask_radius;
-	Glib::RefPtr<Gtk::ToggleAction> duck_mask_width;
-	Glib::RefPtr<Gtk::ToggleAction> duck_mask_angle;
+	Glib::RefPtr<Gtk::ToggleAction> grid_snap_toggle;
+	Glib::RefPtr<Gtk::ToggleAction> grid_show_toggle;
 
 	Gtk::RadioButtonGroup quality_group;
+	Gtk::RadioButtonGroup low_res_pixel_size_group;
 
 	Glib::RefPtr<Gtk::ActionGroup> action_group;
 
-
 	etl::handle<synfigapp::UIInterface> ui_interface_;
 	etl::handle<synfigapp::SelectionManager> selection_manager_;
 
@@ -349,7 +346,6 @@ public:
 
 	bool cancel;
 
-
 	/*
  -- ** -- D I A L O G S -------------------------------------------------------
 	*/
@@ -376,13 +372,13 @@ private:
 	CanvasView(etl::loose_handle<Instance> instance,etl::handle<synfigapp::CanvasInterface> canvas_interface);
 
 	//! Constructor Helper
-	Gtk::Widget* create_layer_tree();
+	// Gtk::Widget* create_layer_tree();
 
 	//! Constructor Helper
-	Gtk::Widget* create_children_tree();
+	// Gtk::Widget* create_children_tree();
 
 	//! Constructor Helper
-	Gtk::Widget* create_keyframe_tree();
+	// Gtk::Widget* create_keyframe_tree();
 
 	//! Constructor Helper
 	Gtk::Widget* create_status_bar();
@@ -404,20 +400,15 @@ private:
 
 	Gtk::Widget *create_time_bar();
 
-
-
 	void popup_param_menu_bezier(float location, synfigapp::ValueDesc value_desc)
 	{ popup_param_menu(value_desc,location); }
 
 	void popup_param_menu(synfigapp::ValueDesc value_desc, float location=0);
 
-
 	void workarea_layer_selected(synfig::Layer::Handle layer);
 
 	void selected_layer_color_set(synfig::Color color);
 
-
-
 	void register_layer_type(synfig::Layer::Book::value_type &lyr,std::map<synfig::String,Gtk::Menu*>*);
 
 	//! Rebuilds the "new layer" menu
@@ -425,6 +416,9 @@ private:
 
 	void rebuild_ducks_layer_(synfig::TransformStack& transform_stack, synfig::Canvas::Handle canvas, std::set<synfig::Layer::Handle>& selected_list);
 
+	void decrease_low_res_pixel_size();
+	void increase_low_res_pixel_size();
+
 	/*
  -- ** -- P U B L I C   M E T H O D S -----------------------------------------
 	*/
@@ -505,8 +499,11 @@ public:
 	//! Updates the title of the window
 	void update_title();
 
+	//! Closes this document
+	bool close_instance();
+
 	//! Closes this canvas view
-	bool close();
+	bool close_view();
 
 	//!	Stops the currently executing action
 	/*! \see get_cancel_status(), reset_cancel_status(), IsWorking */
@@ -584,7 +581,7 @@ public:
 
 	void image_import();
 
-	void on_waypoint_clicked(synfigapp::ValueDesc,synfig::Waypoint, int button);
+	void on_waypoint_clicked_canvasview(synfigapp::ValueDesc,std::set<synfig::Waypoint,std::less<synfig::UniqueID> >, int button);
 
 	void preview_option() {on_preview_option();}
 
@@ -665,19 +662,19 @@ private:
 	void on_audio_offset_notify();
 
 	bool on_duck_changed(const synfig::Point &value,const synfigapp::ValueDesc& value_desc);
+	bool on_duck_angle_changed(const synfig::Angle &rotation,const synfigapp::ValueDesc& value_desc);
 
 	void on_layer_toggle(synfig::Layer::Handle);
 
 	void on_edited_value(synfigapp::ValueDesc,synfig::ValueBase);
 
-	//void on_waypoint_clicked(synfigapp::ValueDesc,synfig::ValueNode_Animated::WaypointList::iterator, int button);
-
 	void on_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time);
 
 	//void on_audio_play();
 	bool on_audio_scrub();
 
 protected:
+	bool close_instance_when_safe();
 	bool on_delete_event(GdkEventAny* event);
 
 	/*
@@ -687,6 +684,8 @@ protected:
 public:
 
 	static etl::handle<studio::CanvasView> create(etl::loose_handle<Instance> instance,etl::handle<synfig::Canvas> canvas);
+	static std::list<int>& get_pixel_sizes();
+
 }; // END of class CanvasView
 
 }; // END of namespace studio
