@@ -2,10 +2,11 @@
 /*!	\file cellrenderer_time.cpp
 **	\brief Template File
 **
-**	$Id: cellrenderer_time.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: cellrenderer_time.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,6 +36,8 @@
 #include "app.h"
 #include "widget_time.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -46,10 +49,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#if ! defined(_)
-#define _(x)	(x)
-#endif
-
 /* === G L O B A L S ======================================================= */
 
 /* === P R O C E D U R E S ================================================= */
@@ -67,7 +66,8 @@ CellRenderer_Time::CellRenderer_Time():
 
 CellRenderer_Time::~CellRenderer_Time()
 {
-	synfig::info("CellRenderer_Time::~CellRenderer_Time(): deleted");
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("CellRenderer_Time::~CellRenderer_Time(): Deleted");
 }
 
 void
