@@ -2,10 +2,11 @@
 /*!	\file cellrenderer_timetrack.h
 **	\brief Template Header
 **
-**	$Id: cellrenderer_timetrack.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: cellrenderer_timetrack.h 1724 2008-02-17 09:06:45Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -68,12 +69,6 @@
 namespace studio {
 class Widget_ValueBase;
 
-enum Side
-{
-	SIDE_LEFT,
-	SIDE_RIGHT
-};
-
 /*! \class CellRenderer_TimeTrack
 **	\brief A cell renderer that displays the waypoints for Animated ValueNodes.
 */
@@ -90,7 +85,7 @@ private:
 	Gtk::Adjustment adjustment_;
 
 	//! Signal for when the user clicks on a waypoint
-	sigc::signal<void, const Glib::ustring&,synfig::Waypoint, int> signal_waypoint_clicked_;
+	sigc::signal<void, const etl::handle<synfig::Node>&, const synfig::Time&, const synfig::Time&, int> signal_waypoint_clicked_cellrenderer_;
 
 	sigc::signal<void, synfig::Waypoint, synfig::ValueNode::Handle> signal_waypoint_changed_;
 
@@ -158,8 +153,8 @@ public:
 
 public:
 
-	sigc::signal<void, const Glib::ustring&,synfig::Waypoint,int> &signal_waypoint_clicked()
-	{return signal_waypoint_clicked_; }
+	sigc::signal<void, const etl::handle<synfig::Node>&, const synfig::Time&, const synfig::Time&, int> &signal_waypoint_clicked_cellrenderer()
+	{return signal_waypoint_clicked_cellrenderer_; }
 
 	sigc::signal<void, synfig::Waypoint, synfig::ValueNode::Handle> &signal_waypoint_changed()
 	{return signal_waypoint_changed_; }
@@ -173,8 +168,6 @@ public:
 	CellRenderer_TimeTrack();
     ~CellRenderer_TimeTrack();
 
-	void show_timepoint_menu(const etl::handle<synfig::Node>& node, const synfig::Time& time, Side side=SIDE_RIGHT);
-
 	void set_adjustment(Gtk::Adjustment &x);
 	Gtk::Adjustment *get_adjustment();
 	const Gtk::Adjustment *get_adjustment()const;
