@@ -2,7 +2,7 @@
 /*!	\file cellrenderer_value.h
 **	\brief Template File
 **
-**	$Id: cellrenderer_value.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: cellrenderer_value.h 1013 2007-10-30 10:55:11Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -97,7 +97,7 @@ public:
 	Glib::PropertyProxy<synfig::ValueBase> property_value() { return property_value_.get_proxy();}
 	Glib::PropertyProxy<etl::handle<synfig::Canvas> > property_canvas() { return property_canvas_.get_proxy();}
 	Glib::PropertyProxy<synfig::ParamDesc> property_param_desc() { return property_param_desc_.get_proxy(); }
-	Glib::PropertyProxy<bool> property_inconsistant() { return property_foreground_set(); }
+	Glib::PropertyProxy<bool> property_inconsistent() { return property_foreground_set(); }
 
 	etl::handle<synfig::Canvas> get_canvas()const { return property_canvas_; }
 	synfig::ParamDesc get_param_desc()const { return property_param_desc_; }
