@@ -2,10 +2,11 @@
 /*!	\file childrentree.cpp
 **	\brief Template File
 **
-**	$Id: childrentree.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: childrentree.cpp 1724 2008-02-17 09:06:45Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,6 +36,9 @@
 #include <synfigapp/action.h>
 #include <synfigapp/instance.h>
 #include <gtkmm/scrolledwindow.h>
+#include <synfig/timepointcollect.h>
+
+#include "general.h"
 
 #endif
 
@@ -101,7 +105,7 @@ ChildrenTree::ChildrenTree()
 		column->set_resizable();
 		column->set_clickable();
 		column->set_min_width(150);
-		column->set_sort_column_id(model.label);
+		column->set_sort_column(model.label);
 		tree_view.append_column(*column);
 
 	}
@@ -113,7 +117,7 @@ ChildrenTree::ChildrenTree()
 			column->set_reorderable();
 			column->set_resizable();
 			column->set_clickable();
-			column->set_sort_column_id(model.type);
+			column->set_sort_column(model.type);
 		}
 	}
 	{	// --- V A L U E  -----------------------------------------------------
@@ -139,7 +143,7 @@ ChildrenTree::ChildrenTree()
 		// Set up the value-node cell-renderer
 		cellrenderer_time_track=ChildrenTreeStore::add_cell_renderer_value_node(column);
 		cellrenderer_time_track->property_mode()=Gtk::CELL_RENDERER_MODE_ACTIVATABLE;
-		cellrenderer_time_track->signal_waypoint_clicked().connect(sigc::mem_fun(*this, &studio::ChildrenTree::on_waypoint_clicked) );
+		cellrenderer_time_track->signal_waypoint_clicked_cellrenderer().connect(sigc::mem_fun(*this, &studio::ChildrenTree::on_waypoint_clicked_childrentree) );
 		column->add_attribute(cellrenderer_time_track->property_value_desc(), model.value_desc);
 		column->add_attribute(cellrenderer_time_track->property_canvas(), model.canvas);
 
@@ -173,21 +177,18 @@ ChildrenTree::ChildrenTree()
 
 	attach(*hbox, 0, 1, 1, 2, Gtk::FILL|Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 
-
-
 	tree_view.set_enable_search(true);
 	tree_view.set_search_column(model.label);
 
-
 /*
 	Gtk::Image *icon;
 	//Gtk::IconSize iconsize(Gtk::IconSize::from_name("synfig-small_icon"));
 	Gtk::IconSize iconsize(Gtk::ICON_SIZE_SMALL_TOOLBAR);
 
-	SMALL_BUTTON(button_raise,"gtk-go-up","Raise");
-	SMALL_BUTTON(button_lower,"gtk-go-down","Lower");
-	SMALL_BUTTON(button_duplicate,"synfig-duplicate","Duplicate");
-	SMALL_BUTTON(button_delete,"gtk-delete","Delete");
+	SMALL_BUTTON(button_raise,"gtk-go-up",_("Raise"));
+	SMALL_BUTTON(button_lower,"gtk-go-down",_("Lower"));
+	SMALL_BUTTON(button_duplicate,"synfig-duplicate",_("Duplicate"));
+	SMALL_BUTTON(button_delete,"gtk-delete",_("Delete"));
 
 	hbox->pack_start(*button_raise,Gtk::PACK_SHRINK);
 	hbox->pack_start(*button_lower,Gtk::PACK_SHRINK);
@@ -205,11 +206,8 @@ ChildrenTree::ChildrenTree()
 	button_delete->set_sensitive(false);
 */
 
-
-
 	get_selection()->signal_changed().connect(sigc::mem_fun(*this, &studio::ChildrenTree::on_selection_changed));
 
-
 	tree_view.set_reorderable(true);
 
 	hbox->show();
@@ -220,7 +218,6 @@ ChildrenTree::ChildrenTree()
 	//get_selection()->set_mode(Gtk::SELECTION_MULTIPLE);
 }
 
-
 ChildrenTree::~ChildrenTree()
 {
 }
@@ -236,6 +233,7 @@ ChildrenTree::set_model(Glib::RefPtr<ChildrenTreeStore> children_tree_store)
 {
 	children_tree_store_=children_tree_store;
 	tree_view.set_model(children_tree_store_);
+	cellrenderer_time_track->set_canvas_interface(children_tree_store_->canvas_interface()); // am I smart people?  (cellrenderer_timetrack.h:176)
 	children_tree_store_->canvas_interface()->signal_dirty_preview().connect(sigc::mem_fun(*this,&studio::ChildrenTree::on_dirty_preview));
 }
 
@@ -263,7 +261,6 @@ ChildrenTree::on_selection_changed()
 	}
 }
 
-
 void
 ChildrenTree::on_edited_value(const Glib::ustring&path_string,synfig::ValueBase value)
 {
@@ -276,13 +273,28 @@ ChildrenTree::on_edited_value(const Glib::ustring&path_string,synfig::ValueBase
 }
 
 void
-ChildrenTree::on_waypoint_clicked(const Glib::ustring &path_string, synfig::Waypoint waypoint,int button)
+ChildrenTree::on_waypoint_clicked_childrentree(const etl::handle<synfig::Node>& node __attribute__ ((unused)),
+											   const synfig::Time& time __attribute__ ((unused)),
+											   const synfig::Time& time_offset __attribute__ ((unused)),
+											   int button __attribute__ ((unused)))
 {
-	Gtk::TreePath path(path_string);
+	std::set<synfig::Waypoint, std::less<UniqueID> > waypoint_set;
+	synfig::waypoint_collect(waypoint_set,time,node);
 
-	const Gtk::TreeRow row = *(tree_view.get_model()->get_iter(path));
+	synfigapp::ValueDesc value_desc;
 
-	signal_waypoint_clicked()(static_cast<synfigapp::ValueDesc>(row[model.value_desc]),waypoint,button);
+	if (waypoint_set.size() == 1)
+	{
+		ValueNode::Handle value_node(waypoint_set.begin()->get_parent_value_node());
+		assert(value_node);
+
+		Gtk::TreeRow row;
+		if (children_tree_store_->find_first_value_node(value_node, row) && row)
+			value_desc = static_cast<synfigapp::ValueDesc>(row[model.value_desc]);
+	}
+
+	if (!waypoint_set.empty())
+		signal_waypoint_clicked_childrentree()(value_desc,waypoint_set,button);
 }
 
 bool
@@ -306,7 +318,13 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 
 			if(column->get_first_cell_renderer()==cellrenderer_time_track)
 			{
-				return signal_user_click()(event->button.button,row,COLUMNID_TIME_TRACK);
+				Gdk::Rectangle rect;
+				tree_view.get_cell_area(path,*column,rect);
+				cellrenderer_time_track->property_value_desc()=row[model.value_desc];
+				cellrenderer_time_track->property_canvas()=row[model.canvas];
+				cellrenderer_time_track->activate(event,*this,path.to_string(),rect,rect,Gtk::CellRendererState());
+				queue_draw_area(rect.get_x(),rect.get_y(),rect.get_width(),rect.get_height());
+				return true;
 			}
 			else if(column->get_first_cell_renderer()==cellrenderer_value)
 				return signal_user_click()(event->button.button,row,COLUMNID_VALUE);
@@ -337,6 +355,13 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 			if(cellrenderer_time_track==column->get_first_cell_renderer())
 			{
 				// Movement on TimeLine
+				Gdk::Rectangle rect;
+				tree_view.get_cell_area(path,*column,rect);
+				cellrenderer_time_track->property_value_desc()=row[model.value_desc];
+				cellrenderer_time_track->property_canvas()=row[model.canvas];
+				cellrenderer_time_track->activate(event,*this,path.to_string(),rect,rect,Gtk::CellRendererState());
+				queue_draw();
+				//queue_draw_area(rect.get_x(),rect.get_y(),rect.get_width(),rect.get_height());
 				return true;
 			}
 			else
@@ -354,6 +379,35 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 		}
 		break;
 	case GDK_BUTTON_RELEASE:
+		{
+			Gtk::TreeModel::Path path;
+			Gtk::TreeViewColumn *column;
+			int cell_x, cell_y;
+			if(!tree_view.get_path_at_pos(
+				   (int)event->button.x,(int)event->button.y,	// x, y
+				   path, // TreeModel::Path&
+				   column, //TreeViewColumn*&
+				   cell_x,cell_y //int&cell_x,int&cell_y
+				   )
+				) break;
+
+			if(!tree_view.get_model()->get_iter(path))
+				break;
+
+			Gtk::TreeRow row = *(tree_view.get_model()->get_iter(path));
+
+			if(column && cellrenderer_time_track == column->get_first_cell_renderer())
+			{
+				Gdk::Rectangle rect;
+				tree_view.get_cell_area(path,*column,rect);
+				cellrenderer_time_track->property_value_desc()=row[model.value_desc];
+				cellrenderer_time_track->property_canvas()=row[model.canvas];
+				cellrenderer_time_track->activate(event,*this,path.to_string(),rect,rect,Gtk::CellRendererState());
+				queue_draw();
+				queue_draw_area(rect.get_x(),rect.get_y(),rect.get_width(),rect.get_height());
+				return true;
+			}
+		}
 		break;
 	default:
 		break;
