@@ -2,10 +2,11 @@
 /*!	\file childrentree.h
 **	\brief Template Header
 **
-**	$Id: childrentree.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: childrentree.h 1724 2008-02-17 09:06:45Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -98,7 +99,7 @@ private:
 
 	sigc::signal<bool, int, Gtk::TreeRow, ColumnID> signal_user_click_;
 
-	sigc::signal<void,synfigapp::ValueDesc,synfig::Waypoint, int> signal_waypoint_clicked_;
+	sigc::signal<void,synfigapp::ValueDesc,std::set<synfig::Waypoint,std::less<synfig::UniqueID> >,int> signal_waypoint_clicked_childrentree_;
 
 	Gtk::Button *button_raise;
 	Gtk::Button *button_lower;
@@ -121,7 +122,7 @@ private:
 
 	void on_edited_value(const Glib::ustring&path_string,synfig::ValueBase value);
 
-	void on_waypoint_clicked(const Glib::ustring &, synfig::Waypoint,int button);
+	void on_waypoint_clicked_childrentree(const etl::handle<synfig::Node>& node,const synfig::Time&,const synfig::Time&,int button);
 
 	bool on_tree_event(GdkEvent *event);
 
@@ -164,7 +165,7 @@ public:
 
 	sigc::signal<bool,int, Gtk::TreeRow, ColumnID>& signal_user_click() { return signal_user_click_; }
 
-	sigc::signal<void,synfigapp::ValueDesc,synfig::Waypoint, int>& signal_waypoint_clicked() { return signal_waypoint_clicked_; }
+	sigc::signal<void,synfigapp::ValueDesc,std::set<synfig::Waypoint,std::less<synfig::UniqueID> >,int>& signal_waypoint_clicked_childrentree() { return signal_waypoint_clicked_childrentree_; }
 
 	etl::handle<synfigapp::SelectionManager> get_selection_manager() { return children_tree_store_->canvas_interface()->get_selection_manager(); }
 
