@@ -2,7 +2,7 @@
 /*!	\file dialog_gradient.h
 **	\brief Template Header
 **
-**	$Id: dialog_gradient.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_gradient.h 1460 2008-01-25 10:20:02Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -103,7 +103,7 @@ public:
 	Dialog_Gradient();
 	~Dialog_Gradient();
 
-	void edit(const synfigapp::ValueDesc &x, etl::handle<synfigapp::CanvasInterface> canvas_interface, synfig::Time x=0);
+	void edit(const synfigapp::ValueDesc &x, etl::handle<synfigapp::CanvasInterface> canvas_interface, synfig::Time time=0);
 }; // END of Dialog_Gradient
 
 }; // END of namespace studio
