@@ -2,7 +2,7 @@
 /*!	\file dialog_keyframe.cpp
 **	\brief Template File
 **
-**	$Id: dialog_keyframe.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_keyframe.cpp 1205 2007-12-17 09:43:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -36,6 +36,8 @@
 #include <synfigapp/action.h>
 #include <synfigapp/instance.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -53,7 +55,7 @@ using namespace studio;
 
 /* === M E T H O D S ======================================================= */
 
-Dialog_Keyframe::Dialog_Keyframe(Gtk::Window& parent,handle<synfigapp::CanvasInterface> canvas_interface):
+Dialog_Keyframe::Dialog_Keyframe(Gtk::Window& parent, etl::handle<synfigapp::CanvasInterface> canvas_interface):
 	Gtk::Dialog(_("Keyframe Dialog"),parent,false,true),
 	canvas_interface(canvas_interface)
 {
@@ -84,7 +86,7 @@ Dialog_Keyframe::Dialog_Keyframe(Gtk::Window& parent,handle<synfigapp::CanvasInt
 
 	get_vbox()->pack_start(*table);
 
-	entry_description.set_text("Not yet implemented");
+	entry_description.set_text(_("Not yet implemented"));
 
 	//table->attach(*manage(new Gtk::Label(_("Description"))), 0, 1, 0, 1, Gtk::SHRINK|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, 0, 0);
 	//table->attach(entry_description, 1, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, 0, 0);
