@@ -2,7 +2,7 @@
 /*!	\file dialog_preview.cpp
 **	\brief Preview dialog File
 **
-**	$Id: dialog_preview.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_preview.cpp 1205 2007-12-17 09:43:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -35,6 +35,8 @@
 #include <gtkmm/alignment.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/box.h>
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -67,7 +69,7 @@ Dialog_Preview::~Dialog_Preview()
 {
 }
 
-void Dialog_Preview::set_preview(handle<Preview>	prev)
+void Dialog_Preview::set_preview(etl::handle<Preview> prev)
 {
 	get_window().clear();
 	preview.set_preview(prev);
