@@ -2,10 +2,11 @@
 /*!	\file dialog_setup.h
 **	\brief Template Header
 **
-**	$Id: dialog_setup.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialog_setup.h 1801 2008-02-23 01:25:23Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,6 +36,7 @@
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/optionmenu.h>
 #include <gtkmm/checkbutton.h>
+#include <gtkmm/widget_time.h>
 
 #include <synfig/gamma.h>
 #include <synfig/time.h>
@@ -162,11 +164,20 @@ class Dialog_Setup : public Gtk::Dialog
 	Gtk::Adjustment adj_undo_depth;
 
 	Gtk::CheckButton toggle_use_colorspace_gamma;
+#ifdef SINGLE_THREADED
+	Gtk::CheckButton toggle_single_threaded;
+#endif
 
 	synfig::Time::Format time_format;
 
 	Gtk::Menu *timestamp_menu;
 	Widget_Enum *widget_enum;
+
+	Widget_Time auto_backup_interval;
+
+	Gtk::CheckButton toggle_restrict_radius_ducks;
+
+	Gtk::Entry textbox_browser_command;
 public:
 
 	void set_time_format(synfig::Time::Format time_format);
