@@ -2,10 +2,11 @@
 /*!	\file dialogsettings.cpp
 **	\brief Template File
 **
-**	$Id: dialogsettings.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dialogsettings.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -31,6 +32,9 @@
 
 #include "dialogsettings.h"
 #include <synfigapp/main.h>
+#include <gdkmm/general.h>
+
+#include "general.h"
 
 #endif
 
@@ -66,14 +70,14 @@ DialogSettings::get_value(const synfig::String& key, synfig::String& value)const
 {
 	if(key=="pos")
 	{
-		if(!window->is_visible())return false;
+		// if(!window->is_visible())return false;
 		int x,y; window->get_position(x,y);
 		value=strprintf("%d %d",x,y);
 		return true;
 	}
 	if(key=="size")
 	{
-		if(!window->is_visible())return false;
+		// if(!window->is_visible())return false;
 		int x,y; window->get_size(x,y);
 		value=strprintf("%d %d",x,y);
 		return true;
@@ -114,6 +118,9 @@ DialogSettings::get_value(const synfig::String& key, synfig::String& value)const
 bool
 DialogSettings::set_value(const synfig::String& key,const synfig::String& value)
 {
+	int screen_w(Gdk::screen_width());
+	int screen_h(Gdk::screen_height());
+
 	if(value.empty())
 		return false;
 
@@ -122,6 +129,10 @@ DialogSettings::set_value(const synfig::String& key,const synfig::String& value)
 		int x,y;
 		if(!strscanf(value,"%d %d",&x, &y))
 			return false;
+
+		if (x > screen_w) x = screen_w - 150; if (x < 0) x = 0;
+		if (y > screen_h) y = screen_h - 150; if (y < 0) y = 0;
+
 		window->move(x,y);
 		return true;
 	}
@@ -130,6 +141,10 @@ DialogSettings::set_value(const synfig::String& key,const synfig::String& value)
 		int x,y;
 		if(!strscanf(value,"%d %d",&x, &y))
 			return false;
+
+		if (x > screen_w) x = 150; if (x < 0) x = 0;
+		if (y > screen_h) y = 150; if (y < 0) y = 0;
+
 		window->set_default_size(x,y);
 		return true;
 	}
