@@ -2,7 +2,7 @@
 /*!	\file dock_canvases.cpp
 **	\brief Template File
 **
-**	$Id: dock_canvases.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_canvases.cpp 1156 2007-11-16 04:19:10Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "dock_canvases.h"
 #include "app.h"
 #include "canvasview.h"
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -103,7 +105,7 @@ Dock_Canvases::create_canvas_tree()
 	studio::Instance::CanvasTreeModel canvas_tree_model;
 	canvas_tree=manage(new class Gtk::TreeView());
 	{
-		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column("ID") );
+		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("ID")) );
 //		Gtk::CellRendererPixbuf* icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
 
 		//column->pack_start(*icon_cellrenderer,false);
