@@ -2,7 +2,7 @@
 /*!	\file dock_canvasspecific.h
 **	\brief Template Header
 **
-**	$Id: dock_canvasspecific.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_canvasspecific.h 1242 2007-12-29 04:29:22Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -44,7 +44,7 @@ class Instance;
 
 class Dock_CanvasSpecific : public Dockable
 {
-	SigC::Connection canvas_delete_connection;
+	sigc::connection canvas_delete_connection;
 protected:
 	virtual void init_instance_vfunc(etl::loose_handle<Instance> instance);
 
