@@ -2,10 +2,11 @@
 /*!	\file dock_children.cpp
 **	\brief Template File
 **
-**	$Id: dock_children.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_children.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -43,6 +44,8 @@
 #include "childrentree.h"
 #include "canvasview.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -63,7 +66,11 @@ using namespace studio;
 Dock_Children::Dock_Children():
 	Dock_CanvasSpecific("children",_("Children"),Gtk::StockID("synfig-children"))
 {
-	set_use_scrolled(false);
+    //! \todo the combination of set_use_scrolled(false) and
+	//!       add(*tree_view) causes crashes when
+	//!       Dockable::prev_widget_ is left referencing a
+	//!       ChildrenTree that has already been destroyed.
+	// set_use_scrolled(false);
 /*
 	add(*create_action_tree());
 
