@@ -2,7 +2,7 @@
 /*!	\file dock_history.h
 **	\brief Template Header
 **
-**	$Id: dock_history.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_history.h 1751 2008-02-18 19:01:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -47,6 +47,11 @@ class Dock_History : public Dock_CanvasSpecific
 	Gtk::TreeView *action_tree;
 
 	etl::loose_handle<studio::Instance>	selected_instance;
+
+	sigc::connection on_undo_tree_changed_connection;
+
+	void on_undo_tree_changed();
+
 	void set_selected_instance_(etl::handle<studio::Instance> x);
 
 
@@ -64,6 +69,7 @@ public:
 
 	void clear_undo();
 	void clear_redo();
+	void clear_undo_and_redo();
 
 	bool on_action_event(GdkEvent *event);
 	void on_action_toggle(const Glib::ustring& path);
