@@ -2,7 +2,7 @@
 /*!	\file dock_info.h
 **	\brief Info Dock Header
 **
-**	$Id: dock_info.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_info.h 1242 2007-12-29 04:29:22Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -47,7 +47,7 @@ class Dock_Info : public Dock_CanvasSpecific
 	Gtk::Label  r,g,b,a;
 	Gtk::Label	x,y;
 
-	SigC::Connection mousecon;
+	sigc::connection mousecon;
 
 	void on_mouse_move();
 
