@@ -2,7 +2,7 @@
 /*!	\file dock_layergroups.cpp
 **	\brief Template File
 **
-**	$Id: dock_layergroups.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_layergroups.cpp 1156 2007-11-16 04:19:10Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,6 +45,8 @@
 #include "layergrouptree.h"
 #include "groupactionmanager.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -69,7 +71,7 @@ Dock_LayerGroups::Dock_LayerGroups():
 {
 	group_action_manager->set_ui_manager(App::ui_manager());
 
-	action_group_group_ops->add( Gtk::Action::create("toolbar-groups", "Group Ops") );
+	action_group_group_ops->add( Gtk::Action::create("toolbar-groups", _("Group Ops")) );
 
 	action_group_add=Gtk::Action::create("action-group_add", Gtk::Stock::ADD,_("Add a New Group"),_("Add a New Group"));
 	action_group_group_ops->add(action_group_add);
