@@ -2,7 +2,7 @@
 /*!	\file dock_metadata.cpp
 **	\brief Template File
 **
-**	$Id: dock_metadata.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_metadata.cpp 1156 2007-11-16 04:19:10Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -41,6 +41,8 @@
 #include "metadatatreestore.h"
 #include "canvasview.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -129,7 +131,7 @@ Dock_MetaData::on_add_pressed()
 	if(get_canvas_interface())
 	{
 		synfig::String key;
-		if(App::dialog_entry("New MetaData Entry", "Please enter the name of the key",key) && !key.empty())
+		if(App::dialog_entry(_("New MetaData Entry"), _("Please enter the name of the key"),key) && !key.empty())
 		{
 			get_canvas_interface()->set_meta_data(key," ");
 		}
