@@ -2,7 +2,7 @@
 /*!	\file dock_params.cpp
 **	\brief Template File
 **
-**	$Id: dock_params.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dock_params.cpp 1338 2008-01-12 17:49:10Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -42,6 +42,8 @@
 #include "layerparamtreestore.h"
 #include "workarea.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -87,7 +89,6 @@ Dock_Params::~Dock_Params()
 void
 Dock_Params::init_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_view)
 {
-	DEBUGPOINT();
 	Gtk::TreeView* tree_view(
 		static_cast<Gtk::TreeView*>(canvas_view->get_ext_widget(get_name()))
 	);
