@@ -2,7 +2,7 @@
 /*!	\file dockable.cpp
 **	\brief Template File
 **
-**	$Id: dockable.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: dockable.cpp 1777 2008-02-20 01:32:10Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -40,6 +40,8 @@
 #include <gtkmm/table.h>
 #include <gtk/gtk.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -116,7 +118,7 @@ Dockable::Dockable(const synfig::String& name,const synfig::String& local_name,G
 	//	event_box->set_events(Gdk::ALL_EVENTS_MASK); //!< \todo change this to only allow what is necessary for DnD
 
 
-		Gtk::Button* bttn_close(manage(new Gtk::Button("X")));
+		Gtk::Button* bttn_close(manage(new Gtk::Button(_("X"))));
 		//table->attach(*bttn_close, 1, 2, 0,1, Gtk::SHRINK|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, 0, 0);
 		header_box_.pack_end(*bttn_close,false,false);
 		bttn_close->show();
@@ -326,7 +328,7 @@ Dockable::add_button(const Gtk::StockID& stock_id, const synfig::String& tooltip
 	//ret->set_relief(Gtk::RELIEF_HALF);
 	//ret->set_relief(Gtk::RELIEF_NONE);
 	ret->set_label(tooltip);
-	//toolbar_->get_tooltips_object()->set_tip(*ret,tooltip);
+	toolbar_->get_tooltips_object()->set_tip(*ret,tooltip);
 
 	ret->show();
 	//icon->show();
