@@ -2,7 +2,7 @@
 /*!	\file dockable.h
 **	\brief Template Header
 **
-**	$Id: dockable.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dockable.h 1242 2007-12-29 04:29:22Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -59,7 +59,7 @@ class Dockable : public Gtk::Table
 
 
 	sigc::signal<void> signal_stock_id_changed_;
-	SigC::Connection prev_widget_delete_connection;
+	sigc::connection prev_widget_delete_connection;
 protected:
 
 //	DialogSettings dialog_settings;
