@@ -2,7 +2,7 @@
 /*!	\file dockdialog.h
 **	\brief Template Header
 **
-**	$Id: dockdialog.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: dockdialog.h 1242 2007-12-29 04:29:22Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -59,7 +59,7 @@ class DockDialog : public Gtk::Window
 	friend class DockManager;
 	friend class DockBook;
 	friend class Dockable;
-	SigC::Connection empty_sig;
+	sigc::connection empty_sig;
 
 	bool composition_selector_;
 
@@ -70,7 +70,7 @@ class DockDialog : public Gtk::Window
 private:
 	std::list<DockBook*> dock_book_list;
 
-	std::vector<Gtk::Paned*>	pannels_;
+	std::vector<Gtk::Paned*>	panels_;
 	std::vector<int>			dock_book_sizes_;
 
 
