@@ -2,11 +2,11 @@
 /*!	\file duckmatic.cpp
 **	\brief Template File
 **
-**	$Id: duckmatic.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: duckmatic.cpp 1809 2008-02-24 05:16:03Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -56,6 +56,8 @@
 
 #include "onemoment.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -87,7 +89,7 @@ Duckmatic::Duckmatic():
 	grid_snap(false),
 	guide_snap(false),
 	grid_size(1.0/4.0,1.0/4.0),
-	show_persistant_strokes(true)
+	show_persistent_strokes(true)
 {
 	axis_lock=false;
 	drag_offset_=Point(0,0);
@@ -97,7 +99,12 @@ Duckmatic::Duckmatic():
 Duckmatic::~Duckmatic()
 {
 	clear_ducks();
-	//synfig::info("Duckmatic::~Duckmatic(): Deleted. Duck Count=%d",Duck::duck_count);
+
+	if (Duck::duck_count)
+		synfig::error("%d ducks not yet deleted!", Duck::duck_count);
+
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("Duckmatic::~Duckmatic(): Deleted");
 }
 
 void
@@ -110,8 +117,8 @@ Duckmatic::clear_ducks()
 	bezier_list_.clear();
 	stroke_list_.clear();
 
-	if(show_persistant_strokes)
-		stroke_list_=persistant_stroke_list_;
+	if(show_persistent_strokes)
+		stroke_list_=persistent_stroke_list_;
 }
 
 //! Returns \a true if the given duck is currently selected
@@ -151,8 +158,6 @@ Duckmatic::set_guide_snap(bool x)
 	}
 }
 
-
-
 Duckmatic::GuideList::iterator
 Duckmatic::find_guide_x(synfig::Point pos, float radius)
 {
@@ -242,21 +247,19 @@ Duckmatic::is_duck_group_selectable(const etl::handle<Duck>& x)const
 {
 	const Type type(get_type_mask());
 
-	if(( x->get_type() && (!(type & x->get_type())) ) )
-	{
+	if (((x->get_type() && (!(type & x->get_type()))) ||
+		 !x->get_editable()))
 		return false;
-	}
+
 	if(x->get_value_desc().parent_is_layer_param() && type & Duck::TYPE_POSITION)
 	{
 		Layer::Handle layer(x->get_value_desc().get_layer());
 		String layer_name(layer->get_name());
-		if(
-			layer_name=="outline" ||
-			layer_name=="region" ||
-			layer_name=="polygon" ||
-			layer_name=="curve_gradient"
-		)
+
+		if (layer_name == "outline" || layer_name == "region" || layer_name == "plant" ||
+			layer_name == "polygon" || layer_name == "curve_gradient")
 			return false;
+
 		if((layer_name=="PasteCanvas"|| layer_name=="paste_canvas") &&
 		   !layer->get_param("children_lock").get(bool()))
 			return false;
@@ -271,6 +274,8 @@ Duckmatic::select_all_ducks()
 	for(iter=duck_map.begin();iter!=duck_map.end();++iter)
 		if(is_duck_group_selectable(iter->second))
 			select_duck(iter->second);
+		else
+			unselect_duck(iter->second);
 }
 
 void
@@ -382,7 +387,6 @@ Duckmatic::toggle_select_duck(const etl::handle<Duck> &duck)
 		select_duck(duck);
 }
 
-
 void
 Duckmatic::translate_selected_ducks(const synfig::Vector& vector)
 {
@@ -409,7 +413,7 @@ Duckmatic::end_duck_drag()
 }
 
 Point
-Duckmatic::snap_point_to_grid(const Point& x, float radius)const
+Duckmatic::snap_point_to_grid(const synfig::Point& x, float radius)const
 {
 	Point ret(x);
 
@@ -428,8 +432,7 @@ Duckmatic::snap_point_to_grid(const Point& x, float radius)const
 	{
 		Point snap(
 			floor(ret[0]/get_grid_size()[0]+0.5)*get_grid_size()[0],
-			floor(ret[1]/get_grid_size()[1]+0.5)*get_grid_size()[1]
-		);
+			floor(ret[1]/get_grid_size()[1]+0.5)*get_grid_size()[1]);
 
 		if(abs(snap[0]-ret[0])<=radius && (!has_guide_x || abs(snap[0]-ret[0])<=abs(*guide_x-ret[0])))
 			ret[0]=snap[0],has_guide_x=false;
@@ -505,26 +508,21 @@ DuckDrag_Translate::duck_drag(Duckmatic* duckmatic, const synfig::Vector& vector
 
 	for(i=0,iter=selected_ducks.begin();iter!=selected_ducks.end();++iter,i++)
 	{
-		if((*iter)->get_type()!=Duck::TYPE_VERTEX&&(*iter)->get_type()!=Duck::TYPE_POSITION)continue;
+		if((*iter)->get_type()!=Duck::TYPE_VERTEX &&
+		   (*iter)->get_type()!=Duck::TYPE_POSITION)
+			continue;
 		(*iter)->set_trans_point(positions[i]+vect);
 	}
 	for(i=0,iter=selected_ducks.begin();iter!=selected_ducks.end();++iter,i++)
 	{
-		if((*iter)->get_type()==Duck::TYPE_VERTEX||(*iter)->get_type()==Duck::TYPE_POSITION)continue;
+		if((*iter)->get_type()==Duck::TYPE_VERTEX ||
+		   (*iter)->get_type()==Duck::TYPE_POSITION)
+			continue;
 		(*iter)->set_trans_point(positions[i]+vect);
 	}
 	last_translate_=vect;
 }
 
-
-
-
-
-
-
-
-
-
 void
 Duckmatic::signal_edited_selected_ducks()
 {
@@ -540,10 +538,46 @@ Duckmatic::signal_edited_selected_ducks()
 	// Go ahead and call everyone's signals
 	for(iter=ducks.begin();iter!=ducks.end();++iter)
 	{
-		if(!(*iter)->signal_edited()((*iter)->get_point()))
+		if ((*iter)->get_type() == Duck::TYPE_ANGLE)
 		{
-			selected_ducks=old_set;
-			throw String("Bad edit");
+			if(!(*iter)->signal_edited_angle()((*iter)->get_rotations()))
+			{
+				selected_ducks=old_set;
+				throw String("Bad edit");
+			}
+		}
+		else if (App::restrict_radius_ducks &&
+				 (*iter)->is_radius())
+		{
+			Point point((*iter)->get_point());
+			bool changed = false;
+
+			if (point[0] < 0)
+			{
+				point[0] = 0;
+				changed = true;
+			}
+			if (point[1] < 0)
+			{
+				point[1] = 0;
+				changed = true;
+			}
+
+			if (changed) (*iter)->set_point(point);
+
+			if(!(*iter)->signal_edited()(point))
+			{
+				selected_ducks=old_set;
+				throw String("Bad edit");
+			}
+		}
+		else
+		{
+			if(!(*iter)->signal_edited()((*iter)->get_point()))
+			{
+				selected_ducks=old_set;
+				throw String("Bad edit");
+			}
 		}
 	}
 	selected_ducks=old_set;
@@ -561,10 +595,6 @@ Duckmatic::signal_user_click_selected_ducks(int button)
 	}
 }
 
-
-
-
-
 void
 Duckmatic::add_duck(const etl::handle<Duck> &duck)
 {
@@ -615,26 +645,26 @@ Duckmatic::add_stroke(etl::smart_ptr<std::list<synfig::Point> > stroke_point_lis
 }
 
 void
-Duckmatic::add_persistant_stroke(etl::smart_ptr<std::list<synfig::Point> > stroke_point_list, const synfig::Color& color)
+Duckmatic::add_persistent_stroke(etl::smart_ptr<std::list<synfig::Point> > stroke_point_list, const synfig::Color& color)
 {
 	add_stroke(stroke_point_list,color);
-	persistant_stroke_list_.push_back(stroke_list_.back());
+	persistent_stroke_list_.push_back(stroke_list_.back());
 }
 
 void
-Duckmatic::clear_persistant_strokes()
+Duckmatic::clear_persistent_strokes()
 {
-	persistant_stroke_list_.clear();
+	persistent_stroke_list_.clear();
 }
 
 void
-Duckmatic::set_show_persistant_strokes(bool x)
+Duckmatic::set_show_persistent_strokes(bool x)
 {
-	if(x!=show_persistant_strokes)
+	if(x!=show_persistent_strokes)
 	{
-		show_persistant_strokes=x;
+		show_persistent_strokes=x;
 		if(x)
-			stroke_list_=persistant_stroke_list_;
+			stroke_list_=persistent_stroke_list_;
 		else
 			stroke_list_.clear();
 	}
@@ -711,7 +741,6 @@ Duckmatic::last_bezier()const
 	return bezier_list_.back();
 }
 
-
 etl::handle<Duckmatic::Duck>
 Duckmatic::find_duck(synfig::Point point, synfig::Real radius, Duck::Type type)
 {
@@ -729,12 +758,14 @@ Duckmatic::find_duck(synfig::Point point, synfig::Real radius, Duck::Type type)
 	{
 		const Duck::Handle& duck(iter->second);
 
-		if(!duck->get_editable())
+		if(duck->get_ignore())
 			continue;
 		Real dist((duck->get_trans_point()-point).mag_squared());
 
 		if(duck->get_type()&Duck::TYPE_VERTEX)
 			dist*=1.0001;
+		else if(duck->get_type()&Duck::TYPE_RADIUS)
+			dist*=0.9999;
 
 		if(dist<=closest && !( duck->get_type() && (!(type & duck->get_type())) ) )
 		{
@@ -814,11 +845,10 @@ Duckmatic::find_bezier(synfig::Point pos, synfig::Real scale, synfig::Real radiu
 	return 0;
 }
 
-
-
 bool
 Duckmatic::save_sketch(const synfig::String& filename)const
 {
+	ChangeLocale change_locale(LC_NUMERIC, "C");
 	std::ofstream file(filename.c_str());
 
 	if(!file)return false;
@@ -827,7 +857,7 @@ Duckmatic::save_sketch(const synfig::String& filename)const
 
 	std::list<etl::handle<Stroke> >::const_iterator iter;
 
-	for(iter=persistant_stroke_list_.begin();iter!=persistant_stroke_list_.end();++iter)
+	for(iter=persistent_stroke_list_.begin();iter!=persistent_stroke_list_.end();++iter)
 	{
 		file<<"C "
 			<<(*iter)->color.get_r()<<' '
@@ -852,6 +882,7 @@ Duckmatic::save_sketch(const synfig::String& filename)const
 bool
 Duckmatic::load_sketch(const synfig::String& filename)
 {
+	ChangeLocale change_locale(LC_NUMERIC, "C");
 	std::ifstream file(filename.c_str());
 
 	if(!file)
@@ -866,7 +897,6 @@ Duckmatic::load_sketch(const synfig::String& filename)
 		return false;
 	}
 
-
 	etl::smart_ptr<std::list<synfig::Point> > stroke_data;
 
 	while(file)
@@ -888,7 +918,7 @@ Duckmatic::load_sketch(const synfig::String& filename)
 					synfig::warning("Bad color line \"%s\"",line.c_str());
 					r=0;g=0;b=0;
 				}
-				add_persistant_stroke(stroke_data, synfig::Color(r,g,b));
+				add_persistent_stroke(stroke_data, synfig::Color(r,g,b));
 			}
 			break;
 		case 'V':
@@ -896,7 +926,7 @@ Duckmatic::load_sketch(const synfig::String& filename)
 			if(!stroke_data)
 			{
 				stroke_data.spawn();
-				add_persistant_stroke(stroke_data, synfig::Color(0,0,0));
+				add_persistent_stroke(stroke_data, synfig::Color(0,0,0));
 			}
 			float x,y;
 			if(!strscanf(line,"V %f %f",&x, &y))
@@ -914,13 +944,6 @@ Duckmatic::load_sketch(const synfig::String& filename)
 	return true;
 }
 
-
-
-
-
-
-
-
 Duckmatic::Push::Push(Duckmatic *duckmatic_):
 	duckmatic_(duckmatic_)
 {
@@ -949,14 +972,6 @@ Duckmatic::Push::restore()
 	needs_restore=false;
 }
 
-
-
-
-
-
-
-
-
 inline String guid_string(const synfigapp::ValueDesc& x)
 {
 	if(x.parent_is_layer_param())
@@ -965,13 +980,13 @@ inline String guid_string(const synfigapp::ValueDesc& x)
 		return strprintf("%s",x.get_value_node()->get_guid().get_string().c_str());
 }
 
-inline GUID calc_duck_guid(const synfigapp::ValueDesc& x,const synfig::TransformStack& transform_stack)
+inline synfig::GUID calc_duck_guid(const synfigapp::ValueDesc& x,const synfig::TransformStack& transform_stack)
 {
-	GUID ret(0);
+	synfig::GUID ret(0);
 
 	if(x.parent_is_layer_param())
 	{
-		ret=x.get_layer()->get_guid()^GUID::hasher(x.get_param_name());
+		ret=x.get_layer()->get_guid()^synfig::GUID::hasher(x.get_param_name());
 	}
 	else
 	{
@@ -986,7 +1001,7 @@ inline GUID calc_duck_guid(const synfigapp::ValueDesc& x,const synfig::Transform
 Duck::Handle
 Duckmatic::create_duck_from(const synfigapp::ValueDesc& value_desc,etl::handle<CanvasView> canvas_view, const synfig::TransformStack& transform_stack, int modifier, synfig::ParamDesc *param_desc)
 {
-	GUID duck_guid(calc_duck_guid(value_desc,transform_stack)^GUID::hasher(modifier));
+	synfig::GUID duck_guid(calc_duck_guid(value_desc,transform_stack)^synfig::GUID::hasher(modifier));
 	etl::handle<Duck> duck=new Duck();
 
 	return duck;
@@ -1009,7 +1024,8 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			duck->set_radius(true);
 			duck->set_type(Duck::TYPE_RADIUS);
 
-			duck->set_point(Point(value_desc.get_value(get_time()).get(Real()),0));
+			// put the duck on the right hand side of the center
+			duck->set_point(Point(value_desc.get_value(get_time()).get(Real()), 0));
 			duck->set_name(guid_string(value_desc));
 			if(value_desc.is_value_node())
 			{
@@ -1036,16 +1052,13 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 				duck->set_scalar(param_desc->get_scalar());
 			}
 
-			duck->signal_edited().clear();
+			duck->signal_edited().clear(); // value_desc.get_value_type() == ValueBase::TYPE_REAL:
 			duck->signal_edited().connect(
 				sigc::bind(
 					sigc::mem_fun(
 						*canvas_view,
-						&studio::CanvasView::on_duck_changed
-					),
-					value_desc
-				)
-			);
+						&studio::CanvasView::on_duck_changed),
+					value_desc));
 			duck->set_value_desc(value_desc);
 
 			duck->signal_user_click(2).connect(
@@ -1053,15 +1066,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					sigc::bind(
 						sigc::mem_fun(
 							*canvas_view,
-							&studio::CanvasView::popup_param_menu
-						),
-						0.0f
-					),
-					value_desc
-				)
-			);
+							&studio::CanvasView::popup_param_menu),
+						0.0f),
+					value_desc));
 
-			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^GUID::hasher(multiple));
+			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^synfig::GUID::hasher(multiple));
 
 			add_duck(duck);
 
@@ -1112,16 +1121,14 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 				duck->set_scalar(param_desc->get_scalar());
 			}
 
-			duck->signal_edited().clear();
-			duck->signal_edited().connect(
+			duck->signal_edited().clear(); // value_desc.get_value_type() == ValueBase::TYPE_ANGLE:
+			duck->signal_edited_angle().clear();
+			duck->signal_edited_angle().connect(
 				sigc::bind(
 					sigc::mem_fun(
 						*canvas_view,
-						&studio::CanvasView::on_duck_changed
-					),
-					value_desc
-				)
-			);
+						&studio::CanvasView::on_duck_angle_changed),
+					value_desc));
 			duck->set_value_desc(value_desc);
 
 			duck->signal_user_click(2).connect(
@@ -1129,14 +1136,10 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					sigc::bind(
 						sigc::mem_fun(
 							*canvas_view,
-							&studio::CanvasView::popup_param_menu
-						),
-						0.0f
-					),
-					value_desc
-				)
-			);
-			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^GUID::hasher(multiple));
+							&studio::CanvasView::popup_param_menu),
+						0.0f),
+					value_desc));
+			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^synfig::GUID::hasher(multiple));
 
 			add_duck(duck);
 
@@ -1173,9 +1176,9 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 				{
 					synfigapp::ValueDesc value_desc_origin(value_desc.get_layer(),param_desc->get_connect());
 					Duck::Handle connect_duck;
-					if(duck_map.find(calc_duck_guid(value_desc_origin,transform_stack)^GUID::hasher(0))!=duck_map.end())
+					if(duck_map.find(calc_duck_guid(value_desc_origin,transform_stack)^synfig::GUID::hasher(0))!=duck_map.end())
 					{
-						connect_duck=duck_map[calc_duck_guid(value_desc_origin,transform_stack)^GUID::hasher(0)];
+						connect_duck=duck_map[calc_duck_guid(value_desc_origin,transform_stack)^synfig::GUID::hasher(0)];
 					}
 					else
 					{
@@ -1210,17 +1213,13 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			else
 				duck->set_type(Duck::TYPE_POSITION);
 
-
-			duck->signal_edited().clear();
+			duck->signal_edited().clear(); // value_desc.get_value_type() == ValueBase::TYPE_VECTOR:
 			duck->signal_edited().connect(
 				sigc::bind(
 					sigc::mem_fun(
 						*canvas_view,
-						&studio::CanvasView::on_duck_changed
-					),
-					value_desc
-				)
-			);
+						&studio::CanvasView::on_duck_changed),
+					value_desc));
 			duck->set_value_desc(value_desc);
 
 			duck->signal_user_click(2).connect(
@@ -1228,14 +1227,10 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					sigc::bind(
 						sigc::mem_fun(
 							*canvas_view,
-							&studio::CanvasView::popup_param_menu
-						),
-						1.0f
-					),
-					value_desc
-				)
-			);
-			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^GUID::hasher(multiple));
+							&studio::CanvasView::popup_param_menu),
+						1.0f),
+					value_desc));
+			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^synfig::GUID::hasher(multiple));
 			add_duck(duck);
 
 			return true;
@@ -1247,8 +1242,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			ValueNode_Composite::Handle value_node;
 
 			if(value_desc.is_value_node() &&
-				(value_node=ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node()))
-			)
+				(value_node=ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node())))
 			{
 				if(!add_to_ducks(synfigapp::ValueDesc(value_node,0),canvas_view,transform_stack))
 					return false;
@@ -1262,7 +1256,6 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 				bezier->c1->set_scalar(TANGENT_BEZIER_SCALE);
 				bezier->c1->set_tangent(true);
 
-
 				if(!add_to_ducks(synfigapp::ValueDesc(value_node,2),canvas_view,transform_stack))
 					return false;
 				bezier->p2=last_duck();
@@ -1279,11 +1272,8 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					sigc::bind(
 						sigc::mem_fun(
 							*canvas_view,
-							&studio::CanvasView::popup_param_menu_bezier
-						),
-						value_desc
-					)
-				);
+							&studio::CanvasView::popup_param_menu_bezier),
+						value_desc));
 
 				add_bezier(bezier);
 			}
@@ -1343,13 +1333,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 	{
 
 		if(value_desc.is_value_node() &&
-			ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node())
-		)
+			ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node()))
 		{
 			ValueNode_Composite::Handle value_node;
 			value_node=ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node());
 
-
 			if(!add_to_ducks(synfigapp::ValueDesc(value_node,0),canvas_view,transform_stack))
 				return false;
 			etl::handle<Duck> vertex_duck(last_duck());
@@ -1391,9 +1379,8 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 	case ValueBase::TYPE_LIST:
 	{
 		// Check for BLine
-		if(value_desc.is_value_node() &&
-			ValueNode_BLine::Handle::cast_dynamic(value_desc.get_value_node())
-		)
+		if (value_desc.is_value_node() &&
+			ValueNode_BLine::Handle::cast_dynamic(value_desc.get_value_node()))
 		{
 			ValueNode_BLine::Handle value_node;
 			value_node=ValueNode_BLine::Handle::cast_dynamic(value_desc.get_value_node());
@@ -1404,25 +1391,28 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			etl::handle<Duck> first_duck;
 			etl::handle<Duck> duck, tduck;
 
-			for(i=0;i<value_node->link_count();i++)
+			for (i = 0; i < value_node->link_count(); i++)
 			{
 				float amount(value_node->list[i].amount_at_time(get_time()));
-				if(amount<0.9999f)
+
+				// skip vertices that aren't fully on
+				if (amount < 0.9999f)
 					continue;
-				if(first==-1)first=i;
+
+				// remember the index of the first vertex we didn't skip
+				if (first == -1)
+					first = i;
 
 				BLinePoint bline_point((*value_node->get_link(i))(get_time()));
 
-				ValueNode_Composite::Handle vertex_value_node(
-					ValueNode_Composite::Handle::cast_dynamic(
-						value_node->get_link(i)
-					)
-				);
+				// try casting the vertex to Composite - this tells us whether it is composite or not
+				ValueNode_Composite::Handle composite_vertex_value_node(
+					ValueNode_Composite::Handle::cast_dynamic(value_node->get_link(i)));
 
-				// Add the vertex duck
-				if(vertex_value_node)
+				// add the vertex duck - it's a composite
+				if(composite_vertex_value_node)
 				{
-					if(add_to_ducks(synfigapp::ValueDesc(vertex_value_node,0),canvas_view,transform_stack))
+					if (add_to_ducks(synfigapp::ValueDesc(composite_vertex_value_node,0),canvas_view,transform_stack))
 					{
 						duck=last_duck();
 						if(i==first)
@@ -1435,13 +1425,9 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 								sigc::bind(
 									sigc::mem_fun(
 										*canvas_view,
-										&studio::CanvasView::popup_param_menu
-									),
-									1.0f
-								),
-								synfigapp::ValueDesc(value_node,i)
-							)
-						);
+										&studio::CanvasView::popup_param_menu),
+									1.0f),
+								synfigapp::ValueDesc(value_node,i)));
 						duck->set_value_desc(synfigapp::ValueDesc(value_node,i));
 
 						if(param_desc)
@@ -1462,6 +1448,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					else
 						return false;
 				}
+				// else it's not a composite
 				else
 				{
 					duck=new Duck(bline_point.get_vertex());
@@ -1487,37 +1474,50 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 */
 						}
 					}
-					duck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^GUID::hasher(".v"));
+					duck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^synfig::GUID::hasher(".v"));
 					duck=add_similar_duck(duck);
 //					add_duck(duck);
 				}
 
-				// Add the width duck only if we have a hint of scale
-				if(param_desc && !param_desc->get_hint().empty())
+				// Add the width duck if it is a parameter with a hint (ie. "width") or if it isn't a parameter
+				if ((param_desc && !param_desc->get_hint().empty()) ||
+					!param_desc)
 				{
 					etl::handle<Duck> width;
-					if(add_to_ducks(synfigapp::ValueDesc(vertex_value_node,1),canvas_view,transform_stack,REAL_COOKIE))
+					if (add_to_ducks(synfigapp::ValueDesc(composite_vertex_value_node,1),canvas_view,transform_stack,REAL_COOKIE))
 					{
 						width=last_duck();
 						width->set_origin(duck);
 						width->set_type(Duck::TYPE_WIDTH);
 						width->set_name(guid_string(synfigapp::ValueDesc(value_node,i))+".w");
+
+						// if the bline is a layer's parameter, scale the width duck by the layer's "width" parameter
+						if (param_desc)
 						{
 							ValueBase value(synfigapp::ValueDesc(value_desc.get_layer(),param_desc->get_hint()).get_value(get_time()));
 							if(value.same_type_as(synfig::Real()))
 								width->set_scalar(value.get(synfig::Real())*0.5f);
+							// if it doesn't have a "width" parameter, scale by 0.5f instead
+							else
+								width->set_scalar(0.5f);
 						}
+						// otherwise just present the raw unscaled width
+						else
+							width->set_scalar(0.5f);
 					}
 					else
 						synfig::error("Unable to add width duck!");
 				}
 
+				// each bezier uses t2 of one point and t1 of the next
+				// the first time through this loop we won't have the t2 duck from the previous vertex
+				// and so we don't make a bezier.  instead we skip on to t2 for this point
 				if(bezier)
 				{
 					// Add the tangent1 duck
-					if(vertex_value_node)
+					if(composite_vertex_value_node)
 					{
-						if(!add_to_ducks(synfigapp::ValueDesc(vertex_value_node,4),canvas_view,transform_stack))
+						if(!add_to_ducks(synfigapp::ValueDesc(composite_vertex_value_node,4),canvas_view,transform_stack))
 							return false;
 						tduck=last_duck();
 					}
@@ -1528,7 +1528,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 						tduck->set_editable(false);
 						tduck->set_name(guid_string(synfigapp::ValueDesc(value_node,i))+".t1");
 //						tduck->set_name(strprintf("%x-tangent1",value_node->get_link(i).get()));
-						tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^GUID::hasher(".t1"));
+						tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^synfig::GUID::hasher(".t1"));
 						tduck=add_similar_duck(tduck);
 //						add_duck(duck);
 					}
@@ -1544,11 +1544,8 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 						sigc::bind(
 							sigc::mem_fun(
 								*canvas_view,
-								&studio::CanvasView::popup_param_menu_bezier
-							),
-							synfigapp::ValueDesc(value_node,i)
-						)
-					);
+								&studio::CanvasView::popup_param_menu_bezier),
+							synfigapp::ValueDesc(value_node,i)));
 
 					duck->signal_user_click(2).clear();
 					duck->signal_user_click(2).connect(
@@ -1556,50 +1553,39 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 							sigc::bind(
 								sigc::mem_fun(
 									*canvas_view,
-									&studio::CanvasView::popup_param_menu
-								),
-								1.0f
-							),
-							synfigapp::ValueDesc(value_node,i)
-						)
-					);
+									&studio::CanvasView::popup_param_menu),
+								1.0f),
+							synfigapp::ValueDesc(value_node,i)));
 					duck->set_value_desc(synfigapp::ValueDesc(value_node,i));
 
 					add_bezier(bezier);
 					bezier=0;
 				}
 
+				// don't start a new bezier for the last point in the line if we're not looped
 				if(i+1>=value_node->link_count() && !value_node->get_loop())
 					continue;
 
 				bezier=new Bezier();
 
 				// Add the tangent2 duck
-				if(vertex_value_node)
+				if(composite_vertex_value_node)
 				{
 					int i=bline_point.get_split_tangent_flag()?5:4;
-					if(!add_to_ducks(synfigapp::ValueDesc(vertex_value_node,i),canvas_view,transform_stack,0,2))
+					if(!add_to_ducks(synfigapp::ValueDesc(composite_vertex_value_node,i),canvas_view,transform_stack,0,2))
 						return false;
 					tduck=last_duck();
 				}
 				else
 				{
 					if(bline_point.get_split_tangent_flag())
-					{
 						tduck=new Duck(bline_point.get_tangent2());
-						tduck->set_transform_stack(transform_stack);
-						//tduck->set_name(strprintf("%x-tangent2",value_node->get_link(i).get()));
-						tduck->set_name(guid_string(synfigapp::ValueDesc(value_node,i))+".t2");
-						tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^GUID::hasher(".t2"));
-					}
 					else
-					{
 						tduck=new Duck(bline_point.get_tangent1());
-						tduck->set_transform_stack(transform_stack);
-						//tduck->set_name(strprintf("%x-tangent1",value_node->get_link(i).get()));
-						tduck->set_name(guid_string(synfigapp::ValueDesc(value_node,i))+".t1");
-						tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^GUID::hasher(".t1"));
-					}
+
+					tduck->set_transform_stack(transform_stack);
+					tduck->set_name(guid_string(synfigapp::ValueDesc(value_node,i))+".t2");
+					tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^synfig::GUID::hasher(".t2"));
 					tduck->set_editable(false);
 					tduck=add_similar_duck(tduck);
 //					add_duck(duck);
@@ -1622,14 +1608,10 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 							sigc::bind(
 								sigc::mem_fun(
 									*canvas_view,
-									&studio::CanvasView::popup_param_menu
-								),
-								1.0f
-							),
-							synfigapp::ValueDesc(value_node,0)
-						)
-					);
-					duck->set_value_desc(synfigapp::ValueDesc(value_node,0));
+									&studio::CanvasView::popup_param_menu),
+								1.0f),
+							synfigapp::ValueDesc(value_node,i)));
+					duck->set_value_desc(synfigapp::ValueDesc(value_node,i));
 
 				}
 
@@ -1639,109 +1621,72 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 
 				bezier->p1=duck;
 				bezier->c1=tduck;
-
 			}
+
 			// Loop if necessary
 			if(bezier && value_node->get_loop())
 			{
 				BLinePoint bline_point((*value_node->get_link(first))(get_time()));
 
-				ValueNode_Composite::Handle vertex_value_node(
+				ValueNode_Composite::Handle composite_vertex_value_node(
 					ValueNode_Composite::Handle::cast_dynamic(
-						value_node->get_link(first)
-					)
-				);
+						value_node->get_link(first)));
 
 				// Add the vertex duck
 				duck=first_duck;
-				/*
-				if(vertex_value_node)
+
+				// Add the tangent1 duck
+				if(composite_vertex_value_node)
 				{
-					if(!add_to_ducks(synfigapp::ValueDesc(vertex_value_node,0),canvas_view,transform_stack))
+					if(!add_to_ducks(synfigapp::ValueDesc(composite_vertex_value_node,4),canvas_view,transform_stack))
 						return false;
-					duck=last_duck();
-					if(param_desc)
-					{
-						if(!param_desc->get_origin().empty())
-							duck->set_origin(value_desc.get_layer()->get_param(param_desc->get_origin()).get(synfig::Point()));
-					}
-					duck->set_type(Duck::TYPE_VERTEX);
+					tduck=last_duck();
 				}
 				else
 				{
-					duck=new Duck(bline_point.get_vertex());
-					duck->set_transform_stack(transform_stack);
-					if(param_desc)
-					{
-						if(!param_desc->get_origin().empty())
-							duck->set_origin(value_desc.get_layer()->get_param(param_desc->get_origin()).get(synfig::Point()));
-					}
-					duck->set_editable(false);
-					duck->set_name(strprintf("%x-vertex",value_node->get_link(first).get()));
-					duck->set_type(Duck::TYPE_VERTEX);
-					duck=add_similar_duck(duck);
+					tduck=new Duck(bline_point.get_tangent1());
+					tduck->set_transform_stack(transform_stack);
+					tduck->set_editable(false);
+					tduck->set_name(guid_string(synfigapp::ValueDesc(value_node,first))+".t1");
+					//tduck->set_name(strprintf("%x-tangent1",value_node->get_link(first).get()));
+					tduck=add_similar_duck(tduck);
+					tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,first),transform_stack)^synfig::GUID::hasher(".t1"));
+					//add_duck(duck);
 				}
-				*/
 
-					// Add the tangent1 duck
-					if(vertex_value_node)
-					{
-						if(!add_to_ducks(synfigapp::ValueDesc(vertex_value_node,4),canvas_view,transform_stack))
-							return false;
-						tduck=last_duck();
-					}
-					else
-					{
-						tduck=new Duck(bline_point.get_tangent1());
-						tduck->set_transform_stack(transform_stack);
-						tduck->set_editable(false);
-						tduck->set_name(guid_string(synfigapp::ValueDesc(value_node,first))+".t1");
-						//tduck->set_name(strprintf("%x-tangent1",value_node->get_link(first).get()));
-						tduck=add_similar_duck(tduck);
-						tduck->set_guid(calc_duck_guid(synfigapp::ValueDesc(value_node,i),transform_stack)^GUID::hasher(".t1"));
-						//add_duck(duck);
-					}
+				tduck->set_origin(duck);
+				tduck->set_scalar(-TANGENT_BEZIER_SCALE);
+				tduck->set_tangent(true);
 
-					tduck->set_origin(duck);
-					tduck->set_scalar(-TANGENT_BEZIER_SCALE);
-					tduck->set_tangent(true);
+				bezier->p2=duck;
+				bezier->c2=tduck;
 
-					bezier->p2=duck;
-					bezier->c2=tduck;
-					bezier->signal_user_click(2).connect(
+				bezier->signal_user_click(2).connect(
+					sigc::bind(
+						sigc::mem_fun(
+							*canvas_view,
+							&studio::CanvasView::popup_param_menu_bezier),
+						synfigapp::ValueDesc(value_node,first)));
+
+				duck->signal_user_click(2).clear();
+				duck->signal_user_click(2).connect(
+					sigc::bind(
 						sigc::bind(
 							sigc::mem_fun(
 								*canvas_view,
-								&studio::CanvasView::popup_param_menu_bezier
-							),
-							synfigapp::ValueDesc(value_node,first)
-						)
-					);
-					duck->signal_user_click(2).clear();
-					duck->signal_user_click(2).connect(
-						sigc::bind(
-							sigc::bind(
-								sigc::mem_fun(
-									*canvas_view,
-									&studio::CanvasView::popup_param_menu
-								),
-								1.0f
-							),
-							synfigapp::ValueDesc(value_node,first)
-						)
-					);
-					duck->set_value_desc(synfigapp::ValueDesc(value_node,first));
-
-					add_bezier(bezier);
-					bezier=0;
+								&studio::CanvasView::popup_param_menu),
+							1.0f),
+						synfigapp::ValueDesc(value_node,first)));
+				duck->set_value_desc(synfigapp::ValueDesc(value_node,first));
 
+				add_bezier(bezier);
+				bezier=0;
 			}
 			return true;
 		}
 		else // Check for DynamicList
 		if(value_desc.is_value_node() &&
-			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_value_node())
-		)
+			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_value_node()))
 		{
 			ValueNode_DynamicList::Handle value_node;
 			value_node=ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_value_node());
@@ -1750,13 +1695,22 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			if(value_node->get_contained_type()==ValueBase::TYPE_VECTOR)
 			{
 				Bezier bezier;
+				etl::handle<Duck> first_duck, duck;
+				int first = -1;
 				for(i=0;i<value_node->link_count();i++)
 				{
 					if(!value_node->list[i].status_at_time(get_time()))
 						continue;
 					if(!add_to_ducks(synfigapp::ValueDesc(value_node,i),canvas_view,transform_stack))
 						return false;
-					etl::handle<Duck> duck(last_duck());
+					duck = last_duck();
+
+					// remember the index of the first vertex we didn't skip
+					if (first == -1)
+					{
+						first = i;
+						first_duck = duck;
+					}
 
 					if(param_desc)
 					{
@@ -1775,7 +1729,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					bezier.p1=bezier.p2;bezier.c1=bezier.c2;
 					bezier.p2=bezier.c2=duck;
 
-					if(i>0)
+					if (first != i)
 					{
 						handle<Bezier> bezier_(new Bezier());
 						bezier_->p1=bezier.p1;
@@ -1787,13 +1741,31 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 							sigc::bind(
 								sigc::mem_fun(
 									*canvas_view,
-									&studio::CanvasView::popup_param_menu_bezier
-								),
-								synfigapp::ValueDesc(value_node,i)
-							)
-						);
+									&studio::CanvasView::popup_param_menu_bezier),
+								synfigapp::ValueDesc(value_node,i)));
 					}
 				}
+
+				if (value_node->get_loop() && first != -1 && first_duck != duck)
+				{
+					duck = first_duck;
+
+					bezier.p1=bezier.p2;bezier.c1=bezier.c2;
+					bezier.p2=bezier.c2=duck;
+
+					handle<Bezier> bezier_(new Bezier());
+					bezier_->p1=bezier.p1;
+					bezier_->c1=bezier.c1;
+					bezier_->p2=bezier.p2;
+					bezier_->c2=bezier.c2;
+					add_bezier(bezier_);
+					last_bezier()->signal_user_click(2).connect(
+						sigc::bind(
+							sigc::mem_fun(
+								*canvas_view,
+								&studio::CanvasView::popup_param_menu_bezier),
+							synfigapp::ValueDesc(value_node,first)));
+				}
 			}
 			/*else if(value_node->get_contained_type()==ValueBase::TYPE_SEGMENT)
 			{
@@ -1817,7 +1789,6 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 		return true;
 	}
 
-
 	break;
 	default:
 		break;
