@@ -2,11 +2,11 @@
 /*!	\file gtkmm/instance.cpp
 **	\brief writeme
 **
-**	$Id: instance.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: instance.cpp 1802 2008-02-23 01:25:55Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,17 +42,22 @@
 #include <sigc++/adaptors/hide.h>
 #include "toolbox.h"
 #include "onemoment.h"
+#include <synfig/savecanvas.h>
 
 #include "autorecover.h"
 #include <sigc++/retype_return.h>
 #include <sigc++/retype.h>
 //#include <sigc++/hide.h>
 #include <synfig/valuenode_composite.h>
+#include <synfig/valuenode_duplicate.h>
 #include "widget_waypointmodel.h"
 #include <gtkmm/actiongroup.h>
-#include "iconcontroler.h"
+#include "iconcontroller.h"
 #include <sys/stat.h>
 #include <errno.h>
+#include <ETL/stringf>
+
+#include "general.h"
 
 #endif
 
@@ -60,7 +65,7 @@ using namespace std;
 using namespace etl;
 using namespace synfig;
 using namespace studio;
-using namespace SigC;
+using namespace sigc;
 
 /* === M A C R O S ========================================================= */
 
@@ -72,7 +77,7 @@ int studio::Instance::instance_count_=0;
 
 /* === M E T H O D S ======================================================= */
 
-Instance::Instance(Canvas::Handle canvas):
+Instance::Instance(synfig::Canvas::Handle canvas):
 	synfigapp::Instance		(canvas),
 //	canvas_tree_store_		(Gtk::TreeStore::create(CanvasTreeModel())),
 //	canvas_tree_store_		(Gtk::TreeStore::create()),
@@ -120,7 +125,7 @@ Instance::get_visible_canvases()const
 }
 
 handle<Instance>
-Instance::create(Canvas::Handle canvas)
+Instance::create(synfig::Canvas::Handle canvas)
 {
 	// Construct a new instance
 	handle<Instance> instance(new Instance(canvas));
@@ -144,7 +149,7 @@ Instance::create(Canvas::Handle canvas)
 }
 
 handle<CanvasView>
-Instance::find_canvas_view(Canvas::Handle canvas)
+Instance::find_canvas_view(etl::handle<synfig::Canvas> canvas)
 {
 	if(!canvas)
 		return 0;
@@ -162,7 +167,7 @@ Instance::find_canvas_view(Canvas::Handle canvas)
 }
 
 void
-Instance::focus(Canvas::Handle canvas)
+Instance::focus(etl::handle<synfig::Canvas> canvas)
 {
 	handle<CanvasView> canvas_view=find_canvas_view(canvas);
 	assert(canvas_view);
@@ -194,35 +199,53 @@ studio::Instance::save_as(const synfig::String &file_name)
 		list<handle<CanvasView> >::iterator iter;
 		for(iter=canvas_view_list().begin();iter!=canvas_view_list().end();iter++)
 			(*iter)->render_settings.set_entry_filename();
-		App::add_recent_file(file_name);
+		App::add_recent_file(etl::handle<Instance>(this));
 		return true;
 	}
 	return false;
 }
 
+void
+studio::Instance::open()
+{
+	App::dialog_open(get_file_name());
+}
+
 Instance::Status
 studio::Instance::save()
 {
-	// the filename will be set to "Synfig Animation 1" or some such when first created
-	// and will be changed to an absolute path once it has been saved
-	// so if it still begins with "Synfig Animation " then we need to ask where to save it
-	if(get_file_name().find(DEFAULT_FILENAME_PREFIX)==0)
+	// if we don't have a real filename yet then we need to ask where to save it
+	if (!has_real_filename())
+	{
 		if (dialog_save_as())
 			return STATUS_OK;
 		else
 			return STATUS_CANCEL;
+	}
 
 	if (synfigapp::Instance::save())
+	{
+		App::add_recent_file(etl::handle<Instance>(this));
 		return STATUS_OK;
+	}
 
 	App::dialog_error_blocking("Save - Error","Unable to save to '" + get_file_name() + "'");
 	return STATUS_ERROR;
 }
 
+// the filename will be set to "Synfig Animation 1" or some such when first created
+// and will be changed to an absolute path once it has been saved
+// so if it still begins with "Synfig Animation " then we don't have a real filename yet
+bool
+studio::Instance::has_real_filename()
+{
+	return get_file_name().find(DEFAULT_FILENAME_PREFIX) != 0;
+}
+
 bool
 studio::Instance::dialog_save_as()
 {
-	string filename=basename(get_file_name());
+	string filename = get_file_name();
 	Canvas::Handle canvas(get_canvas());
 
 	{
@@ -251,31 +274,31 @@ studio::Instance::dialog_save_as()
 		}
 	}
 
+	if (has_real_filename())
+		filename = absolute_path(filename);
+
 	// show the canvas' name if it has one, else its ID
-	while(App::dialog_save_file(_("Choose a Filename to Save As") +
-								String(" (") +
-								(canvas->get_name().empty()
-								 ? canvas->get_id()
-								 : canvas->get_name()) +
-								") ...", filename))
+	while (App::dialog_save_file((_("Choose a Filename to Save As") +
+								  String(" (") +
+								  (canvas->get_name().empty() ? canvas->get_id() : canvas->get_name()) +
+								  ") ..."),
+								 filename, ANIMATION_DIR_PREFERENCE))
 	{
 		// If the filename still has wildcards, then we should
 		// continue looking for the file we want
-		if(find(filename.begin(),filename.end(),'*')!=filename.end())
+		string base_filename = basename(filename);
+		if (find(base_filename.begin(),base_filename.end(),'*')!=base_filename.end())
 			continue;
 
-		std::string base = basename(filename);
-		if(find(base.begin(),base.end(),'.')==base.end())
+		if (filename_extension(filename) == "")
 			filename+=".sifz";
 
 		try
 		{
-			String ext(String(filename.begin()+filename.find_last_of('.')+1,filename.end()));
-			if(ext!="sif" && ext!="sifz" && !App::dialog_yes_no(_("Unknown extension"),
-				_("You have given the file name an extension\nwhich I do not recognise. Are you sure this is what you want?")))
-			{
+			String ext(filename_extension(filename));
+			if(ext!=".sif" && ext!=".sifz" && !App::dialog_yes_no(_("Unknown extension"),
+				_("You have given the file name an extension\nwhich I do not recognize. Are you sure this is what you want?")))
 				continue;
-			}
 		}
 		catch(...)
 		{
@@ -306,7 +329,10 @@ studio::Instance::dialog_save_as()
 		}
 
 		if(save_as(filename))
+		{
+			synfig::set_file_version(ReleaseVersion(RELEASE_VERSION_END-1));
 			return true;
+		}
 
 		App::dialog_error_blocking("SaveAs - Error","Unable to save to '" + filename + "'");
 	}
@@ -369,9 +395,8 @@ Instance::close()
 		studio::App::instance_list.front()->canvas_view_list().front()->present();
 }
 
-
 void
-Instance::insert_canvas(Gtk::TreeRow row,Canvas::Handle canvas)
+Instance::insert_canvas(Gtk::TreeRow row, synfig::Canvas::Handle canvas)
 {
 	CanvasTreeModel canvas_tree_model;
 	assert(canvas);
@@ -421,7 +446,6 @@ Instance::insert_canvas(Gtk::TreeRow row,Canvas::Handle canvas)
 	*/
 }
 
-
 /*
 void
 Instance::insert_value_node(Gtk::TreeRow row,Canvas::Handle canvas,etl::handle<synfig::ValueNode> value_node)
@@ -483,7 +507,7 @@ Instance::dialog_cvs_commit()
 	}
 	catch(...)
 	{
-		App::dialog_error_blocking(_("Error"),_("An error has occured when trying to COMMIT"));
+		App::dialog_error_blocking(_("Error"),_("An error has occurred when trying to COMMIT"));
 	}
 	update_all_titles();
 }
@@ -508,7 +532,7 @@ Instance::dialog_cvs_add()
 	}
 	catch(...)
 	{
-		App::dialog_error_blocking(_("Error"),_("An error has occured when trying to ADD"));
+		App::dialog_error_blocking(_("Error"),_("An error has occurred when trying to ADD"));
 	}
 	update_all_titles();
 }
@@ -549,7 +573,7 @@ Instance::dialog_cvs_update()
 	}
 	catch(...)
 	{
-		App::dialog_error_blocking(_("Error"),_("An error has occured when trying to UPDATE"));
+		App::dialog_error_blocking(_("Error"),_("An error has occurred when trying to UPDATE"));
 	}
 	//update_all_titles();
 }
@@ -585,7 +609,7 @@ Instance::dialog_cvs_revert()
 	}
 	catch(...)
 	{
-		App::dialog_error_blocking(_("Error"),_("An error has occured when trying to UPDATE"));
+		App::dialog_error_blocking(_("Error"),_("An error has occurred when trying to UPDATE"));
 	}
 	//update_all_titles();
 }
@@ -685,7 +709,6 @@ Instance::safe_close()
 	return true;
 }
 
-
 void
 Instance::add_actions_to_group(const Glib::RefPtr<Gtk::ActionGroup>& action_group, synfig::String& ui_info,   const synfigapp::Action::ParamList &param_list, synfigapp::Action::Category category)const
 {
@@ -696,8 +719,8 @@ Instance::add_actions_to_group(const Glib::RefPtr<Gtk::ActionGroup>& action_grou
 
 	candidate_list.sort();
 
-	if(candidate_list.empty())
-		synfig::warning("%s:%d Action CandidateList is empty!", __FILE__, __LINE__);
+	// if(candidate_list.empty())
+	// 	synfig::warning("%s:%d Action CandidateList is empty!", __FILE__, __LINE__);
 
 	for(iter=candidate_list.begin();iter!=candidate_list.end();++iter)
 	{
@@ -810,7 +833,7 @@ Instance::add_actions_to_menu(Gtk::Menu *menu, const synfigapp::Action::ParamLis
 	if(candidate_list2.empty())
 		synfig::warning("%s:%d Action CandidateList2 is empty!", __FILE__, __LINE__);
 
-	// Seperate out the candidate lists so that there are no conflicts
+	// Separate out the candidate lists so that there are no conflicts
 	for(iter=candidate_list.begin();iter!=candidate_list.end();++iter)
 	{
 		synfigapp::Action::CandidateList::iterator iter2(candidate_list2.find(iter->name));
@@ -921,7 +944,7 @@ Instance::add_actions_to_menu(Gtk::Menu *menu, const synfigapp::Action::ParamLis
 }
 
 void
-Instance::process_action(String name, synfigapp::Action::ParamList param_list)
+Instance::process_action(synfig::String name, synfigapp::Action::ParamList param_list)
 {
 	assert(synfigapp::Action::book().count(name));
 
@@ -1003,10 +1026,21 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 		param_list2.add("origin",location);
 	}
 
-
 	// Populate the convert menu by looping through
 	// the ValueNode book and find the ones that are
 	// relevant.
+
+	// show the 'Convert' sub-menu if this valuedesc is anything other than either:
+	//   the 'Index' parameter of a Duplicate layer
+	// or
+	//   a Duplicate ValueNode whose parent is not a (layer or ValueNode)
+	if (!((value_desc.parent_is_layer_param() &&
+		   value_desc.get_layer()->get_name() == "duplicate" &&
+		   value_desc.get_param_name() == "index") ||
+		  (value_desc.is_value_node() &&
+		   ValueNode_Duplicate::Handle::cast_dynamic(value_desc.get_value_node()) &&
+		   !(value_desc.parent_is_layer_param() ||
+			 value_desc.parent_is_value_node()))))
 	{
 		Gtk::Menu *convert_menu=manage(new Gtk::Menu());
 		LinkableValueNode::Book::const_iterator iter;
@@ -1047,15 +1081,20 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 
 		try
 		{
+			// try to find a waypoint at the current time - if we
+			// can't, we don't want the menu entry - an exception is thrown
 			WaypointList::iterator iter(value_node->find(canvas->get_time()));
+			std::set<synfig::Waypoint, std::less<UniqueID> > waypoint_set;
+			waypoint_set.insert(*iter);
+
 			parammenu.items().push_back(Gtk::Menu_Helpers::MenuElem(_("Edit Waypoint"),
 				sigc::bind(
 					sigc::bind(
 						sigc::bind(
-							sigc::mem_fun(*find_canvas_view(canvas),&studio::CanvasView::on_waypoint_clicked),
+							sigc::mem_fun(*find_canvas_view(canvas),&studio::CanvasView::on_waypoint_clicked_canvasview),
 							-1
 						),
-						*iter
+						waypoint_set
 					),
 					value_desc
 				)
@@ -1083,15 +1122,12 @@ edit_several_waypoints(etl::handle<CanvasView> canvas_view, std::list<synfigapp:
 
 	dialog.get_vbox()->pack_start(widget_waypoint_model);
 
-
 	dialog.add_button(Gtk::StockID("gtk-apply"),1);
 	dialog.add_button(Gtk::StockID("gtk-cancel"),0);
 	dialog.show();
 
-	DEBUGPOINT();
 	if(dialog.run()==0 || widget_waypoint_model.get_waypoint_model().is_trivial())
 		return;
-	DEBUGPOINT();
 	synfigapp::Action::PassiveGrouper group(canvas_interface->get_instance().get(),_("Set Waypoints"));
 
 	std::list<synfigapp::ValueDesc>::iterator iter;
@@ -1135,7 +1171,6 @@ edit_several_waypoints(etl::handle<CanvasView> canvas_view, std::list<synfigapp:
 			action->set_param("canvas",canvas_view->get_canvas());
 			action->set_param("canvas_interface",canvas_interface);
 
-
 			if(!canvas_interface->get_instance()->perform_action(action))
 			{
 				canvas_view->get_ui_interface()->error(_("Unable to convert to animated waypoint"));
@@ -1149,10 +1184,8 @@ edit_several_waypoints(etl::handle<CanvasView> canvas_view, std::list<synfigapp:
 				value_node=ValueNode_Animated::Handle::cast_dynamic(value_desc.get_value_node());
 		}
 
-
 		if(value_node)
 		{
-
 			synfigapp::Action::Handle action(synfigapp::Action::create("waypoint_set_smart"));
 
 			if(!action)
@@ -1162,7 +1195,6 @@ edit_several_waypoints(etl::handle<CanvasView> canvas_view, std::list<synfigapp:
 				return;
 			}
 
-
 			action->set_param("canvas",canvas_view->get_canvas());
 			action->set_param("canvas_interface",canvas_interface);
 			action->set_param("value_node",ValueNode::Handle(value_node));
