@@ -2,7 +2,7 @@
 /*!	\file gtkmm/instance.h
 **	\brief writeme
 **
-**	$Id: instance.h 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: instance.h 1782 2008-02-20 02:06:58Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -178,10 +178,15 @@ public:
 
 	bool save_as(const synfig::String &filename);
 
+	//! returns true if the instance has a real filename associated with it, rather than the made up "synfig animation 1" or some such
+	bool has_real_filename();
+
 	//! Opens a "Save As" dialog, and then saves the composition to that file
 	//! returns true if the save was successful
 	bool dialog_save_as();
 
+	void open();
+
 	Status save();
 
 	void dialog_cvs_commit();
