@@ -2,7 +2,7 @@
 /*!	\file ipc.cpp
 **	\brief Template File
 **
-**	$Id: ipc.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: ipc.cpp 1490 2008-01-25 17:57:53Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -67,6 +67,8 @@
 #include <synfig/string.h>
 #include <glibmm/thread.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -260,11 +262,17 @@ IPC::process_command(const synfig::String& command_line)
 	if(command_line.empty())
 		return false;
 
-	char cmd=command_line[0];
+	char cmd = command_line[0];
 
 	String args(command_line.begin()+1,command_line.end());
-	while(!args.empty() && args[0]==' ') args.erase(args.begin());
-	while(!args.empty() && args[args.size()-1]=='\n' || args[args.size()-1]==' ') args.erase(args.end()-1);
+
+	// erase leading spaces
+	while (!args.empty() && args[0] == ' ')
+		args.erase(args.begin());
+
+	// erase trailing newlines and spaces
+	while (!args.empty() && (args[args.size()-1] == '\n' || args[args.size()-1] == ' '))
+		args.erase(args.end()-1);
 
 	switch(toupper(cmd))
 	{
