@@ -2,7 +2,7 @@
 /*!	\file layeractionmanager.h
 **	\brief Template Header
 **
-**	$Id: layeractionmanager.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layeractionmanager.h 1755 2008-02-19 10:31:20Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -62,10 +62,11 @@ class LayerActionManager
 	Glib::RefPtr<Gtk::Action>	action_amount_dec_;
 	Glib::RefPtr<Gtk::Action>	action_amount_;
 
+	Glib::RefPtr<Gtk::Action>	action_select_all_child_layers_;
+	sigc::connection			select_all_child_layers_connection;
 
 	std::list<synfig::Layer::Handle> clipboard_;
 
-
 	sigc::connection selection_changed_connection;
 
 	bool queued;
@@ -76,6 +77,7 @@ class LayerActionManager
 	void cut();
 	void copy();
 	void paste();
+	void export_dup_nodes(synfig::Layer::Handle, synfig::Canvas::Handle, int &);
 
 	void amount_inc();
 	void amount_dec();
@@ -99,6 +101,8 @@ public:
 
 	void refresh();
 	void clear();
+
+	Glib::RefPtr<Gtk::Action> get_action_select_all_child_layers() { return action_select_all_child_layers_; }
 }; // END of LayerActionManager
 
 }; // END of namespace studio
