@@ -2,10 +2,11 @@
 /*!	\file layergrouptree.cpp
 **	\brief Template File
 **
-**	$Id: layergrouptree.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layergrouptree.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -34,6 +35,8 @@
 #include <gtkmm/treemodelsort.h>
 #include <ETL/misc>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -72,7 +75,7 @@ LayerGroupTree::LayerGroupTree()
 		index=append_column_editable(_("Name"),model.label);
 		label_column = get_column(index-1);
 
-		//column->set_sort_column_id(layer_model.index);
+		//column->set_sort_column(layer_model.index);
 
 		//set_expander_column(*column);
 		//column->set_reorderable();
@@ -108,7 +111,8 @@ LayerGroupTree::LayerGroupTree()
 
 LayerGroupTree::~LayerGroupTree()
 {
-	synfig::info("LayerGroupTree::~LayerGroupTree(): deleted");
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("LayerGroupTree::~LayerGroupTree(): Deleted");
 }
 
 void
@@ -122,7 +126,7 @@ LayerGroupTree::set_model(Glib::RefPtr<LayerGroupTreeStore> layer_group_tree_sto
 		Glib::RefPtr<Gtk::TreeModelSort> sorted_store(Gtk::TreeModelSort::create(layer_group_tree_store_));
 		sorted_store->set_default_sort_func(sigc::ptr_fun(&studio::LayerGroupTreeStore::time_sorter));
 		sorted_store->set_sort_func(model.time.index(),sigc::ptr_fun(&studio::LayerGroupTreeStore::time_sorter));
-		sorted_store->set_sort_column_id(model.time.index(), Gtk::SORT_ASCENDING);
+		sorted_store->set_sort_column(model.time.index(), Gtk::SORT_ASCENDING);
 		Gtk::TreeView::set_model(sorted_store);
 	}
 #else
