@@ -2,10 +2,11 @@
 /*!	\file layergrouptreestore.cpp
 **	\brief Template File
 **
-**	$Id: layergrouptreestore.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: layergrouptreestore.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -30,7 +31,7 @@
 #endif
 
 #include "layergrouptreestore.h"
-#include "iconcontroler.h"
+#include "iconcontroller.h"
 #include <gtkmm/button.h>
 #include <synfig/paramdesc.h>
 #include <synfigapp/action.h>
@@ -40,10 +41,11 @@
 #include <synfigapp/action_system.h>
 #include "dockmanager.h"
 #include "dockable.h"
-#include "iconcontroler.h"
 
 #include <gtk/gtkversion.h>
 #include <ETL/clock>
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -94,7 +96,9 @@ LayerGroupTreeStore::LayerGroupTreeStore(etl::loose_handle<synfigapp::CanvasInte
 LayerGroupTreeStore::~LayerGroupTreeStore()
 {
 	//clear();
-	synfig::info("LayerGroupTreeStore::~LayerGroupTreeStore(): Deleted");
+
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("LayerGroupTreeStore::~LayerGroupTreeStore(): Deleted");
 }
 
 bool
@@ -211,11 +215,7 @@ LayerGroupTreeStore::get_value_vfunc (const Gtk::TreeModel::iterator& iter, int
 			Glib::Value<Glib::ustring> x;
 			g_value_init(x.gobj(),x.value_type());
 
-
-			if(!layer->get_description().empty())
-				x.set(layer->get_description());
-			else
-				x.set(layer->get_local_name());
+			x.set(layer->get_non_empty_description());
 
 			g_value_init(value.gobj(),x.value_type());
 			//g_value_copy(x.gobj(),value.gobj());
@@ -670,12 +670,10 @@ LayerGroupTreeStore::drag_data_received_vfunc (const TreeModel::Path& dest, cons
 				action->set_param("dest_canvas",dest_canvas);
 				if(canvas_interface()->get_instance()->perform_action(action))
 				{
-					DEBUGPOINT();
 					ret=true;
 				}
 				else
 				{
-					DEBUGPOINT();
 					passive_grouper.cancel();
 					return false;
 				}
@@ -683,7 +681,7 @@ LayerGroupTreeStore::drag_data_received_vfunc (const TreeModel::Path& dest, cons
 			}
 		}
 	}
-	synfig::info("I suposidly moved %d layers",i);
+	synfig::info("I supposedly moved %d layers",i);
 
 	// Reselect the previously selected layers
 	canvas_interface()->get_selection_manager()->set_selected_layers(selected_layer_list);
@@ -703,7 +701,7 @@ void
 LayerGroupTreeStore::rebuild()
 {
 	rebuilding=true;
-		etl::clock timer;timer.reset();
+	// etl::clock timer;timer.reset();
 	try {
 
 		// Clear out the current list
@@ -736,7 +734,7 @@ LayerGroupTreeStore::rebuild()
 		throw;
 	}
 	rebuilding=false;
-	synfig::info("LayerGroupTreeStore::rebuild() took %f seconds",float(timer()));
+	// synfig::info("LayerGroupTreeStore::rebuild() took %f seconds",float(timer()));
 }
 
 void
@@ -830,8 +828,6 @@ LayerGroupTreeStore::on_group_added(synfig::String group)
 bool
 LayerGroupTreeStore::on_group_removed(synfig::String group)
 {
-	//DEBUGPOINT();
-
 	Gtk::TreeModel::Children::iterator iter;
 	if(find_group_row(group,iter) && iter->children().size()==0)
 		erase(iter);
@@ -844,16 +840,14 @@ LayerGroupTreeStore::on_group_removed(synfig::String group)
 bool
 LayerGroupTreeStore::on_group_changed(synfig::String /*group*/)
 {
-	//DEBUGPOINT();
 	return true;
 }
 
 void
-LayerGroupTreeStore::on_group_pair_added(String group, etl::handle<Layer> layer)
+LayerGroupTreeStore::on_group_pair_added(synfig::String group, etl::handle<synfig::Layer> layer)
 {
 	if(!layer->get_canvas())
 		return;
-	//DEBUGPOINT();
 	Gtk::TreeModel::Children::iterator iter;
 	if(!find_group_row(group, iter))
 		iter=on_group_added(group);
@@ -864,11 +858,10 @@ LayerGroupTreeStore::on_group_pair_added(String group, etl::handle<Layer> layer)
 }
 
 void
-LayerGroupTreeStore::on_group_pair_removed(String group, etl::handle<Layer> layer)
+LayerGroupTreeStore::on_group_pair_removed(synfig::String group, etl::handle<synfig::Layer> layer)
 {
 	if(!layer->get_canvas())
 		return;
-	//DEBUGPOINT();
 	Gtk::TreeModel::Children::iterator iter;
 	if(!find_group_row(group, iter))
 		return;
@@ -951,7 +944,6 @@ LayerGroupTreeStore::find_layer_row_(const synfig::Layer::Handle &layer, synfig:
 		}
 
 		iter=children().end();
-		//DEBUGPOINT();
 		//return false;
 	}
 
@@ -986,7 +978,7 @@ LayerGroupTreeStore::find_layer_row(const synfig::Layer::Handle &layer, Gtk::Tre
 }
 
 bool
-LayerGroupTreeStore::find_group_row(const String &group, Gtk::TreeModel::Children::iterator &iter)
+LayerGroupTreeStore::find_group_row(const synfig::String &group, Gtk::TreeModel::Children::iterator &iter)
 {
 	Gtk::TreeModel::Children::iterator prev;
 	return find_group_row_(group,children(),iter,prev);
@@ -1005,7 +997,6 @@ LayerGroupTreeStore::find_group_row_(const synfig::String &group, Gtk::TreeModel
 		}
 
 		iter=children().end();
-		//DEBUGPOINT();
 		//return false;
 	}
 
