@@ -2,10 +2,11 @@
 /*!	\file layertree.cpp
 **	\brief Template File
 **
-**	$Id: layertree.cpp 578 2007-09-03 19:13:34Z dooglus $
+**	$Id: layertree.cpp 1745 2008-02-18 11:22:13Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -41,6 +42,12 @@
 #include "instance.h"
 #include <gtkmm/treemodelsort.h>
 
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+#  include <synfig/timepointcollect.h>
+#endif	// TIMETRACK_IN_PARAMS_PANEL
+
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -116,9 +123,6 @@ LayerTree::LayerTree():
 	attach(*layer_amount_hscale, 1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK, 1, 1);
 	layer_amount_adjustment_.signal_value_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_amount_value_changed));
 
-
-
-
 	Gtk::Image *icon;
 	//Gtk::IconSize iconsize(Gtk::IconSize::from_name("synfig-small_icon"));
 	Gtk::IconSize iconsize(Gtk::ICON_SIZE_SMALL_TOOLBAR);
@@ -126,36 +130,35 @@ LayerTree::LayerTree():
 	SMALL_BUTTON(button_raise,"gtk-go-up","Raise");
 	SMALL_BUTTON(button_lower,"gtk-go-down","Lower");
 	SMALL_BUTTON(button_duplicate,"synfig-duplicate","Duplicate");
+	SMALL_BUTTON(button_encapsulate,"synfig-encapsulate","Encapsulate");
 	SMALL_BUTTON(button_delete,"gtk-delete","Delete");
 
 	hbox->pack_start(*button_raise,Gtk::PACK_SHRINK);
 	hbox->pack_start(*button_lower,Gtk::PACK_SHRINK);
 	hbox->pack_start(*button_duplicate,Gtk::PACK_SHRINK);
+	hbox->pack_start(*button_encapsulate,Gtk::PACK_SHRINK);
 	hbox->pack_start(*button_delete,Gtk::PACK_SHRINK);
 
-	button_raise->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_raise_pressed));
-	button_lower->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_lower_pressed));
-	button_duplicate->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_duplicate_pressed));
-	button_delete->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_delete_pressed));
-
+	// button_raise->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_raise_pressed));
+	// button_lower->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_lower_pressed));
+	// button_duplicate->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_duplicate_pressed));
+	// button_encapsulate->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_encapsulate_pressed));
+	// button_delete->signal_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_delete_pressed));
+	
 	button_raise->set_sensitive(false);
 	button_lower->set_sensitive(false);
 	button_duplicate->set_sensitive(false);
+	button_encapsulate->set_sensitive(false);
 	button_delete->set_sensitive(false);
 
-
-
-
 	get_selection()->signal_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_selection_changed));
 
-
 	get_layer_tree_view().set_reorderable(true);
 	get_selection()->set_mode(Gtk::SELECTION_MULTIPLE);
 	//get_param_tree_view().get_selection()->set_mode(Gtk::SELECTION_MULTIPLE);
 	get_layer_tree_view().show();
 	get_param_tree_view().show();
 
-
 	hbox->show();
 	layer_amount_hscale->show();
 	blend_method_widget.show();
@@ -163,10 +166,6 @@ LayerTree::LayerTree():
 	tooltips_.enable();
 	disable_amount_changed_signal=false;
 
-
-
-
-
 	blend_method_widget.set_param_desc(ParamDesc(Color::BlendMethod(),"blend_method"));
 
 	blend_method_widget.set_value((int)Color::BLEND_COMPOSITE);
@@ -175,10 +174,10 @@ LayerTree::LayerTree():
 	blend_method_widget.signal_activate().connect(sigc::mem_fun(*this, &studio::LayerTree::on_blend_method_changed));
 }
 
-
 LayerTree::~LayerTree()
 {
-	synfig::info("LayerTree::~LayerTree(): Deleted");
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("LayerTree::~LayerTree(): Deleted");
 }
 
 Gtk::Widget*
@@ -186,7 +185,6 @@ LayerTree::create_layer_tree()
 {
 	const LayerTreeStore::Model model;
 
-
 	{	// --- O N / O F F ----------------------------------------------------
 		//int index;
 		//index=get_layer_tree_view().append_column_editable(_(" "),layer_model.active);
@@ -209,8 +207,7 @@ LayerTree::create_layer_tree()
 		Gtk::TreeView::Column* column = get_layer_tree_view().get_column(index-1);
 		get_layer_tree_view().set_expander_column(*column);
 
-
-		column->set_sort_column_id(layer_model.z_depth);
+		column->set_sort_column(layer_model.z_depth);
 		//column->set_reorderable();
 		//column->set_resizable();
 		//column->set_clickable();
@@ -221,27 +218,27 @@ LayerTree::create_layer_tree()
 	}
 	//get_layer_tree_view().append_column(_("Z"),layer_model.z_depth);
 	{	// --- N A M E --------------------------------------------------------
-		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Layer")) );
+		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Name")) );
 
 		// Set up the icon cell-renderer
 		Gtk::CellRendererText* cellrenderer = Gtk::manage( new Gtk::CellRendererText() );
+		column->pack_start(*cellrenderer,false);
+		column->add_attribute(cellrenderer->property_text(), layer_model.label);
 		cellrenderer->signal_edited().connect(sigc::mem_fun(*this, &studio::LayerTree::on_layer_renamed));
 		cellrenderer->property_editable()=true;
 
-		column->pack_start(*cellrenderer,false);
-		column->add_attribute(cellrenderer->property_text(), layer_model.label);
+		column->set_reorderable();
+		// column->set_resizable();
+		column->set_clickable(true);
+		column->set_sort_column(layer_model.label);
+
 		get_layer_tree_view().append_column(*column);
 
 		//		int index;
 //		index=get_layer_tree_view().append_column_editable(_("Layer"),layer_model.label);
 		//Gtk::TreeView::Column* column = get_layer_tree_view().get_column(index-1);
 
-		//column->set_sort_column_id(layer_model.index);
-
 		//get_layer_tree_view().set_expander_column(*column);
-		//column->set_reorderable();
-		//column->set_resizable();
-		//column->set_clickable(false);
 
 		//Gtk::CellRendererPixbuf* icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
 		//column->pack_start(*icon_cellrenderer,false);
@@ -256,7 +253,7 @@ LayerTree::create_layer_tree()
 		column_z_depth->set_resizable();
 		column_z_depth->set_clickable();
 
-		column_z_depth->set_sort_column_id(layer_model.z_depth);
+		column_z_depth->set_sort_column(layer_model.z_depth);
 	}
 
 	get_layer_tree_view().set_enable_search(true);
@@ -267,7 +264,6 @@ LayerTree::create_layer_tree()
 	listTargets.push_back( Gtk::TargetEntry("LAYER") );
 	get_layer_tree_view().drag_dest_set(listTargets);
 
-
 	// This makes things easier to read.
 	get_layer_tree_view().set_rules_hint();
 
@@ -277,8 +273,6 @@ LayerTree::create_layer_tree()
 	get_layer_tree_view().signal_event().connect(sigc::mem_fun(*this, &studio::LayerTree::on_layer_tree_event));
 	get_layer_tree_view().show();
 
-
-
 	Gtk::ScrolledWindow *scroll = manage(new class Gtk::ScrolledWindow());
 	scroll->set_flags(Gtk::CAN_FOCUS);
 	scroll->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
@@ -344,7 +338,7 @@ LayerTree::create_param_tree()
 		cellrenderer_value->signal_edited().connect(sigc::mem_fun(*this, &studio::LayerTree::on_edited_value));
 		cellrenderer_value->property_value()=synfig::ValueBase();
 		column->add_attribute(cellrenderer_value->property_param_desc(), param_model.param_desc);
-		column->add_attribute(cellrenderer_value->property_inconsistant(),param_model.is_inconsistent);
+		column->add_attribute(cellrenderer_value->property_inconsistent(),param_model.is_inconsistent);
 		//cellrenderer_value->property_canvas()=canvas_interface->get_canvas(); // Is this line necessary?
 		cellrenderer_value->property_attributes()=attr_list;
 
@@ -356,29 +350,41 @@ LayerTree::create_param_tree()
 		column->set_reorderable();
 		column->set_resizable();
 	}
-	/*{	// --- T I M E   T R A C K --------------------------------------------
+	{	// --- T Y P E --------------------------------------------------------
+		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Type")) );
+		Gtk::CellRendererText* text_cellrenderer = Gtk::manage( new Gtk::CellRendererText() );
+		column->pack_start(*text_cellrenderer,false);
+		column->add_attribute(text_cellrenderer->property_text(), param_model.type);
+		text_cellrenderer->property_attributes()=attr_list;
+		get_param_tree_view().append_column(*column);
+		column->set_reorderable();
+		column->set_resizable();
+		column->set_clickable();
+		column->set_sort_column(param_model.type);
+	}
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+	{	// --- T I M E   T R A C K --------------------------------------------
 		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Time Track")) );
 		column_time_track=column;
 
 		// Set up the value-node cell-renderer
 		cellrenderer_time_track=LayerParamTreeStore::add_cell_renderer_value_node(column);
 		cellrenderer_time_track->property_mode()=Gtk::CELL_RENDERER_MODE_ACTIVATABLE;
-		cellrenderer_time_track->signal_waypoint_clicked().connect(sigc::mem_fun(*this, &studio::LayerTree::on_waypoint_clicked) );
+		cellrenderer_time_track->signal_waypoint_clicked_cellrenderer().connect(sigc::mem_fun(*this, &studio::LayerTree::on_waypoint_clicked_layertree) );
 		cellrenderer_time_track->signal_waypoint_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_waypoint_changed) );
 		column->add_attribute(cellrenderer_time_track->property_value_desc(), param_model.value_desc);
 		column->add_attribute(cellrenderer_time_track->property_canvas(), param_model.canvas);
-		//column->add_attribute(cellrenderer_time_track->property_visible(), model.is_value_node);
-
-		//column->pack_start(*cellrenderer_time_track);
+		column->add_attribute(cellrenderer_time_track->property_visible(), param_model.is_value_node);
 
 		// Finish setting up the column
 		column->set_reorderable();
 		column->set_resizable();
 		column->set_min_width(200);
-		//get_param_tree_view().append_column(*column);
-	}*/
-
 
+		if (!getenv("SYNFIG_DISABLE_PARAMS_PANEL_TIMETRACK"))
+			get_param_tree_view().append_column(*column);
+	}
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 
 	// This makes things easier to read.
 	get_param_tree_view().set_rules_hint();
@@ -415,7 +421,7 @@ LayerTree::on_waypoint_changed( synfig::Waypoint waypoint , synfig::ValueNode::H
 }
 
 void
-LayerTree::select_layer(Layer::Handle layer)
+LayerTree::select_layer(synfig::Layer::Handle layer)
 {
 	Gtk::TreeModel::Children::iterator iter;
 	if(layer_tree_store_->find_layer_row(layer,iter))
@@ -510,18 +516,6 @@ LayerTree::clear_selected_layers()
 	get_layer_tree_view().get_selection()->unselect_all();
 }
 
-
-
-
-
-
-
-
-
-
-
-
-
 void
 LayerTree::set_show_timetrack(bool x)
 {
@@ -535,7 +529,6 @@ LayerTree::set_model(Glib::RefPtr<LayerTreeStore> layer_tree_store)
 {
 	layer_tree_store_=layer_tree_store;
 
-
 	if(false)
 	{
 		sorted_layer_tree_store_=Gtk::TreeModelSort::create(layer_tree_store);
@@ -543,7 +536,7 @@ LayerTree::set_model(Glib::RefPtr<LayerTreeStore> layer_tree_store)
 		sorted_layer_tree_store_->set_default_sort_func(sigc::ptr_fun(&studio::LayerTreeStore::z_sorter));
 
 		//sorted_store->set_sort_func(model.time.index(),sigc::mem_fun(&studio::KeyframeTreeStore::time_sorter));
-		//sorted_store->set_sort_column_id(model.time.index(), Gtk::SORT_ASCENDING);
+		//sorted_store->set_sort_column(model.time.index(), Gtk::SORT_ASCENDING);
 
 		get_layer_tree_view().set_model(sorted_layer_tree_store_);
 	}
@@ -566,17 +559,18 @@ LayerTree::set_model(Glib::RefPtr<LayerTreeStore> layer_tree_store)
 		get_param_tree_view().set_model(param_tree_store_);
 	}
 
-/*	if(cellrenderer_time_track && layer_tree_store_ && layer_tree_store_->canvas_interface())
-	{
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+	if(cellrenderer_time_track && layer_tree_store_ && layer_tree_store_->canvas_interface())
 		cellrenderer_time_track->set_canvas_interface(layer_tree_store_->canvas_interface());
-	}
-*/
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 }
 
 void
 LayerTree::set_time_adjustment(Gtk::Adjustment &adjustment)
 {
-	//cellrenderer_time_track->set_adjustment(adjustment);
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+	cellrenderer_time_track->set_adjustment(adjustment);
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 	adjustment.signal_value_changed().connect(sigc::mem_fun(get_param_tree_view(),&Gtk::TreeView::queue_draw));
 	adjustment.signal_changed().connect(sigc::mem_fun(get_param_tree_view(),&Gtk::TreeView::queue_draw));
 }
@@ -618,7 +612,6 @@ LayerTree::on_selection_changed()
 		}
 	}
 
-
 	{
 		if(!layer_list.empty())
 		{
@@ -631,12 +624,12 @@ LayerTree::on_selection_changed()
 		}
 	}
 
-
 	if(layer_list.empty())
 	{
 		button_raise->set_sensitive(false);
 		button_lower->set_sensitive(false);
 		button_duplicate->set_sensitive(false);
+		button_encapsulate->set_sensitive(false);
 		button_delete->set_sensitive(false);
 		layer_amount_hscale->set_sensitive(false);
 		blend_method_widget.set_sensitive(false);
@@ -646,6 +639,7 @@ LayerTree::on_selection_changed()
 	button_raise->set_sensitive(true);
 	button_lower->set_sensitive(true);
 	button_duplicate->set_sensitive(true);
+	button_encapsulate->set_sensitive(true);
 	button_delete->set_sensitive(true);
 
 	if(layer_list.size()==1 && (*layer_list.begin())->get_param("amount").is_valid()&& (*layer_list.begin())->get_param("amount").same_type_as(Real()))
@@ -678,7 +672,6 @@ LayerTree::on_selection_changed()
 	}
 }
 
-
 void
 LayerTree::on_blend_method_changed()
 {
@@ -708,7 +701,6 @@ LayerTree::on_amount_value_changed()
 	disable_amount_changed_signal=false;
 }
 
-
 void
 LayerTree::on_edited_value(const Glib::ustring&path_string,synfig::ValueBase value)
 {
@@ -730,6 +722,7 @@ LayerTree::on_layer_renamed(const Glib::ustring&path_string,const Glib::ustring&
 	if(!row)
 		return;
 	row[layer_model.label]=value;
+	get_layer_tree_view().columns_autosize();
 }
 
 void
@@ -742,17 +735,32 @@ LayerTree::on_layer_toggle(const Glib::ustring& path_string)
 	row[layer_model.active]=!active;
 }
 
+#ifdef TIMETRACK_IN_PARAMS_PANEL
 void
-LayerTree::on_waypoint_clicked(const Glib::ustring &path_string, synfig::Waypoint waypoint,int button)
+LayerTree::on_waypoint_clicked_layertree(const etl::handle<synfig::Node>& node __attribute__ ((unused)),
+										 const synfig::Time& time __attribute__ ((unused)),
+										 const synfig::Time& time_offset __attribute__ ((unused)),
+										 int button __attribute__ ((unused)))
 {
-	Gtk::TreePath path(path_string);
+	std::set<synfig::Waypoint, std::less<UniqueID> > waypoint_set;
+	synfig::waypoint_collect(waypoint_set,time,node);
 
-	const Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
-	if(!row)
-		return;
+	synfigapp::ValueDesc value_desc;
 
-	signal_waypoint_clicked()(static_cast<synfigapp::ValueDesc>(row[param_model.value_desc]),waypoint,button);
+	if (waypoint_set.size() == 1)
+	{
+		ValueNode::Handle value_node(waypoint_set.begin()->get_parent_value_node());
+		assert(value_node);
+
+		Gtk::TreeRow row;
+		if (param_tree_store_->find_first_value_node(value_node, row) && row)
+			value_desc = static_cast<synfigapp::ValueDesc>(row[param_tree_store_->model.value_desc]);
+	}
+
+	if (!waypoint_set.empty())
+		signal_waypoint_clicked_layertree()(value_desc,waypoint_set,button);
 }
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 
 bool
 LayerTree::on_layer_tree_event(GdkEvent *event)
@@ -773,10 +781,12 @@ LayerTree::on_layer_tree_event(GdkEvent *event)
 			) break;
 			const Gtk::TreeRow row = *(get_layer_tree_view().get_model()->get_iter(path));
 
-			//if(column->get_first_cell_renderer()==cellrenderer_time_track)
-			//	return signal_layer_user_click()(event->button.button,row,COLUMNID_TIME_TRACK);
-			//else
-				if(column->get_first_cell_renderer()==cellrenderer_value)
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+			if(column->get_first_cell_renderer()==cellrenderer_time_track)
+				return signal_layer_user_click()(event->button.button,row,COLUMNID_TIME_TRACK);
+			else
+#endif	// TIMETRACK_IN_PARAMS_PANEL
+			if(column->get_first_cell_renderer()==cellrenderer_value)
 				return signal_layer_user_click()(event->button.button,row,COLUMNID_VALUE);
 			else
 				return signal_layer_user_click()(event->button.button,row,COLUMNID_NAME);
@@ -802,14 +812,12 @@ LayerTree::on_layer_tree_event(GdkEvent *event)
 
 			Gtk::TreeRow row = *(get_layer_tree_view().get_model()->get_iter(path));
 
-			/*
+#ifdef TIMETRACK_IN_PARAMS_PANEL
 			if(cellrenderer_time_track==column->get_first_cell_renderer())
-			{
 				// Movement on TimeLine
 				return true;
-			}
 			else
-				*/
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 			if(last_tooltip_path.get_depth()<=0 || path!=last_tooltip_path)
 			{
 				tooltips_.unset_tip(*this);
@@ -831,7 +839,6 @@ LayerTree::on_layer_tree_event(GdkEvent *event)
 	return false;
 }
 
-
 bool
 LayerTree::on_param_tree_event(GdkEvent *event)
 {
@@ -851,7 +858,8 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 			) break;
 			const Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
 
-/*			if(column && column->get_first_cell_renderer()==cellrenderer_time_track)
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+			if(column && column->get_first_cell_renderer()==cellrenderer_time_track)
 			{
 				Gdk::Rectangle rect;
 				get_param_tree_view().get_cell_area(path,*column,rect);
@@ -863,7 +871,8 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 				//return signal_param_user_click()(event->button.button,row,COLUMNID_TIME_TRACK);
 			}
 			else
-*/			{
+#endif	// TIMETRACK_IN_PARAMS_PANEL
+			{
 				if(event->button.button==3)
 				{
 					LayerList layer_list(get_selected_layers());
@@ -871,11 +880,13 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 					{
 						synfigapp::ValueDesc value_desc(row[param_model.value_desc]);
 						Gtk::Menu* menu(manage(new Gtk::Menu()));
+						menu->signal_hide().connect(sigc::bind(sigc::ptr_fun(&delete_widget), menu));
 						App::get_instance(param_tree_store_->canvas_interface()->get_canvas())->make_param_menu(menu,param_tree_store_->canvas_interface()->get_canvas(),value_desc,0.5f);
 						menu->popup(event->button.button,gtk_get_current_event_time());
 						return true;
 					}
 					Gtk::Menu* menu(manage(new Gtk::Menu()));
+					menu->signal_hide().connect(sigc::bind(sigc::ptr_fun(&delete_widget), menu));
 					std::list<synfigapp::ValueDesc> value_desc_list;
 					ParamDesc param_desc(row[param_model.param_desc]);
 					for(;!layer_list.empty();layer_list.pop_back())
@@ -913,7 +924,8 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 
 			Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
 
-/*			if((event->motion.state&GDK_BUTTON1_MASK ||event->motion.state&GDK_BUTTON3_MASK) && column && cellrenderer_time_track==column->get_first_cell_renderer())
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+			if((event->motion.state&GDK_BUTTON1_MASK ||event->motion.state&GDK_BUTTON3_MASK) && column && cellrenderer_time_track==column->get_first_cell_renderer())
 			{
 				Gdk::Rectangle rect;
 				get_param_tree_view().get_cell_area(path,*column,rect);
@@ -925,7 +937,8 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 				return true;
 			}
 			else
-*/			if(last_tooltip_path.get_depth()<=0 || path!=last_tooltip_path)
+#endif	// TIMETRACK_IN_PARAMS_PANEL
+			if(last_tooltip_path.get_depth()<=0 || path!=last_tooltip_path)
 			{
 				tooltips_.unset_tip(*this);
 				Glib::ustring tooltips_string(row[layer_model.tooltip]);
@@ -956,7 +969,8 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 
 			Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
 
-/*			if(column && cellrenderer_time_track==column->get_first_cell_renderer())
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+			if(column && cellrenderer_time_track==column->get_first_cell_renderer())
 			{
 				Gdk::Rectangle rect;
 				get_param_tree_view().get_cell_area(path,*column,rect);
@@ -968,7 +982,7 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 				return true;
 
 			}
-*/
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 		}
 		break;
 	default:
@@ -977,107 +991,109 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 	return false;
 }
 
-void
-LayerTree::on_raise_pressed()
-{
-	synfigapp::Action::ParamList param_list;
-	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
-	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
-	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
-
-	{
-		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
-		synfigapp::SelectionManager::LayerList::iterator iter;
-
-		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
-			param_list.add("layer",Layer::Handle(*iter));
-	}
-	synfigapp::Action::Handle action(synfigapp::Action::create("layer_raise"));
-	action->set_param_list(param_list);
-	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
-}
-
-void
-LayerTree::on_lower_pressed()
-{
-	synfigapp::Action::ParamList param_list;
-	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
-	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
-	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
-
-	{
-		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
-		synfigapp::SelectionManager::LayerList::iterator iter;
-
-		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
-			param_list.add("layer",Layer::Handle(*iter));
-	}
-
-	synfigapp::Action::Handle action(synfigapp::Action::create("layer_lower"));
-	action->set_param_list(param_list);
-	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
-}
-
-void
-LayerTree::on_duplicate_pressed()
-{
-	synfigapp::Action::ParamList param_list;
-	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
-	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
-	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
-
-	{
-		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
-		synfigapp::SelectionManager::LayerList::iterator iter;
-
-		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
-			param_list.add("layer",Layer::Handle(*iter));
-	}
-
-	synfigapp::Action::Handle action(synfigapp::Action::create("layer_duplicate"));
-	action->set_param_list(param_list);
-	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
-}
-
-void
-LayerTree::on_delete_pressed()
-{
-	synfigapp::Action::ParamList param_list;
-	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
-	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
-	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
-
-	{
-		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
-		synfigapp::SelectionManager::LayerList::iterator iter;
-
-		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
-			param_list.add("layer",Layer::Handle(*iter));
-	}
-
-	synfigapp::Action::Handle action(synfigapp::Action::create("layer_remove"));
-	action->set_param_list(param_list);
-	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
-}
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+// void
+// LayerTree::on_raise_pressed()
+// {
+// 	synfigapp::Action::ParamList param_list;
+// 	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
+// 	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
+// 	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
+//
+// 	{
+// 		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
+// 		synfigapp::SelectionManager::LayerList::iterator iter;
+//
+// 		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
+// 			param_list.add("layer",Layer::Handle(*iter));
+// 	}
+// 	synfigapp::Action::Handle action(synfigapp::Action::create("layer_raise"));
+// 	action->set_param_list(param_list);
+// 	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
+// }
 
+// void
+// LayerTree::on_lower_pressed()
+// {
+// 	synfigapp::Action::ParamList param_list;
+// 	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
+// 	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
+// 	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
+//
+// 	{
+// 		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
+// 		synfigapp::SelectionManager::LayerList::iterator iter;
+//
+// 		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
+// 			param_list.add("layer",Layer::Handle(*iter));
+// 	}
+//
+// 	synfigapp::Action::Handle action(synfigapp::Action::create("layer_lower"));
+// 	action->set_param_list(param_list);
+// 	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
+// }
 
+// void
+// LayerTree::on_duplicate_pressed()
+// {
+// 	synfigapp::Action::ParamList param_list;
+// 	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
+// 	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
+// 	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
+//
+// 	{
+// 		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
+// 		synfigapp::SelectionManager::LayerList::iterator iter;
+//
+// 		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
+// 			param_list.add("layer",Layer::Handle(*iter));
+// 	}
+//
+// 	synfigapp::Action::Handle action(synfigapp::Action::create("layer_duplicate"));
+// 	action->set_param_list(param_list);
+// 	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
+// }
 
+// void
+// LayerTree::on_encapsulate_pressed()
+// {
+// 	synfigapp::Action::ParamList param_list;
+// 	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
+// 	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
+// 	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
+//
+// 	{
+// 		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
+// 		synfigapp::SelectionManager::LayerList::iterator iter;
+//
+// 		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
+// 			param_list.add("layer",Layer::Handle(*iter));
+// 	}
+//
+// 	synfigapp::Action::Handle action(synfigapp::Action::create("layer_encapsulate"));
+// 	action->set_param_list(param_list);
+// 	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
+// }
 
+// void
+// LayerTree::on_delete_pressed()
+// {
+// 	synfigapp::Action::ParamList param_list;
+// 	param_list.add("time",layer_tree_store_->canvas_interface()->get_time());
+// 	param_list.add("canvas",layer_tree_store_->canvas_interface()->get_canvas());
+// 	param_list.add("canvas_interface",layer_tree_store_->canvas_interface());
+//
+// 	{
+// 		synfigapp::SelectionManager::LayerList layer_list(get_selection_manager()->get_selected_layers());
+// 		synfigapp::SelectionManager::LayerList::iterator iter;
+//
+// 		for(iter=layer_list.begin();iter!=layer_list.end();++iter)
+// 			param_list.add("layer",Layer::Handle(*iter));
+// 	}
+//
+// 	synfigapp::Action::Handle action(synfigapp::Action::create("layer_remove"));
+// 	action->set_param_list(param_list);
+// 	layer_tree_store_->canvas_interface()->get_instance()->perform_action(action);
+// }
 
 /*
 void
@@ -1087,24 +1103,19 @@ LayerTree::on_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&context, Gtk::S
 	synfig::info("Dragged data of target \"%s\"",gdk_atom_name(selection_data->target));
 	synfig::info("Dragged selection=\"%s\"",gdk_atom_name(selection_data->selection));
 
-	DEBUGPOINT();
-
 	Gtk::TreeModel::Path path;
 	Gtk::TreeViewColumn *column;
 	int cell_x, cell_y;
 	if(get_selection()
 	Gtk::TreeRow row = *(get_selection()->get_selected());
-	DEBUGPOINT();
 
 	if(synfig::String(gdk_atom_name(selection_data->target))=="LAYER" && (bool)row[model.is_layer])
 	{
-		DEBUGPOINT();
 		Layer* layer(((Layer::Handle)row[model.layer]).get());
 		assert(layer);
 		selection_data.set(8, reinterpret_cast<const guchar*>(&layer), sizeof(layer));
 		return;
 	}
-	DEBUGPOINT();
 }
 
 void
@@ -1135,7 +1146,6 @@ LayerTree::on_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& cont
 
 	Gtk::TreeRow row = *(get_model()->get_iter(path));
 
-
 	if ((selection_data.get_length() >= 0) && (selection_data.get_format() == 8))
 	{
 		if(synfig::String(selection_data.get_data_type())=="LAYER")do
