@@ -2,10 +2,11 @@
 /*!	\file layertree.h
 **	\brief Template Header
 **
-**	$Id: layertree.h 357 2007-03-19 16:09:53Z dooglus $
+**	$Id: layertree.h 1724 2008-02-17 09:06:45Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -46,6 +47,10 @@
 
 /* === M A C R O S ========================================================= */
 
+// comment this out if you don't want the params dialog to have a 'timetrack' column
+// (alternatively, export SYNFIG_DISABLE_PARAMS_PANEL_TIMETRACK=1 in environment at runtime)
+#define TIMETRACK_IN_PARAMS_PANEL
+
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
@@ -100,14 +105,10 @@ private:
 	Gtk::Tooltips tooltips_;
 	Gtk::TreePath last_tooltip_path;
 
-
-
 	Gtk::TreeView* layer_tree_view_;
 
 	Gtk::TreeView* param_tree_view_;
 
-
-
 	Gtk::HBox *hbox;
 
 	Gtk::Adjustment layer_amount_adjustment_;
@@ -122,7 +123,9 @@ private:
 
 	Glib::RefPtr<Gtk::TreeModelSort> sorted_layer_tree_store_;
 
-//	CellRenderer_TimeTrack *cellrenderer_time_track;
+#ifdef TIMETRACK_IN_PARAMS_PANEL
+	CellRenderer_TimeTrack *cellrenderer_time_track;
+#endif	// TIMETRACK_IN_PARAMS_PANEL
 
 	Gtk::TreeView::Column* column_time_track;
 
@@ -138,13 +141,14 @@ private:
 
 	sigc::signal<bool, int, Gtk::TreeRow, ColumnID> signal_param_user_click_;
 
-	sigc::signal<void,synfigapp::ValueDesc,synfig::Waypoint,int> signal_waypoint_clicked_;
+	sigc::signal<void,synfigapp::ValueDesc,std::set<synfig::Waypoint,std::less<synfig::UniqueID> >,int> signal_waypoint_clicked_layertree_;
 
 	bool disable_amount_changed_signal;
 
 	Gtk::Button *button_raise;
 	Gtk::Button *button_lower;
 	Gtk::Button *button_duplicate;
+	Gtk::Button *button_encapsulate;
 	Gtk::Button *button_delete;
 
 	Widget_ValueBase blend_method_widget;
@@ -170,7 +174,7 @@ private:
 
 	void on_layer_toggle(const Glib::ustring& path_string);
 
-	void on_waypoint_clicked(const Glib::ustring &, synfig::Waypoint, int button);
+	void on_waypoint_clicked_layertree(const etl::handle<synfig::Node>& node, const synfig::Time&, const synfig::Time&, int button);
 
 	void on_waypoint_changed( synfig::Waypoint waypoint , synfig::ValueNode::Handle value_node);
 
@@ -188,13 +192,15 @@ private:
 
 public:
 
-	void on_raise_pressed();
+	// void on_raise_pressed();
 
-	void on_lower_pressed();
+	// void on_lower_pressed();
 
-	void on_duplicate_pressed();
+	// void on_duplicate_pressed();
 
-	void on_delete_pressed();
+	// void on_encapsulate_pressed();
+
+	// void on_delete_pressed();
 
 	/*
  -- ** -- P U B L I C   M E T H O D S -----------------------------------------
@@ -234,12 +240,10 @@ public:
 
 	sigc::signal<bool,int, Gtk::TreeRow, ColumnID>& signal_param_user_click() { return signal_param_user_click_; }
 
-	sigc::signal<void,synfigapp::ValueDesc,synfig::Waypoint,int>& signal_waypoint_clicked() { return signal_waypoint_clicked_; }
+	sigc::signal<void,synfigapp::ValueDesc,std::set<synfig::Waypoint,std::less<synfig::UniqueID> >,int>& signal_waypoint_clicked_layertree() { return signal_waypoint_clicked_layertree_; }
 
 	etl::handle<synfigapp::SelectionManager> get_selection_manager() { return layer_tree_store_->canvas_interface()->get_selection_manager(); }
 
-
-
 	void select_layer(synfig::Layer::Handle layer);
 	void select_layers(const LayerList& layer_list);
 	void select_all_children_layers(synfig::Layer::Handle layer);
