@@ -2,10 +2,11 @@
 /*!	\file layertreestore.cpp
 **	\brief Template File
 **
-**	$Id: layertreestore.cpp 815 2007-10-03 02:17:04Z dooglus $
+**	$Id: layertreestore.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -30,18 +31,19 @@
 #endif
 
 #include "layertreestore.h"
-#include "iconcontroler.h"
+#include "iconcontroller.h"
 #include <gtkmm/button.h>
 #include <synfig/paramdesc.h>
 #include <synfigapp/action.h>
 #include <synfigapp/instance.h>
 #include "app.h"
 #include "instance.h"
-#include "iconcontroler.h"
 #include <synfigapp/action_system.h>
 
 #include <gtk/gtkversion.h>
 #include <ETL/clock>
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -96,7 +98,8 @@ LayerTreeStore::LayerTreeStore(etl::loose_handle<synfigapp::CanvasInterface> can
 
 LayerTreeStore::~LayerTreeStore()
 {
-	synfig::info("LayerTreeStore::~LayerTreeStore(): Deleted");
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("LayerTreeStore::~LayerTreeStore(): Deleted");
 }
 
 int
@@ -197,11 +200,7 @@ LayerTreeStore::get_value_vfunc (const Gtk::TreeModel::iterator& iter, int colum
 		Glib::Value<Glib::ustring> x;
 		g_value_init(x.gobj(),x.value_type());
 
-
-		if(!layer->get_description().empty())
-			x.set(layer->get_description());
-		else
-			x.set(layer->get_local_name());
+		x.set(layer->get_non_empty_description());
 
 		g_value_init(value.gobj(),x.value_type());
 		//g_value_copy(x.gobj(),value.gobj());
@@ -578,7 +577,7 @@ LayerTreeStore::drag_data_received_vfunc (const TreeModel::Path& dest, const Gtk
 			*/
 		}
 	}
-	synfig::info("I suposidly moved %d layers",i);
+	synfig::info("I supposedly moved %d layers",i);
 
 	// Reselect the previously selected layers
 	canvas_interface()->get_selection_manager()->set_selected_layers(selected_layer_list);
@@ -896,25 +895,21 @@ LayerTreeStore::on_layer_param_changed(synfig::Layer::Handle handle,synfig::Stri
 	}
 
 	/*
-	//DEBUGPOINT();
 	Gtk::TreeModel::Children::iterator iter;
 	if(find_layer_row(handle,iter))
 	{
-		//DEBUGPOINT();
 		Gtk::TreeModel::Children children(iter->children());
 
 		for(iter = children.begin(); iter && iter != children.end(); ++iter)
 		{
 			if((Glib::ustring)(*iter)[model.param_name]==param_name)
 			{
-				//DEBUGPOINT();
 				Gtk::TreeRow row=*iter;
 				refresh_row(row);
 				return;
 			}
 		}
 	}
-	//DEBUGPOINT();
 	rebuild();
 	*/
 }
@@ -1007,7 +1002,6 @@ LayerTreeStore::find_layer_row_(const synfig::Layer::Handle &layer, synfig::Canv
 		}
 
 		iter=children().end();
-		//DEBUGPOINT();
 		//return false;
 	}
 
