@@ -2,11 +2,11 @@
 /*!	\file gtkmm/main.cpp
 **	\brief Synfig Studio Entrypoint
 **
-**	$Id: main.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: main.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,6 +35,8 @@
 #include "ipc.h"
 #include <stdexcept>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -56,10 +58,21 @@ using namespace studio;
 
 int main(int argc, char **argv)
 {
+
+#ifdef ENABLE_NLS
+	setlocale(LC_ALL, "");
+	bindtextdomain("synfigstudio", LOCALEDIR);
+	textdomain("synfigstudio");
+#endif
+
 	{
 		SmartFILE file(IPC::make_connection());
 		if(file)
 		{
+			cout << endl;
+			cout << "   " << _("synfig studio is already running") << endl << endl;
+			cout << "   " << _("the existing process will be used") << endl << endl;;
+
 			fprintf(file.get(),"F\n");
 
 			// Hey, another copy of us is open!
@@ -80,17 +93,15 @@ int main(int argc, char **argv)
 		}
 	}
 
+	cout << endl;
+	cout << "   " << _("synfig studio -- starting up application...") << endl << endl;
+
 	try
 	{
 		studio::App app(&argc, &argv);
 
 		app.run();
 	}
-	catch(synfig::SoftwareExpired)
-	{
-		cerr<<"FATAL: Software Expired"<<endl;
-		return 39;
-	}
 	catch(int ret)
 	{
 		std::cerr<<"Application shutdown with errors ("<<ret<<')'<<std::endl;
