@@ -2,7 +2,7 @@
 /*!	\file preview.h
 **	\brief Previews an animation
 **
-**	$Id: preview.h 362 2007-03-21 08:42:05Z dooglus $
+**	$Id: preview.h 1242 2007-12-29 04:29:22Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -201,7 +201,7 @@ class Widget_Preview : public Gtk::Table
 	etl::clock	timer;
 
 	//int		curindex; //for later
-	SigC::Connection	timecon;
+	sigc::connection	timecon;
 
 	void slider_move(); //later to be a time_slider that's cooler
 	bool play_update();
