@@ -2,10 +2,11 @@
 /*!	\file renderer_ducks.cpp
 **	\brief Template File
 **
-**	$Id: renderer_ducks.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: renderer_ducks.cpp 1814 2008-02-24 20:50:44Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -38,6 +39,8 @@
 #include <synfig/distance.h>
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -161,11 +164,11 @@ Renderer_Ducks::render_vfunc(
 		// Draw the curve
 /*		if(solid_lines)
 		{
-			gc->set_rgb_fg_color(Gdk::Color("#000000"));
+			gc->set_rgb_fg_color(DUCK_COLOR_BEZIER_1);
 			gc->set_function(Gdk::COPY);
 			gc->set_line_attributes(3,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 			drawable->draw_lines(gc, Glib::ArrayHandle<Gdk::Point>(points));
-			gc->set_rgb_fg_color(Gdk::Color("#afafaf"));
+			gc->set_rgb_fg_color(DUCK_COLOR_BEZIER_2);
 			gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 			drawable->draw_lines(gc, Glib::ArrayHandle<Gdk::Point>(points));
 		}
@@ -176,11 +179,11 @@ Renderer_Ducks::render_vfunc(
 //			gc->set_function(Gdk::INVERT);
 //			gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 //			drawable->draw_lines(gc, Glib::ArrayHandle<Gdk::Point>(points));
-			gc->set_rgb_fg_color(Gdk::Color("#000000"));
+			gc->set_rgb_fg_color(DUCK_COLOR_BEZIER_1);
 			gc->set_function(Gdk::COPY);
 			gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 			drawable->draw_lines(gc, Glib::ArrayHandle<Gdk::Point>(points));
-			gc->set_rgb_fg_color(Gdk::Color("#afafaf"));
+			gc->set_rgb_fg_color(DUCK_COLOR_BEZIER_2);
 			gc->set_line_attributes(1,Gdk::LINE_ON_OFF_DASH,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 			drawable->draw_lines(gc, Glib::ArrayHandle<Gdk::Point>(points));
 
@@ -206,8 +209,20 @@ Renderer_Ducks::render_vfunc(
 
 //		Real x,y;
 	//	Gdk::Rectangle area;
-		Point point((*iter)->get_trans_point());
-		Point origin((*iter)->get_trans_origin());
+		Point sub_trans_point((*iter)->get_sub_trans_point());
+		Point sub_trans_origin((*iter)->get_sub_trans_origin());
+
+		if (App::restrict_radius_ducks &&
+			(*iter)->is_radius())
+		{
+			if (sub_trans_point[0] < sub_trans_origin[0])
+				sub_trans_point[0] = sub_trans_origin[0];
+			if (sub_trans_point[1] < sub_trans_origin[1])
+				sub_trans_point[1] = sub_trans_origin[1];
+		}
+
+		Point point((*iter)->get_transform_stack().perform(sub_trans_point));
+		Point origin((*iter)->get_transform_stack().perform(sub_trans_origin));
 
 		point[0]=(point[0]-window_startx)/pw;
 		point[1]=(point[1]-window_starty)/ph;
@@ -226,9 +241,8 @@ Renderer_Ducks::render_vfunc(
 		origin[0]=(origin[0]-window_startx)/pw;
 		origin[1]=(origin[1]-window_starty)/ph;
 
-
 		bool selected(get_work_area()->duck_is_selected(*iter));
-		bool hover(*iter==hover_duck);
+		bool hover(*iter==hover_duck || (*iter)->get_hover());
 
 		shadow = selected?Gtk::SHADOW_IN:Gtk::SHADOW_OUT;
 
@@ -238,7 +252,7 @@ Renderer_Ducks::render_vfunc(
 			if(value_desc.is_valid() && value_desc.is_value_node() && get_work_area()->get_selected_value_node()==value_desc.get_value_node())
 			{
 				gc->set_function(Gdk::COPY);
-				gc->set_rgb_fg_color(Gdk::Color("#FF0000"));
+				gc->set_rgb_fg_color(DUCK_COLOR_SELECTED);
 				//gc->set_line_attributes(1,Gdk::LINE_ON_OFF_DASH,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 				gc->set_line_attributes(2,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 
@@ -260,7 +274,7 @@ Renderer_Ducks::render_vfunc(
 			Point tl(min(point[0],boxpoint[0]),min(point[1],boxpoint[1]));
 
 			gc->set_function(Gdk::COPY);
-			gc->set_rgb_fg_color(Gdk::Color("#FFFFFF"));
+			gc->set_rgb_fg_color(DUCK_COLOR_BOX_1);
 			gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 			drawable->draw_rectangle(gc,false,
 				round_to_int(tl[0]),
@@ -269,7 +283,7 @@ Renderer_Ducks::render_vfunc(
 				round_to_int(abs(boxpoint[1]-point[1]))
 			);
 			gc->set_function(Gdk::COPY);
-			gc->set_rgb_fg_color(Gdk::Color("#000000"));
+			gc->set_rgb_fg_color(DUCK_COLOR_BOX_2);
 			gc->set_line_attributes(1,Gdk::LINE_ON_OFF_DASH,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
 			drawable->draw_rectangle(gc,false,
 				round_to_int(tl[0]),
@@ -285,19 +299,19 @@ Renderer_Ducks::render_vfunc(
 		screen_duck.hover=hover;
 
 		if(!(*iter)->get_editable())
-			screen_duck.color=(Gdk::Color("#cfcfcf"));
+			screen_duck.color=(DUCK_COLOR_NOT_EDITABLE);
 		else if((*iter)->get_tangent())
-			screen_duck.color=((*iter)->get_scalar()<0?Gdk::Color("#ffff00"):Gdk::Color("#ff0000"));
+			screen_duck.color=((*iter)->get_scalar()<0 ? DUCK_COLOR_TANGENT_1 : DUCK_COLOR_TANGENT_2);
 		else if((*iter)->get_type()&Duck::TYPE_VERTEX)
-			screen_duck.color=Gdk::Color("#ff7f00");
+			screen_duck.color=DUCK_COLOR_VERTEX;
 		else if((*iter)->get_type()&Duck::TYPE_RADIUS)
-			screen_duck.color=Gdk::Color("#00ffff");
+			screen_duck.color=DUCK_COLOR_RADIUS;
 		else if((*iter)->get_type()&Duck::TYPE_WIDTH)
-			screen_duck.color=Gdk::Color("#ff00ff");
+			screen_duck.color=DUCK_COLOR_WIDTH;
 		else if((*iter)->get_type()&Duck::TYPE_ANGLE)
-			screen_duck.color=(Gdk::Color("#0000ff"));
+			screen_duck.color=(DUCK_COLOR_ANGLE);
 		else
-			screen_duck.color=Gdk::Color("#00ff00");
+			screen_duck.color=DUCK_COLOR_OTHER;
 
 		screen_duck_list.push_front(screen_duck);
 
@@ -306,11 +320,11 @@ Renderer_Ducks::render_vfunc(
 			if(solid_lines)
 			{
 				gc->set_line_attributes(3,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
-				gc->set_rgb_fg_color(Gdk::Color("#000000"));
+				gc->set_rgb_fg_color(DUCK_COLOR_CONNECT_OUTSIDE);
 				gc->set_function(Gdk::COPY);
 				drawable->draw_line(gc, (int)origin[0],(int)origin[1],(int)(point[0]),(int)(point[1]));
 				gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
-				gc->set_rgb_fg_color(Gdk::Color("#9fefef"));
+				gc->set_rgb_fg_color(DUCK_COLOR_CONNECT_INSIDE);
 				drawable->draw_line(gc, (int)origin[0],(int)origin[1],(int)(point[0]),(int)(point[1]));
 			}
 			else
@@ -319,11 +333,11 @@ Renderer_Ducks::render_vfunc(
 //				gc->set_function(Gdk::INVERT);
 //				drawable->draw_line(gc, (int)origin[0],(int)origin[1],(int)(point[0]),(int)(point[1]));
 				gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
-				gc->set_rgb_fg_color(Gdk::Color("#000000"));
+				gc->set_rgb_fg_color(DUCK_COLOR_CONNECT_OUTSIDE);
 				gc->set_function(Gdk::COPY);
 				drawable->draw_line(gc, (int)origin[0],(int)origin[1],(int)(point[0]),(int)(point[1]));
 				gc->set_line_attributes(1,Gdk::LINE_ON_OFF_DASH,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
-				gc->set_rgb_fg_color(Gdk::Color("#9fefef"));
+				gc->set_rgb_fg_color(DUCK_COLOR_CONNECT_INSIDE);
 				drawable->draw_line(gc, (int)origin[0],(int)origin[1],(int)(point[0]),(int)(point[1]));
 			}
 		}
@@ -372,18 +386,37 @@ Renderer_Ducks::render_vfunc(
 
 			if(hover)
 			{
-				Distance real_mag(((*iter)->get_trans_point()-(*iter)->get_trans_origin()).mag(),Distance::SYSTEM_UNITS);
+				Real mag;
+				if (App::restrict_radius_ducks)
+				{
+					Point sub_trans_point((*iter)->get_sub_trans_point());
+					Point sub_trans_origin((*iter)->get_sub_trans_origin());
+
+					if (sub_trans_point[0] < sub_trans_origin[0])
+						sub_trans_point[0] = sub_trans_origin[0];
+					if (sub_trans_point[1] < sub_trans_origin[1])
+						sub_trans_point[1] = sub_trans_origin[1];
+
+					Point point((*iter)->get_transform_stack().perform(sub_trans_point));
+					Point origin((*iter)->get_transform_stack().perform(sub_trans_origin));
+
+					mag = (point-origin).mag();
+				}
+				else
+					mag = ((*iter)->get_trans_point()-(*iter)->get_trans_origin()).mag();
+
+				Distance real_mag(mag, Distance::SYSTEM_UNITS);
 				real_mag.convert(App::distance_system,get_work_area()->get_rend_desc());
 				layout->set_text(real_mag.get_string());
 
-				gc->set_rgb_fg_color(Gdk::Color("#000000"));
+				gc->set_rgb_fg_color(DUCK_COLOR_WIDTH_TEXT_1);
 				drawable->draw_layout(
 					gc,
 					round_to_int(point[0])+1+6,
 					round_to_int(point[1])+1-8,
 					layout
 				);
-				gc->set_rgb_fg_color(Gdk::Color("#FF00FF"));
+				gc->set_rgb_fg_color(DUCK_COLOR_WIDTH_TEXT_2);
 				drawable->draw_layout(
 					gc,
 					round_to_int(point[0])+6,
@@ -424,7 +457,7 @@ Renderer_Ducks::render_vfunc(
 
 		gc->set_function(Gdk::COPY);
 		gc->set_line_attributes(1,Gdk::LINE_SOLID,Gdk::CAP_BUTT,Gdk::JOIN_MITER);
-		gc->set_rgb_fg_color(Gdk::Color("#000000"));
+		gc->set_rgb_fg_color(DUCK_COLOR_OUTLINE);
 		drawable->draw_arc(
 			gc,
 			true,
