@@ -2,7 +2,7 @@
 /*!	\file state_gradient.cpp
 **	\brief Template File
 **
-**	$Id: state_gradient.cpp 680 2007-09-16 19:28:39Z dooglus $
+**	$Id: state_gradient.cpp 1491 2008-01-25 18:11:04Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,6 +51,8 @@
 #include "widget_enum.h"
 #include <synfigapp/main.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -214,7 +216,10 @@ StateGradient_Context::increment_id()
 	if(id[id.size()-1]<='9' && id[id.size()-1]>='0')
 	{
 		// figure out how many digits it is
-		for(digits=0;(int)id.size()-1>=digits && id[id.size()-1-digits]<='9' && id[id.size()-1-digits]>='0';digits++)while(false);
+		for (digits = 0;
+			 (int)id.size()-1 >= digits && id[id.size()-1-digits] <= '9' && id[id.size()-1-digits] >= '0';
+			 digits++)
+			;
 
 		String str_number;
 		str_number=String(id,id.size()-digits,id.size());
