@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file state_zoom.cpp
-**	\brief Zoom Toole Implementation File
+**	\brief Zoom Tool Implementation File
 **
-**	$Id: state_zoom.cpp 672 2007-09-14 22:34:53Z dooglus $
+**	$Id: state_zoom.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,6 +45,8 @@
 #include "toolbox.h"
 #include <synfigapp/main.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
