@@ -2,11 +2,11 @@
 /*!	\file toolbox.cpp
 **	\brief writeme
 **
-**	$Id: toolbox.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: toolbox.cpp 1737 2008-02-17 16:46:58Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -79,13 +79,15 @@
 
 #include <synfigapp/main.h>
 
+#include "general.h"
+
 #endif
 
 using namespace std;
 using namespace etl;
 using namespace synfig;
 using namespace studio;
-using namespace SigC;
+using namespace sigc;
 
 /* === M A C R O S ========================================================= */
 
@@ -128,7 +130,7 @@ save_selected_instance()
 {
 	if(!studio::App::get_selected_instance())
 	{
-		App::dialog_error_blocking("Cannot save","Nothing to save");
+		App::dialog_error_blocking(_("Cannot save"),_("Nothing to save"));
 		return;
 	}
 
@@ -140,7 +142,7 @@ save_as_selected_instance()
 {
 	if(!studio::App::get_selected_instance())
 	{
-		App::dialog_error_blocking("Cannot save as","Nothing to save");
+		App::dialog_error_blocking(_("Cannot save as"),_("Nothing to save"));
 		return;
 	}
 
@@ -162,7 +164,7 @@ close_selected_instance()
 
 	if(!instance)
 	{
-		App::dialog_error_blocking("Cannot close","Nothing to close");
+		App::dialog_error_blocking(_("Cannot close"),_("Nothing to close"));
 		return;
 	}
 
@@ -215,26 +217,26 @@ Toolbox::Toolbox():
 
 	dock_dialogs=manage(new class Gtk::Menu());
 
-	dock_dialogs->items().push_back(Gtk::Menu_Helpers::MenuElem("Canvases, History",sigc::ptr_fun(_create_stock_dialog1)));
-	dock_dialogs->items().push_back(Gtk::Menu_Helpers::MenuElem("Layers, Children, Params",sigc::ptr_fun(_create_stock_dialog2)));
+	dock_dialogs->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Vertical Dock: Canvases, History"),sigc::ptr_fun(_create_stock_dialog1)));
+	dock_dialogs->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Horizontal Dock: Layers, Children, Params"),sigc::ptr_fun(_create_stock_dialog2)));
 	dock_dialogs->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
-	dock_dialogs->items().push_back(Gtk::Menu_Helpers::MenuElem("Reset Windows to Original Layout",sigc::ptr_fun(App::reset_initial_window_configuration)));
+	dock_dialogs->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Reset Windows to Original Layout"),sigc::ptr_fun(App::reset_initial_window_configuration)));
 	dock_dialogs->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
 
 
 	filemenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::NEW,
 		sigc::ptr_fun(&studio::App::new_instance)));
 	filemenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::OPEN,
-		sigc::ptr_fun(&studio::App::dialog_open)));
+		sigc::bind(sigc::ptr_fun(&studio::App::dialog_open), "")));
 
 	filemenu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Open Recent"),*recent_files_menu));
 
 	filemenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::StockID("synfig-saveall"),
-		sigc::ptr_fun(&studio::App::dialog_not_implemented)));
+		sigc::ptr_fun(save_all)));
 	filemenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::CLOSE,
 		sigc::ptr_fun(close_selected_instance)));
 	filemenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
-	filemenu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Dialogs"),*dock_dialogs));
+	filemenu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Panels"),*dock_dialogs));
 
 	//filemenu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Canvas Browser..."),
 	//	sigc::mem_fun(studio::App::show_comp_view)));
@@ -255,34 +257,51 @@ Toolbox::Toolbox():
 	filemenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::StockID(Gtk::Stock::QUIT),
 		sigc::ptr_fun(studio::App::quit)));
 
+#define WIKI(title,page)											\
+	helpmenu->items().push_back(Gtk::Menu_Helpers::MenuElem(title,	\
+		sigc::bind(sigc::ptr_fun(&studio::App::open_url),String("http://synfig.org")+page)))
+
 	Gtk::Menu	*helpmenu = manage(new class Gtk::Menu());
-	helpmenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::HELP,
-		sigc::ptr_fun(studio::App::dialog_not_implemented)));
+	helpmenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::HELP, sigc::ptr_fun(studio::App::dialog_help)));
+	helpmenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
+
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Synfig Wiki"),				/* TRANSLATORS: a wiki page */ _("/Main_Page")				);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Tutorials"),					/* TRANSLATORS: a wiki page */ _("/Tutorials")				);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Frequently Asked Questions"),/* TRANSLATORS: a wiki page */ _("/FAQ")					);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Get Support"),				/* TRANSLATORS: a wiki page */ _("/Communication")			);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Keyboard Shortcuts"),		/* TRANSLATORS: a wiki page */ _("/Keyboard_Shortcuts")		);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("Mouse Shortcuts"),			/* TRANSLATORS: a wiki page */ _("/Mouse_Shortcuts")		);
+	/* TRANSLATORS: Help menu entry */ WIKI(_("All Pages"),					/* TRANSLATORS: a wiki page */ _("/Special:Allpages")		);
+
 	helpmenu->items().push_back(Gtk::Menu_Helpers::SeparatorElem());
 	helpmenu->items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::StockID("synfig-about"),
 		sigc::ptr_fun(studio::App::dialog_about)));
 
 	Gtk::MenuBar *menubar1 = manage(new class Gtk::MenuBar());
-	menubar1->items().push_back(Gtk::Menu_Helpers::MenuElem("_File",*filemenu));
-	menubar1->items().push_back(Gtk::Menu_Helpers::MenuElem("_Help",*helpmenu));
+	menubar1->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_File"),*filemenu));
+	menubar1->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_Help"),*helpmenu));
 
 
 	menubar1->show();
 
 	Gtk::Image *icon;
 
-	ADD_TOOLBOX_BUTTON(button_new,"gtk-new","New...");
-	ADD_TOOLBOX_BUTTON(button_open,"gtk-open","Open...");
-	ADD_TOOLBOX_BUTTON(button_save,"gtk-save","Save");
-	ADD_TOOLBOX_BUTTON(button_saveas,"gtk-save-as","Save as...");
-	ADD_TOOLBOX_BUTTON(button_save_all,"synfig-saveall","Save All");
-	TOOLBOX_BUTTON(button_undo,"gtk-undo","Undo");
-	TOOLBOX_BUTTON(button_redo,"gtk-redo","Redo");
-	ADD_TOOLBOX_BUTTON(button_about,"synfig-about","About Synfig Studio");
+	ADD_TOOLBOX_BUTTON(button_new,"gtk-new",_("New..."));
+	ADD_TOOLBOX_BUTTON(button_open,"gtk-open",_("Open..."));
+	ADD_TOOLBOX_BUTTON(button_save,"gtk-save",_("Save"));
+	ADD_TOOLBOX_BUTTON(button_saveas,"gtk-save-as",_("Save As..."));
+	ADD_TOOLBOX_BUTTON(button_save_all,"synfig-saveall",_("Save All"));
+	TOOLBOX_BUTTON(button_undo,"gtk-undo",_("Undo"));
+	TOOLBOX_BUTTON(button_redo,"gtk-redo",_("Redo"));
+	ADD_TOOLBOX_BUTTON(button_setup,"gtk-properties",_("Setup"));
+	ADD_TOOLBOX_BUTTON(button_about,"synfig-about",_("About Synfig Studio"));
+	ADD_TOOLBOX_BUTTON(button_help,"gtk-help",_("Help"));
 
+	button_setup->signal_clicked().connect(sigc::ptr_fun(studio::App::show_setup));
 	button_about->signal_clicked().connect(sigc::ptr_fun(studio::App::dialog_about));
+	button_help->signal_clicked().connect(sigc::ptr_fun(studio::App::dialog_help));
 	button_new->signal_clicked().connect(sigc::ptr_fun(studio::App::new_instance));
-	button_open->signal_clicked().connect(sigc::ptr_fun(studio::App::dialog_open));
+	button_open->signal_clicked().connect(sigc::bind(sigc::ptr_fun(studio::App::dialog_open), ""));
 	button_save->signal_clicked().connect(sigc::ptr_fun(save_selected_instance));
 	button_saveas->signal_clicked().connect(sigc::ptr_fun(save_as_selected_instance));
 	button_save_all->signal_clicked().connect(sigc::ptr_fun(save_all));
@@ -290,21 +309,23 @@ Toolbox::Toolbox():
 	button_redo->signal_clicked().connect(sigc::ptr_fun(studio::App::redo));
 
 	// Create the file button cluster
-	Gtk::Table *file_buttons=manage(new class Gtk::Table(4, 4, false));
+	Gtk::Table *file_buttons=manage(new class Gtk::Table());
 
 	file_buttons->attach(*button_new,      0,1, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	file_buttons->attach(*button_open,     1,2, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	file_buttons->attach(*button_save,     2,3, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	file_buttons->attach(*button_saveas,   3,4, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_save_all, 4,5, 0,1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 
-	file_buttons->attach(*button_save_all, 0,1, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_undo,     1,2, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
-	file_buttons->attach(*button_redo,     2,3, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_undo,     0,1, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_redo,     1,2, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_setup,    2,3, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	file_buttons->attach(*button_about,    3,4, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+	file_buttons->attach(*button_help,     4,5, 1,2, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 
 	file_buttons->show();
 
-	tool_table=manage(new class Gtk::Table(4, 4, false));
+	tool_table=manage(new class Gtk::Table());
 	tool_table->show();
 	Gtk::HandleBox* handle_tools(manage(new Gtk::HandleBox()));
 	handle_tools->add(*tool_table);
@@ -335,7 +356,7 @@ Toolbox::Toolbox():
 
 	// Set the parameters for this window
 	add(*table1);
-	set_title("Synfig Studio");
+	set_title(_("Synfig Studio"));
 	set_modal(false);
 	property_window_position().set_value(Gtk::WIN_POS_NONE);
 	signal_delete_event().connect(sigc::ptr_fun(App::shutdown_request));
@@ -377,7 +398,7 @@ Toolbox::Toolbox():
 Toolbox::~Toolbox()
 {
 	hide();
-	//studio::App::cb.task("Toolbox: I was nailed!");
+	//studio::App::cb.task(_("Toolbox: I was nailed!"));
 	//studio::App::quit();
 
 	if(studio::App::toolbox==this)
@@ -386,7 +407,7 @@ Toolbox::~Toolbox()
 }
 
 void
-Toolbox::set_active_state(const String& statename)
+Toolbox::set_active_state(const synfig::String& statename)
 {
 	std::map<synfig::String,Gtk::ToggleButton *>::iterator iter;
 
@@ -495,8 +516,8 @@ Toolbox::add_state(const Smach::state_base *state)
 	icon->show();
 	button->show();
 
-	int row=state_button_map.size()/4;
-	int col=state_button_map.size()%4;
+	int row=state_button_map.size()/5;
+	int col=state_button_map.size()%5;
 
 	tool_table->attach(*button,col,col+1,row,row+1, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 
@@ -588,8 +609,8 @@ Toolbox::on_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& contex
 	{
 		synfig::String selection_data((gchar *)(selection_data_.get_data()));
 
-		// For some reason, GTK hands us a list of URL's seperated
-		// by not only Carrage-Returns, but also Line-Feeds.
+		// For some reason, GTK hands us a list of URLs separated
+		// by not only Carriage-Returns, but also Line-Feeds.
 		// Line-Feeds will mess us up. Remove all the line-feeds.
 		while(selection_data.find_first_of('\r')!=synfig::String::npos)
 			selection_data.erase(selection_data.begin()+selection_data.find_first_of('\r'));
