@@ -2,7 +2,7 @@
 /*!	\file valuelink.h
 **	\brief ValueBase Link Header
 **
-**	$Id: valuelink.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuelink.h 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -45,7 +45,7 @@ class ValueBaseLink : public synfig::LinkableValueNode
 
 protected:
 	//stuff I don't want
-	virtual bool set_link_vfunc(int i,synfig::ValueNode::Handle x) {return false;}
+	virtual bool set_link_vfunc(int /*i*/,synfig::ValueNode::Handle /*x*/) {return false;}
 	virtual LinkableValueNode* create_new()const {return 0;}
 
 	//new stuff I need
