@@ -2,7 +2,7 @@
 /*!	\file widget_compselect.cpp
 **	\brief Template File
 **
-**	$Id: widget_compselect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_compselect.cpp 1491 2008-01-25 18:11:04Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -35,6 +35,8 @@
 #include <synfig/valuenode.h>
 #include "instance.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -96,7 +98,8 @@ Widget_CompSelect::set_selected_instance(etl::loose_handle<studio::Instance> x)
 	if(x)
 	{
 		int i;
-		for(i=0,iter=studio::App::instance_list.begin();iter!=studio::App::instance_list.end() && ((*iter)!=x);iter++,i++);
+		for(i=0,iter=studio::App::instance_list.begin();iter!=studio::App::instance_list.end() && ((*iter)!=x);iter++,i++)
+			;
 
 		assert(*iter==x);
 
@@ -138,7 +141,6 @@ Widget_CompSelect::new_instance(etl::handle<studio::Instance> instance)
 void
 Widget_CompSelect::delete_instance(etl::handle<studio::Instance> instance)
 {
-	DEBUGPOINT();
 	refresh();
 
 	if(selected_instance==instance)
