@@ -2,7 +2,7 @@
 /*!	\file widget_defaults.cpp
 **	\brief Template File
 **
-**	$Id: widget_defaults.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: widget_defaults.cpp 1732 2008-02-17 12:18:42Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -43,6 +43,8 @@
 #include "widget_distance.h"
 #include "widget_enum.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -168,13 +170,15 @@ public:
 				{
 					Distance dist(synfigapp::Main::get_bline_width());
 
-					if(event->scroll.direction==GDK_SCROLL_UP)
-					{
-						dist+=DEFAULT_INCREMENT;
-					}
-					else if(event->scroll.direction==GDK_SCROLL_DOWN)
-					{
-						dist-=DEFAULT_INCREMENT;
+					switch(event->scroll.direction){
+						case GDK_SCROLL_UP:
+						case GDK_SCROLL_RIGHT:
+							dist+=DEFAULT_INCREMENT;
+						break;
+						case GDK_SCROLL_DOWN:
+						case GDK_SCROLL_LEFT:
+							dist-=DEFAULT_INCREMENT;
+						break;
 					}
 					synfigapp::Main::set_bline_width(dist);
 					return true;
@@ -280,10 +284,10 @@ Widget_Defaults::Widget_Defaults()
 	widget_interpolation->set_param_desc(
 		ParamDesc("interpolation")
 			.set_hint("enum")
-			.add_enum_value(INTERPOLATION_TCB,"auto",_("TCB"))
-			.add_enum_value(INTERPOLATION_CONSTANT,"constant",_("Constant"))
-			.add_enum_value(INTERPOLATION_HALT,"ease",_("Ease in/out"))
-			.add_enum_value(INTERPOLATION_LINEAR,"linear",_("Linear"))
+			.add_enum_value(INTERPOLATION_TCB,"auto",_("_TCB"))
+			.add_enum_value(INTERPOLATION_CONSTANT,"constant",_("_Constant"))
+			.add_enum_value(INTERPOLATION_HALT,"ease",_("_Ease In/Out"))
+			.add_enum_value(INTERPOLATION_LINEAR,"linear",_("_Linear"))
 	);
 	attach(*widget_interpolation,0, 2, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, 1, 1);
 	tooltips_.set_tip(*widget_interpolation,_("Default Interpolation"));
