@@ -2,7 +2,7 @@
 /*!	\file widget_distance.cpp
 **	\brief Template File
 **
-**	$Id: widget_distance.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_distance.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -34,6 +34,8 @@
 #include "widget_distance.h"
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -45,10 +47,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#if ! defined(_)
-#define _(x)	(x)
-#endif
-
 /* === G L O B A L S ======================================================= */
 
 /* === P R O C E D U R E S ================================================= */
