@@ -2,10 +2,11 @@
 /*!	\file widget_filename.cpp
 **	\brief Template File
 **
-**	$Id: widget_filename.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_filename.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -34,6 +35,8 @@
 #include "widget_filename.h"
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -45,10 +48,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#if ! defined(_)
-#define _(x)	(x)
-#endif
-
 /* === G L O B A L S ======================================================= */
 
 /* === P R O C E D U R E S ================================================= */
@@ -82,7 +81,7 @@ Widget_Filename::set_has_frame(bool x)
 
 
 void
-Widget_Filename::set_value(const string &data)
+Widget_Filename::set_value(const std::string &data)
 {
 	entry_filename->set_text(data);
 }
@@ -112,6 +111,6 @@ Widget_Filename::on_button_choose_pressed()
 	string filename=entry_filename->get_text();
 	if(filename.empty())
 		filename=".";
-	if(App::dialog_open_file(_("Choose File"),filename))
+	if(App::dialog_open_file(_("Choose File"), filename, MISC_DIR_PREFERENCE))
 		entry_filename->set_text(filename);
 }
