@@ -2,7 +2,7 @@
 /*!	\file widget_gradient.cpp
 **	\brief Template File
 **
-**	$Id: widget_gradient.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: widget_gradient.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -36,6 +36,8 @@
 #include <synfig/exception.h>
 #include <ETL/misc>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -212,6 +214,7 @@ void
 Widget_Gradient::popup_menu(float x)
 {
 	Gtk::Menu* menu(manage(new Gtk::Menu()));
+	menu->signal_hide().connect(sigc::bind(sigc::ptr_fun(&delete_widget), menu));
 
 	menu->items().clear();
 
