@@ -2,10 +2,11 @@
 /*!	\file widget_time.cpp
 **	\brief Template File
 **
-**	$Id: widget_time.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_time.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -34,6 +35,8 @@
 #include "widget_time.h"
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -45,10 +48,6 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
-#if ! defined(_)
-#define _(x)	(x)
-#endif
-
 /* === G L O B A L S ======================================================= */
 
 /* === P R O C E D U R E S ================================================= */
@@ -135,6 +134,12 @@ Widget_Time::on_event(GdkEvent* event)
 		}
 		return true;
 		break;
+	case GDK_BUTTON_PRESS:
+	case GDK_2BUTTON_PRESS:
+	case GDK_3BUTTON_PRESS:
+		if (!has_focus())
+			grab_focus();
+		break;
 	default:
 		break;
 	}
@@ -153,6 +158,9 @@ Widget_Time::on_focus_out_event(GdkEventFocus* event)
 bool
 Widget_Time::on_focus_in_event(GdkEventFocus* event)
 {
-	set_text(time_.get_string(fps_,App::get_time_format()|Time::FORMAT_FULL));
+	// if defined, show the full time format "0h 0m 5s 0f" when the time widget gets focus
+	if (getenv("SYNFIG_SHOW_FULL_TIME_ON_FOCUS"))
+		set_text(time_.get_string(fps_,App::get_time_format()|Time::FORMAT_FULL));
+
 	return Gtk::Entry::on_focus_in_event(event);
 }
