@@ -2,7 +2,7 @@
 /*!	\file widget_value.cpp
 **	\brief Template File
 **
-**	$Id: widget_value.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_value.cpp 1338 2008-01-12 17:49:10Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -49,6 +49,8 @@
 #include "app.h"
 #include "widget_distance.h"
 
+#include "general.h"
+
 #endif
 
 using namespace synfig;
@@ -147,7 +149,6 @@ Widget_ValueBase::~Widget_ValueBase()
 void
 Widget_ValueBase::activate()
 {
-	//DEBUGPOINT();
 	signal_activate()();
 }
 
