@@ -2,7 +2,7 @@
 /*!	\file widget_vector.cpp
 **	\brief Template File
 **
-**	$Id: widget_vector.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_vector.cpp 1205 2007-12-17 09:43:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -34,6 +34,8 @@
 #include "widget_distance.h"
 #include "app.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -200,7 +202,7 @@ Widget_Vector::on_value_changed()
 }
 
 void
-Widget_Vector::set_canvas(Canvas::LooseHandle x)
+Widget_Vector::set_canvas(synfig::Canvas::LooseHandle x)
 {
 	canvas_=x;
 	if(x)
