@@ -2,10 +2,11 @@
 /*!	\file widget_waypoint.cpp
 **	\brief Template Header
 **
-**	$Id: widget_waypoint.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: widget_waypoint.cpp 1685 2008-02-13 01:58:21Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -43,6 +44,8 @@
 #include <gtkmm/optionmenu.h>
 #include "widget_time.h"
 #include "widget_waypoint.h"
+#include "general.h"
+
 #endif
 
 using namespace synfig;
@@ -134,6 +137,7 @@ Widget_Waypoint::Widget_Waypoint(etl::handle<synfig::Canvas> canvas):
 	waypointValueLabel->set_mnemonic_widget(*value_widget);
 	waypointTable->attach(*waypointValueLabel, 0, 1, 0, 1, Gtk::SHRINK | Gtk::FILL, Gtk::EXPAND | Gtk::FILL, 0, 0);
 	waypointTable->attach(*value_widget, 1, 2, 0, 1, Gtk::EXPAND | Gtk::FILL, Gtk::EXPAND | Gtk::FILL, 0, 0);
+	waypointTable->attach(*value_node_label, 1, 2, 0, 1, Gtk::EXPAND | Gtk::FILL, Gtk::EXPAND | Gtk::FILL, 0, 0);
 
 	Gtk::Label *waypointTimeLabel = manage(new Gtk::Label(_("_Time"), true));
 	waypointTimeLabel->set_alignment(0, 0.5);
@@ -232,7 +236,7 @@ Widget_Waypoint::set_waypoint(synfig::Waypoint &x)
 
 	waypoint=x;
 
-#warning This really needs to be fixed to support value node waypoints!
+	//! \todo This really needs to be fixed to support value node waypoints!
 	if(waypoint.is_static())
 	{
 		value_widget->set_value(waypoint.get_value());
@@ -259,9 +263,10 @@ Widget_Waypoint::set_waypoint(synfig::Waypoint &x)
 const synfig::Waypoint &
 Widget_Waypoint::get_waypoint()const
 {
-#warning This too!
+	//! \todo This too!
 	waypoint.set_time(time_widget->get_value());
-	waypoint.set_value(value_widget->get_value());
+	if(waypoint.is_static())
+		waypoint.set_value(value_widget->get_value());
 	//int i;
 
 	waypoint.set_before((synfig::Waypoint::Interpolation)before->get_history());
