@@ -2,12 +2,12 @@
 /*!	\file workarea.cpp
 **	\brief Template Header
 **
-**	$Id: workarea.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: workarea.cpp 1801 2008-02-23 01:25:23Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright 2006 Yue Shi Lai
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2006 Yue Shi Lai
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -72,6 +72,8 @@
 
 #include <synfig/mutex.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -169,8 +171,9 @@ public:
 		set_clipping(true);
 		if(low_res)
 		{
-			set_tile_w(workarea->tile_w/2);
-			set_tile_h(workarea->tile_h/2);
+			int div = workarea->get_low_res_pixel_size();
+			set_tile_w(workarea->tile_w/div);
+			set_tile_h(workarea->tile_h/div);
 		}
 		else
 		{
@@ -190,8 +193,10 @@ public:
 	{
 		assert(workarea);
 		newdesc->set_flags(RendDesc::PX_ASPECT|RendDesc::IM_SPAN);
-		if(low_res)
-			newdesc->set_wh(w/2,h/2);
+		if(low_res) {
+			int div = workarea->get_low_res_pixel_size();
+			newdesc->set_wh(w/div,h/div);
+		}
 		else
 			newdesc->set_wh(w,h);
 
@@ -303,7 +308,10 @@ public:
 			int w(get_tile_w());
 			int h(get_tile_h());
 			int x(surface.get_w()*surface.get_h());
-			//if(low_res) { w/=2,h/=2; }
+			//if(low_res) {
+			//	int div = workarea->get_low_res_pixel_size();
+			//	w/=div,h/=div;
+			//}
 			Color dark(0.6,0.6,0.6);
 			Color lite(0.8,0.8,0.8);
 			for(int i=0;i<x;i++)
@@ -343,9 +351,10 @@ public:
 		if(low_res)
 		{
 			// We need to scale up
+			int div = workarea->get_low_res_pixel_size();
 			pixbuf=pixbuf->scale_simple(
-				surface.get_w()*2,
-				surface.get_h()*2,
+				surface.get_w()*div,
+				surface.get_h()*div,
 				Gdk::INTERP_NEAREST
 			);
 		}
@@ -466,7 +475,10 @@ public:
 		assert(workarea);
 		newdesc->set_flags(RendDesc::PX_ASPECT|RendDesc::IM_SPAN);
 		if(low_res)
-			newdesc->set_wh(w/2,h/2);
+		{
+			int div = workarea->get_low_res_pixel_size();
+			newdesc->set_wh(w/div,h/div);
+		}
 		else
 			newdesc->set_wh(w,h);
 
@@ -542,15 +554,19 @@ public:
 			int w(surface.get_w());
 			//int h(surface.get_h());
 			int x(surface.get_w()*surface.get_h());
-			//if(low_res) { w/=2,h/=2; }
+			//if(low_res) {
+			//	int div = workarea->get_low_res_pixel_size();
+			//	w/=div,h/=div;
+			//}
 			Color dark(0.6,0.6,0.6);
 			Color lite(0.8,0.8,0.8);
 			int tw=workarea->tile_w;
 			int th=workarea->tile_h;
 			if(low_res)
 			{
-				tw/=2;
-				th/=2;
+				int div = workarea->get_low_res_pixel_size();
+				tw/=div;
+				th/=div;
 			}
 			for(int i=0;i<x;i++)
 				dest=Color2PixelFormat(
@@ -581,9 +597,10 @@ public:
 		if(low_res)
 		{
 			// We need to scale up
+			int div = workarea->get_low_res_pixel_size();
 			pixbuf=pixbuf->scale_simple(
-				surface.get_w()*2,
-				surface.get_h()*2,
+				surface.get_w()*div,
+				surface.get_h()*div,
 				Gdk::INTERP_NEAREST
 			);
 		}
@@ -628,14 +645,14 @@ WorkArea::WorkArea(etl::loose_handle<synfigapp::CanvasInterface> canvas_interfac
 	canvas(canvas_interface->get_canvas()),
 	scrollx_adjustment(0,-4,4,0.01,0.1),
 	scrolly_adjustment(0,-4,4,0.01,0.1),
-	w(128),
-	h(128),
+	w(TILE_SIZE),
+	h(TILE_SIZE),
 	last_event_time(0),
 	progresscallback(0),
 	dragging(DRAG_NONE),
 	show_grid(false),
-	tile_w(128),
-	tile_h(128),
+	tile_w(TILE_SIZE),
+	tile_h(TILE_SIZE),
 	timecode_width(0),
 	timecode_height(0)
 {
@@ -647,6 +664,7 @@ WorkArea::WorkArea(etl::loose_handle<synfigapp::CanvasInterface> canvas_interfac
 	render_idle_func_id=0;
 	zoom=prev_zoom=1.0;
 	quality=10;
+	low_res_pixel_size=2;
 	rendering=false;
 	canceled_=false;
 	low_resolution=true;
@@ -810,6 +828,23 @@ WorkArea::~WorkArea()
 		render_idle_func_id=0;
 }
 
+#ifdef SINGLE_THREADED
+bool
+WorkArea::get_updating()const
+{
+	return App::single_threaded && async_renderer && async_renderer->updating;
+}
+#endif
+
+#ifdef SINGLE_THREADED
+void
+WorkArea::stop_updating(bool cancel)
+{
+	async_renderer->stop();
+	if (cancel) canceled_=true;
+}
+#endif
+
 void
 WorkArea::save_meta_data()
 {
@@ -877,6 +912,8 @@ WorkArea::load_meta_data()
 
 		if(!tmp.empty())
 			gx=stratof(tmp);
+		else
+			synfig::error("WorkArea::load_meta_data(): Unable to parse data for \"grid_size\", which was \"%s\"",data.c_str());
 
 		if(iter==data.end())
 			tmp.clear();
@@ -885,11 +922,11 @@ WorkArea::load_meta_data()
 
 		if(!tmp.empty())
 			gy=stratof(tmp);
+		else
+			synfig::error("WorkArea::load_meta_data(): Unable to parse data for \"grid_size\", which was \"%s\"",data.c_str());
 
 		set_grid_size(Vector(gx,gy));
 	}
-	else
-		synfig::error("WorkArea::load_meta_data(): Unable to parse data for \"grid_size\", which was \"%s\"",data.c_str());
 
 	data=canvas->get_meta_data("grid_show");
 	if(data.size() && (data=="1" || data[0]=='t' || data[0]=='T'))
@@ -1048,7 +1085,7 @@ void
 WorkArea::set_focus_point(const synfig::Point &point)
 {
 	// These next three lines try to ensure that we place the
-	// focus on a pixel boundry
+	// focus on a pixel boundary
 	/*Point adjusted(point[0]/abs(get_pw()),point[1]/abs(get_ph()));
 	adjusted[0]=(abs(adjusted[0]-floor(adjusted[0]))<0.5)?floor(adjusted[0])*abs(get_pw()):ceil(adjusted[0])*abs(get_ph());
 	adjusted[1]=(abs(adjusted[1]-floor(adjusted[1]))<0.5)?floor(adjusted[1])*abs(get_ph()):ceil(adjusted[1])*abs(get_ph());
@@ -1131,7 +1168,7 @@ WorkArea::on_key_press_event(GdkEventKey* event)
 			break;
 	}
 
-	synfigapp::Action::PassiveGrouper grouper(instance.get(),"Nudge");
+	synfigapp::Action::PassiveGrouper grouper(instance.get(),_("Nudge"));
 
 	// Grid snap does not apply to nudging
 	bool grid_snap_holder(get_grid_snap());
@@ -1166,8 +1203,6 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 	bool is_mouse(false);
 	Gdk::ModifierType modifier(Gdk::ModifierType(0));
 
-	drawing_area->grab_focus();
-
 	// Handle input stuff
 	if(
 		event->any.type==GDK_MOTION_NOTIFY ||
@@ -1187,9 +1222,10 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 		{
 			device=event->button.device;
 			modifier=Gdk::ModifierType(event->button.state);
+			drawing_area->grab_focus();
 		}
 
-		// Make sure we recognise the device
+		// Make sure we recognize the device
 		if(curr_input_device)
 		{
 			if(curr_input_device!=device)
@@ -1255,7 +1291,7 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 	// GDK mouse scrolling events
 	else if(event->any.type==GDK_SCROLL)
 	{
-		// GDK information needed to properly interprete mouse
+		// GDK information needed to properly interpret mouse
 		// scrolling events are: scroll.state, scroll.x/scroll.y, and
 		// scroll.direction. The value of scroll.direction will be
 		// obtained later.
@@ -1315,8 +1351,11 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 
 
 			selected_bezier=find_bezier(mouse_pos,radius,&bezier_click_pos);
-			if(duck && duck->get_editable())
+			if(duck)
 			{
+				if (!duck->get_editable())
+					return true;
+
 				//get_selected_duck()->signal_user_click(0)();
 				//if(clicked_duck)clicked_duck->signal_user_click(0)();
 
@@ -1432,19 +1471,15 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 				if(get_selected_ducks().size()<=1)
 					duck->signal_user_click(2)();
 				else
-				{
 					canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MULTIPLE_DUCKS_CLICKED,BUTTON_RIGHT,mouse_pos,pressure,modifier));
-				}
 				return true;
 			}
-			else
-			if(bezier)
+			else if(bezier)
 			{
 				bezier->signal_user_click(2)(bezier_click_pos);
 				return true;
 			}
-			else
-			if(layer)
+			else if (layer)
 			{
 				if(canvas_view->get_smach().process_event(EventLayerClick(layer,BUTTON_RIGHT,mouse_pos))==Smach::RESULT_OK)
 					return false;
@@ -1482,7 +1517,7 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 
 		signal_cursor_moved_();
 
-		// Guide/Duck hilights on hover
+		// Guide/Duck highlights on hover
 		if(dragging==DRAG_NONE)
 		{
 			GuideList::iterator iter;
@@ -1533,11 +1568,13 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 
 			drawing_area->queue_draw();
 		}
+
 		if(dragging==DRAG_BOX)
 		{
 			curr_point=mouse_pos;
 			drawing_area->queue_draw();
 		}
+
 		if(dragging==DRAG_GUIDE)
 		{
 			if(curr_guide_is_x)
@@ -1546,30 +1583,34 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 				*curr_guide=mouse_pos[1];
 			drawing_area->queue_draw();
 		}
+
 		if(dragging!=DRAG_WINDOW)
 		{	// Update those triangle things on the rulers
 			const synfig::Point point(mouse_pos);
 			hruler->property_position()=Distance(point[0],Distance::SYSTEM_UNITS).get(App::distance_system,get_canvas()->rend_desc());
 			vruler->property_position()=Distance(point[1],Distance::SYSTEM_UNITS).get(App::distance_system,get_canvas()->rend_desc());
 		}
-		if(dragging==DRAG_WINDOW)
-		{
-			set_focus_point(get_focus_point()+mouse_pos-drag_point);
-		}
-		else
-		if(event->motion.state&GDK_BUTTON1_MASK && canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_BUTTON_DRAG,BUTTON_LEFT,mouse_pos,pressure,modifier))==Smach::RESULT_ACCEPT)
+
+		if(dragging == DRAG_WINDOW)
+			set_focus_point(get_focus_point() + mouse_pos-drag_point);
+		else if (event->motion.state & GDK_BUTTON1_MASK &&
+				canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_BUTTON_DRAG, BUTTON_LEFT,
+																  mouse_pos,pressure,modifier)) == Smach::RESULT_ACCEPT)
 			return true;
-		else
-		if(event->motion.state&GDK_BUTTON2_MASK && canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_BUTTON_DRAG,BUTTON_MIDDLE,mouse_pos,pressure,modifier))==Smach::RESULT_ACCEPT)
+		else if (event->motion.state & GDK_BUTTON2_MASK &&
+				 canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_BUTTON_DRAG, BUTTON_MIDDLE,
+																   mouse_pos, pressure, modifier)) == Smach::RESULT_ACCEPT)
 			return true;
-		else
-		if(event->motion.state&GDK_BUTTON3_MASK && canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_BUTTON_DRAG,BUTTON_RIGHT,mouse_pos,pressure,modifier))==Smach::RESULT_ACCEPT)
+		else if (event->motion.state & GDK_BUTTON3_MASK &&
+				 canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_BUTTON_DRAG, BUTTON_RIGHT,
+																   mouse_pos, pressure, modifier)) == Smach::RESULT_ACCEPT)
 			return true;
-		else
-		if(canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_MOTION,BUTTON_NONE,mouse_pos,pressure,modifier))==Smach::RESULT_ACCEPT)
+		else if(canvas_view->get_smach().process_event(EventMouse(EVENT_WORKAREA_MOUSE_MOTION, BUTTON_NONE,
+																  mouse_pos, pressure,modifier)) == Smach::RESULT_ACCEPT)
 			return true;
 
 		break;
+
 	case GDK_BUTTON_RELEASE:
 	{
 		bool ret(false);
@@ -1583,7 +1624,7 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 		else
 		if(dragging==DRAG_DUCK)
 		{
-			synfigapp::Action::PassiveGrouper grouper(instance.get(),"Move");
+			synfigapp::Action::PassiveGrouper grouper(instance.get(),_("Move"));
 			dragging=DRAG_NONE;
 			//translate_selected_ducks(mouse_pos);
 			set_axis_lock(false);
@@ -1852,10 +1893,8 @@ WorkArea::on_vruler_event(GdkEvent */*event*/)
 	switch(event->type)
     {
 	case GDK_BUTTON_PRESS:
-		DEBUGPOINT();
 		if(dragging==DRAG_NONE)
 		{
-			DEBUGPOINT();
 			dragging=DRAG_GUIDE;
 			curr_guide=get_guide_list_x().insert(get_guide_list_x().begin());
 			curr_guide_is_x=true;
@@ -1863,10 +1902,8 @@ WorkArea::on_vruler_event(GdkEvent */*event*/)
 		return true;
 		break;
 	case GDK_BUTTON_RELEASE:
-		DEBUGPOINT();
 		if(dragging==DRAG_GUIDE && curr_guide_is_x==true)
 		{
-			DEBUGPOINT();
 			dragging=DRAG_NONE;
 			get_guide_list_x().erase(curr_guide);
 		}
@@ -1963,7 +2000,8 @@ WorkArea::next_unrendered_tile(int refreshes)const
 		x(focus_point[0]/pw+drawing_area->get_width()/2-w/2),
 		y(focus_point[1]/ph+drawing_area->get_height()/2-h/2);
 
-	const int width_in_tiles(w/tile_w+(w%tile_w?1:0));
+	int div = low_res_pixel_size;
+	const int width_in_tiles(w/tile_w+((low_resolution?((w/div)%(tile_w/div)):(w%tile_w))?1:0));
 	const int height_in_tiles(h/tile_h+(h%tile_h?1:0));
 
 	int
@@ -2129,6 +2167,14 @@ WorkArea::set_quality(int x)
 	queue_render_preview();
 }
 
+void
+WorkArea::set_low_res_pixel_size(int x)
+{
+	if(x==low_res_pixel_size)
+		return;
+	low_res_pixel_size=x;
+	queue_render_preview();
+}
 
 namespace studio
 {
@@ -2174,6 +2220,15 @@ public:
 bool
 studio::WorkArea::async_update_preview()
 {
+#ifdef SINGLE_THREADED
+	if (get_updating())
+	{
+		stop_updating();
+		queue_render_preview();
+		return false;
+	}
+#endif
+
 	async_renderer=0;
 
 	queued=false;
@@ -2209,6 +2264,11 @@ studio::WorkArea::async_update_preview()
 	int w=(int)(desc.get_w()*zoom);
 	int h=(int)(desc.get_h()*zoom);
 
+	// ensure that the size we draw is at least one pixel in each dimension
+	int min_size = low_resolution ? low_res_pixel_size : 1;
+	if (w < min_size) w = min_size;
+	if (h < min_size) h = min_size;
+
 	// Setup the description parameters
 	desc.set_antialias(1);
 	desc.set_time(cur_time);
@@ -2218,8 +2278,12 @@ studio::WorkArea::async_update_preview()
 	// Create the render target
 	handle<Target> target;
 
-	if(w*h>(low_resolution?480*270:480*270/2))
+	// if we have lots of pixels to render and the tile renderer isn't disabled, use it
+	int div;
+	div = low_resolution ? low_res_pixel_size : 1;
+	if (w*h > 240*div*135*div && !getenv("SYNFIG_DISABLE_TILE_RENDER"))
 	{
+		// do a tile render
 		handle<WorkAreaTarget> trgt(new class WorkAreaTarget(this,w,h));
 
 		trgt->set_rend_desc(&desc);
@@ -2228,6 +2292,7 @@ studio::WorkArea::async_update_preview()
 	}
 	else
 	{
+		// do a scanline render
 		handle<WorkAreaTarget_Full> trgt(new class WorkAreaTarget_Full(this,w,h));
 
 		trgt->set_rend_desc(&desc);
@@ -2252,7 +2317,7 @@ studio::WorkArea::async_update_preview()
 	synfig::ProgressCallback *cb=get_canvas_view()->get_ui_interface().get();
 
 	rendering=true;
-	cb->task("Rendering...");
+	cb->task(_("Rendering..."));
 	rendering=true;
 
 	return true;
@@ -2274,12 +2339,12 @@ studio::WorkArea::async_update_finished()
 	{
 		dirty=false;
 		//queued=false;
-		cb->task("Idle");
+		cb->task(_("Idle"));
 	}
 	else
 	{
 		dirty=true;
-		cb->task("Render Failed");
+		cb->task(_("Render Failed"));
 	}
 	//get_canvas_view()->reset_cancel_status();
 	done_rendering();
@@ -2353,7 +2418,7 @@ again:
 	target->set_avoid_time_sync(true);
 
 	if(cb)
-		cb->task(strprintf("Rendering canvas %s...",get_canvas()->get_name().c_str()));
+		cb->task(strprintf(_("Rendering canvas %s..."),get_canvas()->get_name().c_str()));
 
 	bool ret = target->render(cb);
 
@@ -2369,9 +2434,9 @@ again:
 	if(cb)
 	{
 		if(ret)
-			cb->task("Idle");
+			cb->task(_("Idle"));
 		else
-			cb->task("Render Failed");
+			cb->task(_("Render Failed"));
 		cb->amount_complete(0,1);
 	}
 
@@ -2394,7 +2459,7 @@ again:
 }
 
 void
-studio::WorkArea::async_render_preview(Time time)
+studio::WorkArea::async_render_preview(synfig::Time time)
 {
 	cur_time=time;
 	//tile_book.clear();
@@ -2415,7 +2480,7 @@ WorkArea::async_render_preview()
 }
 
 bool
-studio::WorkArea::sync_render_preview(Time time)
+studio::WorkArea::sync_render_preview(synfig::Time time)
 {
 	cur_time=time;
 	//tile_book.clear();
@@ -2625,12 +2690,12 @@ studio::WorkArea::set_cursor(Gdk::CursorType x)
 	drawing_area->get_window()->set_cursor(Gdk::Cursor(x));
 }
 
-#include "iconcontroler.h"
+#include "iconcontroller.h"
 
 void
 studio::WorkArea::refresh_cursor()
 {
-//	set_cursor(IconControler::get_tool_cursor(canvas_view->get_smach().get_state_name(),drawing_area->get_window()));
+//	set_cursor(IconController::get_tool_cursor(canvas_view->get_smach().get_state_name(),drawing_area->get_window()));
 }
 
 void
