@@ -2,10 +2,11 @@
 /*!	\file action_param.h
 **	\brief Template File
 **
-**	$Id: action_param.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: action_param.h 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -73,26 +74,26 @@ class Param
 public:
 	enum Type
 	{
-		TYPE_NIL,
+		TYPE_NIL,				// 0
 		TYPE_INTEGER,
 		TYPE_REAL,
 		TYPE_BOOL,
-		TYPE_ACTIVEPOINT,
+		TYPE_ACTIVEPOINT,		// 4
 		TYPE_WAYPOINT,
 		TYPE_WAYPOINTMODEL,
 		TYPE_KEYFRAME,
-		TYPE_CANVAS,
+		TYPE_CANVAS,			// 8
 		TYPE_LAYER,
 		TYPE_VALUENODE,
 		TYPE_VALUEDESC,
-		TYPE_VALUE,
+		TYPE_VALUE,				// 12
 		TYPE_STRING,
 		TYPE_TIME,
 		TYPE_CANVASINTERFACE,
-		TYPE_EDITMODE,
+		TYPE_EDITMODE,			// 16
 		TYPE_RENDDESC,
 
-		TYPE_END
+		TYPE_END				// 18
 	};
 private:
 	Type type_;
