@@ -2,7 +2,7 @@
 /*!	\file action_system.cpp
 **	\brief Template File
 **
-**	$Id: action_system.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: action_system.cpp 1338 2008-01-12 17:49:10Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,6 +33,8 @@
 #include "instance.h"
 #include "canvasinterface.h"
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -64,7 +66,7 @@ Action::System::~System()
 }
 
 bool
-Action::System::perform_action(handle<Action::Base> action)
+Action::System::perform_action(etl::handle<Action::Base> action)
 {
 	handle<UIInterface> uim(get_ui_interface());
 
@@ -196,7 +198,6 @@ Action::System::perform_action(handle<Action::Base> action)
 		{
 			handle<CanvasInterface> canvas_interface=static_cast<Instance*>(this)->find_canvas_interface(canvas);
 			assert(canvas_interface);
-			DEBUGPOINT();
 			//canvas_interface->signal_dirty_preview()();
 		}
 	}
@@ -207,7 +208,7 @@ Action::System::perform_action(handle<Action::Base> action)
 }
 
 bool
-synfigapp::Action::System::undo_(handle<UIInterface> uim)
+synfigapp::Action::System::undo_(etl::handle<UIInterface> uim)
 {
 	handle<Action::Undoable> action(undo_action_stack().front());
 	most_recent_action_=action;
@@ -297,7 +298,6 @@ synfigapp::Action::System::undo()
 		{
 			handle<CanvasInterface> canvas_interface=static_cast<Instance*>(this)->find_canvas_interface(canvas);
 			assert(canvas_interface);
-			//DEBUGPOINT();
 			//canvas_interface->signal_dirty_preview()();
 		}
 	}
@@ -306,7 +306,7 @@ synfigapp::Action::System::undo()
 }
 
 bool
-Action::System::redo_(handle<UIInterface> uim)
+Action::System::redo_(etl::handle<UIInterface> uim)
 {
 	handle<Action::Undoable> action(redo_action_stack().front());
 	most_recent_action_=action;
@@ -396,7 +396,6 @@ Action::System::redo()
 		{
 			handle<CanvasInterface> canvas_interface=static_cast<Instance*>(this)->find_canvas_interface(canvas);
 			assert(canvas_interface);
-			//DEBUGPOINT();
 			//canvas_interface->signal_dirty_preview()();
 		}
 	}
@@ -509,7 +508,6 @@ Action::System::set_action_status(etl::handle<Action::Undoable> action, bool x)
 			Canvas::Handle canvas=canvas_specific->get_canvas();
 			handle<CanvasInterface> canvas_interface=static_cast<Instance*>(this)->find_canvas_interface(canvas);
 			assert(canvas_interface);
-			//DEBUGPOINT();
 			//canvas_interface->signal_dirty_preview()();
 		}
 
@@ -530,7 +528,6 @@ Action::System::set_action_status(etl::handle<Action::Undoable> action, bool x)
 			Canvas::Handle canvas=canvas_specific->get_canvas();
 			handle<CanvasInterface> canvas_interface=static_cast<Instance*>(this)->find_canvas_interface(canvas);
 			assert(canvas_interface);
-			DEBUGPOINT();
 			//canvas_interface->signal_dirty_preview()();
 		}
 
@@ -540,7 +537,7 @@ Action::System::set_action_status(etl::handle<Action::Undoable> action, bool x)
 	return false;
 }
 
-Action::PassiveGrouper::PassiveGrouper(etl::loose_handle<Action::System> instance_,synfig::String name_):
+Action::PassiveGrouper::PassiveGrouper(etl::loose_handle<System> instance_,synfig::String name_):
 	instance_(instance_),
 	name_(name_),
 	redraw_requested_(false),
@@ -551,14 +548,12 @@ Action::PassiveGrouper::PassiveGrouper(etl::loose_handle<Action::System> instanc
 }
 
 void
-Action::PassiveGrouper::request_redraw(handle<CanvasInterface> x)
+Action::PassiveGrouper::request_redraw(etl::handle<CanvasInterface> x)
 {
-/*	DEBUGPOINT();
-	if(instance_->group_stack_.empty())
+/*	if(instance_->group_stack_.empty())
 	{
 		if(x!=canvas_interface_)
 		{
-			DEBUGPOINT();
 			x->signal_dirty_preview()();
 		}
 
@@ -566,21 +561,16 @@ Action::PassiveGrouper::request_redraw(handle<CanvasInterface> x)
 	}
 	else
 	{
-		DEBUGPOINT();
 		if(instance_->group_stack_.back()==this)
 		{
-			DEBUGPOINT();
 			redraw_requested_=true;
 		}
 		else
 		{
-			DEBUGPOINT();
 			instance_->group_stack_.back()->request_redraw(x);
 			redraw_requested_=false;
 		}
-		DEBUGPOINT();
 	}
-	DEBUGPOINT();
 */
 	if(x)
 	{
@@ -676,7 +666,6 @@ Action::PassiveGrouper::~PassiveGrouper()
 		if(instance_->group_stack_.empty())
 		{
 			assert(canvas_interface_);
-			DEBUGPOINT();
 			canvas_interface_->signal_dirty_preview()();
 		}
 		else
