@@ -2,7 +2,7 @@
 /*!	\file activepointremove.cpp
 **	\brief Template File
 **
-**	$Id: activepointremove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: activepointremove.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "activepointremove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ActivepointRemove);
 ACTION_SET_NAME(Action::ActivepointRemove,"activepoint_remove");
-ACTION_SET_LOCAL_NAME(Action::ActivepointRemove,"Remove Activepoint");
+ACTION_SET_LOCAL_NAME(Action::ActivepointRemove,N_("Remove Activepoint"));
 ACTION_SET_TASK(Action::ActivepointRemove,"remove");
 ACTION_SET_CATEGORY(Action::ActivepointRemove,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointRemove,0);
 ACTION_SET_VERSION(Action::ActivepointRemove,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointRemove,"$Id: activepointremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ActivepointRemove,"$Id: activepointremove.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
