@@ -2,7 +2,7 @@
 /*!	\file activepointset.cpp
 **	\brief Template File
 **
-**	$Id: activepointset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: activepointset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "activepointset.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ActivepointSet);
 ACTION_SET_NAME(Action::ActivepointSet,"activepoint_set");
-ACTION_SET_LOCAL_NAME(Action::ActivepointSet,"Set Activepoint");
+ACTION_SET_LOCAL_NAME(Action::ActivepointSet,N_("Set Activepoint"));
 ACTION_SET_TASK(Action::ActivepointSet,"set");
 ACTION_SET_CATEGORY(Action::ActivepointSet,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointSet,0);
 ACTION_SET_VERSION(Action::ActivepointSet,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSet,"$Id: activepointset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ActivepointSet,"$Id: activepointset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -191,7 +193,7 @@ Action::ActivepointSet::perform()
 		}
 	}
 
-	//remove all the points we're supposed to be overwritting
+	//remove all the points we're supposed to be overwriting
 	{
 		vector<Activepoint>::iterator 	oi = overwritten_activepoints.begin(),
 										oend = overwritten_activepoints.end();
