@@ -2,7 +2,7 @@
 /*!	\file activepointseton.cpp
 **	\brief Template File
 **
-**	$Id: activepointseton.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: activepointseton.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -40,6 +40,8 @@
 #include "valuedescconnect.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -52,12 +54,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ActivepointSetOn);
 ACTION_SET_NAME(Action::ActivepointSetOn,"activepoint_set_on");
-ACTION_SET_LOCAL_NAME(Action::ActivepointSetOn,_("Mark Activepoint as \"On\""));
+ACTION_SET_LOCAL_NAME(Action::ActivepointSetOn,N_("Mark Activepoint as \"On\""));
 ACTION_SET_TASK(Action::ActivepointSetOn,"set_on");
 ACTION_SET_CATEGORY(Action::ActivepointSetOn,Action::CATEGORY_ACTIVEPOINT|Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ActivepointSetOn,-10);
 ACTION_SET_VERSION(Action::ActivepointSetOn,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSetOn,"$Id: activepointseton.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ActivepointSetOn,"$Id: activepointseton.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
