@@ -2,7 +2,7 @@
 /*!	\file activepointsetsmart.cpp
 **	\brief Template File
 **
-**	$Id: activepointsetsmart.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: activepointsetsmart.cpp 1834 2008-03-02 15:54:10Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -39,6 +39,8 @@
 #include "valuedescconnect.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -51,12 +53,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ActivepointSetSmart);
 ACTION_SET_NAME(Action::ActivepointSetSmart,"activepoint_set_smart");
-ACTION_SET_LOCAL_NAME(Action::ActivepointSetSmart,_("Set Activepoint (Smart)"));
+ACTION_SET_LOCAL_NAME(Action::ActivepointSetSmart,N_("Set Activepoint (Smart)"));
 ACTION_SET_TASK(Action::ActivepointSetSmart,"set");
 ACTION_SET_CATEGORY(Action::ActivepointSetSmart,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointSetSmart,0);
 ACTION_SET_VERSION(Action::ActivepointSetSmart,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSetSmart,"$Id: activepointsetsmart.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ActivepointSetSmart,"$Id: activepointsetsmart.cpp 1834 2008-03-02 15:54:10Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -284,7 +286,7 @@ Action::ActivepointSetSmart::prepare()
 	clear();
 	times.clear();
 
-	// First, we need to to add any activepoints necessary to
+	// First, we need to add any activepoints necessary to
 	// maintain the integrity of the keyframes.
 	enclose_activepoint(activepoint);
 
@@ -293,7 +295,7 @@ Action::ActivepointSetSmart::prepare()
 		if(value_node->list[index].find(activepoint)==value_node->list[index].timing_info.end())
 			throw int();
 
-		// Then, lets try to replace the old activepoint, if it exists
+		// Then, let's try to replace the old activepoint, if it exists
 		enclose_activepoint(*value_node->list[index].find(activepoint));
 
 		Action::Handle action(ActivepointSet::create());
@@ -361,5 +363,5 @@ Action::ActivepointSetSmart::prepare()
 	catch(int){}
 	catch(Exception::NotFound){}
 
-	throw Error(_("Unable to determine how to procede. This is a bug."));
+	throw Error(_("Unable to determine how to proceed. This is a bug."));
 }
