@@ -2,7 +2,7 @@
 /*!	\file activepointsimpleadd.cpp
 **	\brief Simple add activepoint File
 **
-**	$Id: activepointsimpleadd.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: activepointsimpleadd.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -32,6 +32,8 @@
 #include "activepointsimpleadd.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ActivepointSimpleAdd);
 ACTION_SET_NAME(Action::ActivepointSimpleAdd,"waypoint_simpleadd");
-ACTION_SET_LOCAL_NAME(Action::ActivepointSimpleAdd,"Simply Add Waypoint");
+ACTION_SET_LOCAL_NAME(Action::ActivepointSimpleAdd,N_("Simply Add Waypoint"));
 ACTION_SET_TASK(Action::ActivepointSimpleAdd,"add");
 ACTION_SET_CATEGORY(Action::ActivepointSimpleAdd,Action::CATEGORY_WAYPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointSimpleAdd,0);
 ACTION_SET_VERSION(Action::ActivepointSimpleAdd,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSimpleAdd,"$Id: activepointsimpleadd.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ActivepointSimpleAdd,"$Id: activepointsimpleadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
