@@ -2,7 +2,7 @@
 /*!	\file canvasadd.cpp
 **	\brief Template File
 **
-**	$Id: canvasadd.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: canvasadd.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "canvasadd.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::CanvasAdd);
 ACTION_SET_NAME(Action::CanvasAdd,"canvas_add");
-ACTION_SET_LOCAL_NAME(Action::CanvasAdd,"Add Child Canvas");
+ACTION_SET_LOCAL_NAME(Action::CanvasAdd,N_("Add Child Canvas"));
 ACTION_SET_TASK(Action::CanvasAdd,"add");
 ACTION_SET_CATEGORY(Action::CanvasAdd,Action::CATEGORY_CANVAS);
 ACTION_SET_PRIORITY(Action::CanvasAdd,0);
 ACTION_SET_VERSION(Action::CanvasAdd,"0.0");
-ACTION_SET_CVS_ID(Action::CanvasAdd,"$Id: canvasadd.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::CanvasAdd,"$Id: canvasadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
