@@ -2,7 +2,7 @@
 /*!	\file canvasremove.cpp
 **	\brief Template File
 **
-**	$Id: canvasremove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: canvasremove.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "canvasremove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::CanvasRemove);
 ACTION_SET_NAME(Action::CanvasRemove,"canvas_remove");
-ACTION_SET_LOCAL_NAME(Action::CanvasRemove,"Remove Canvas");
+ACTION_SET_LOCAL_NAME(Action::CanvasRemove,N_("Remove Canvas"));
 ACTION_SET_TASK(Action::CanvasRemove,"remove");
 ACTION_SET_CATEGORY(Action::CanvasRemove,Action::CATEGORY_CANVAS);
 ACTION_SET_PRIORITY(Action::CanvasRemove,0);
 ACTION_SET_VERSION(Action::CanvasRemove,"0.0");
-ACTION_SET_CVS_ID(Action::CanvasRemove,"$Id: canvasremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::CanvasRemove,"$Id: canvasremove.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
