@@ -2,7 +2,7 @@
 /*!	\file canvasrenddescset.cpp
 **	\brief Template File
 **
-**	$Id: canvasrenddescset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: canvasrenddescset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "canvasrenddescset.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::CanvasRendDescSet);
 ACTION_SET_NAME(Action::CanvasRendDescSet,"canvas_rend_desc_set");
-ACTION_SET_LOCAL_NAME(Action::CanvasRendDescSet,"Set Canvas RendDesc");
+ACTION_SET_LOCAL_NAME(Action::CanvasRendDescSet,N_("Set Canvas RendDesc"));
 ACTION_SET_TASK(Action::CanvasRendDescSet,"set");
 ACTION_SET_CATEGORY(Action::CanvasRendDescSet,Action::CATEGORY_CANVAS);
 ACTION_SET_PRIORITY(Action::CanvasRendDescSet,0);
 ACTION_SET_VERSION(Action::CanvasRendDescSet,"0.0");
-ACTION_SET_CVS_ID(Action::CanvasRendDescSet,"$Id: canvasrenddescset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::CanvasRendDescSet,"$Id: canvasrenddescset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
