@@ -2,7 +2,7 @@
 /*!	\file colorset.cpp
 **	\brief Template File
 **
-**	$Id: colorset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: colorset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -38,6 +38,8 @@
 #include <synfigapp/canvasinterface.h>
 #include <synfigapp/main.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -50,12 +52,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ColorSet);
 ACTION_SET_NAME(Action::ColorSet,"color_set");
-ACTION_SET_LOCAL_NAME(Action::ColorSet,"Apply Default Color");
+ACTION_SET_LOCAL_NAME(Action::ColorSet,N_("Apply Default Color"));
 ACTION_SET_TASK(Action::ColorSet,"set");
 ACTION_SET_CATEGORY(Action::ColorSet,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ColorSet,0);
 ACTION_SET_VERSION(Action::ColorSet,"0.0");
-ACTION_SET_CVS_ID(Action::ColorSet,"$Id: colorset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ColorSet,"$Id: colorset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
