@@ -2,7 +2,7 @@
 /*!	\file editmodeset.cpp
 **	\brief Template File
 **
-**	$Id: editmodeset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: editmodeset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "editmodeset.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::EditModeSet);
 ACTION_SET_NAME(Action::EditModeSet,"edit_mode_set");
-ACTION_SET_LOCAL_NAME(Action::EditModeSet,"Set Edit Mode");
+ACTION_SET_LOCAL_NAME(Action::EditModeSet,N_("Set Edit Mode"));
 ACTION_SET_TASK(Action::EditModeSet,"set");
 ACTION_SET_CATEGORY(Action::EditModeSet,Action::CATEGORY_OTHER);
 ACTION_SET_PRIORITY(Action::EditModeSet,0);
 ACTION_SET_VERSION(Action::EditModeSet,"0.0");
-ACTION_SET_CVS_ID(Action::EditModeSet,"$Id: editmodeset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::EditModeSet,"$Id: editmodeset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
