@@ -2,7 +2,7 @@
 /*!	\file groupaddlayers.cpp
 **	\brief Template File
 **
-**	$Id: groupaddlayers.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: groupaddlayers.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "groupaddlayers.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::GroupAddLayers);
 ACTION_SET_NAME(Action::GroupAddLayers,"group_add_layers");
-ACTION_SET_LOCAL_NAME(Action::GroupAddLayers,"Add Layers to Group");
+ACTION_SET_LOCAL_NAME(Action::GroupAddLayers,N_("Add Layers to Group"));
 ACTION_SET_TASK(Action::GroupAddLayers,"add");
 ACTION_SET_CATEGORY(Action::GroupAddLayers,Action::CATEGORY_LAYER|Action::CATEGORY_GROUP);
 ACTION_SET_PRIORITY(Action::GroupAddLayers,0);
 ACTION_SET_VERSION(Action::GroupAddLayers,"0.0");
-ACTION_SET_CVS_ID(Action::GroupAddLayers,"$Id: groupaddlayers.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::GroupAddLayers,"$Id: groupaddlayers.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
