@@ -2,7 +2,7 @@
 /*!	\file groupremove.cpp
 **	\brief Template File
 **
-**	$Id: groupremove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: groupremove.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "groupremove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::GroupRemove);
 ACTION_SET_NAME(Action::GroupRemove,"group_remove");
-ACTION_SET_LOCAL_NAME(Action::GroupRemove,"Remove Group");
+ACTION_SET_LOCAL_NAME(Action::GroupRemove,N_("Remove Group"));
 ACTION_SET_TASK(Action::GroupRemove,"remove");
 ACTION_SET_CATEGORY(Action::GroupRemove,Action::CATEGORY_GROUP);
 ACTION_SET_PRIORITY(Action::GroupRemove,0);
 ACTION_SET_VERSION(Action::GroupRemove,"0.0");
-ACTION_SET_CVS_ID(Action::GroupRemove,"$Id: groupremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::GroupRemove,"$Id: groupremove.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
