@@ -2,10 +2,11 @@
 /*!	\file groupremovelayers.cpp
 **	\brief Template File
 **
-**	$Id: groupremovelayers.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: groupremovelayers.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "groupremovelayers.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +47,12 @@ using namespace Action;
 
 ACTION_INIT(Action::GroupRemoveLayers);
 ACTION_SET_NAME(Action::GroupRemoveLayers,"group_remove_layers");
-ACTION_SET_LOCAL_NAME(Action::GroupRemoveLayers,"Remove Layers from a Group");
+ACTION_SET_LOCAL_NAME(Action::GroupRemoveLayers,N_("Remove Layers from a Group"));
 ACTION_SET_TASK(Action::GroupRemoveLayers,"remove");
 ACTION_SET_CATEGORY(Action::GroupRemoveLayers,Action::CATEGORY_LAYER|Action::CATEGORY_GROUP);
 ACTION_SET_PRIORITY(Action::GroupRemoveLayers,0);
 ACTION_SET_VERSION(Action::GroupRemoveLayers,"0.0");
-ACTION_SET_CVS_ID(Action::GroupRemoveLayers,"$Id: groupremovelayers.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::GroupRemoveLayers,"$Id: groupremovelayers.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -68,16 +71,10 @@ Action::GroupRemoveLayers::get_param_vocab()
 
 	ret.push_back(ParamDesc("layer",Param::TYPE_LAYER)
 		.set_local_name(_("Layer"))
-		.set_desc(_("Layer to be added to group"))
+		.set_desc(_("Layer to be removed from group"))
 		.set_supports_multiple()
 	);
 
-	ret.push_back(ParamDesc("group",Param::TYPE_STRING)
-		.set_local_name(_("Group"))
-		.set_desc(_("Name of the Group to add the Layers to"))
-		.set_user_supplied()
-	);
-
 	return ret;
 }
 
@@ -99,20 +96,13 @@ Action::GroupRemoveLayers::set_param(const synfig::String& name, const Action::P
 		return true;
 	}
 
-	if(name=="group" && param.get_type()==Param::TYPE_STRING)
-	{
-		group=param.get_string();
-
-		return true;
-	}
-
 	return Action::CanvasSpecific::set_param(name,param);
 }
 
 bool
 Action::GroupRemoveLayers::is_ready()const
 {
-	if(layer_list.empty() || group.empty())
+	if(layer_list.empty())
 		return false;
 	return Action::CanvasSpecific::is_ready();
 }
@@ -124,9 +114,7 @@ Action::GroupRemoveLayers::perform()
 	for(iter=layer_list.begin();iter!=layer_list.end();++iter)
 	{
 		Layer::Handle layer(iter->first);
-		iter->second=layer->get_group();
-
-		layer->remove_from_group(group);
+		layer->remove_from_group(iter->second=layer->get_group());
 	}
 }
 
