@@ -2,10 +2,11 @@
 /*!	\file groupremovelayers.h
 **	\brief Template File
 **
-**	$Id: groupremovelayers.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: groupremovelayers.h 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -52,9 +53,6 @@ private:
 	// List contains the layers and their previous groups
 	std::list<std::pair<synfig::Layer::Handle,synfig::String> > layer_list;
 
-	// The name of the new group
-	synfig::String group;
-
 public:
 
 	GroupRemoveLayers();
