@@ -2,7 +2,7 @@
 /*!	\file grouprename.cpp
 **	\brief Template File
 **
-**	$Id: grouprename.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: grouprename.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "grouprename.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::GroupRename);
 ACTION_SET_NAME(Action::GroupRename,"group_rename");
-ACTION_SET_LOCAL_NAME(Action::GroupRename,"Rename Group");
+ACTION_SET_LOCAL_NAME(Action::GroupRename,N_("Rename Group"));
 ACTION_SET_TASK(Action::GroupRename,"rename");
 ACTION_SET_CATEGORY(Action::GroupRename,Action::CATEGORY_GROUP);
 ACTION_SET_PRIORITY(Action::GroupRename,0);
 ACTION_SET_VERSION(Action::GroupRename,"0.0");
-ACTION_SET_CVS_ID(Action::GroupRename,"$Id: grouprename.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::GroupRename,"$Id: grouprename.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
