@@ -2,7 +2,7 @@
 /*!	\file keyframeadd.cpp
 **	\brief Template File
 **
-**	$Id: keyframeadd.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframeadd.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "keyframeadd.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::KeyframeAdd);
 ACTION_SET_NAME(Action::KeyframeAdd,"keyframe_add");
-ACTION_SET_LOCAL_NAME(Action::KeyframeAdd,"Add Keyframe");
+ACTION_SET_LOCAL_NAME(Action::KeyframeAdd,N_("Add Keyframe"));
 ACTION_SET_TASK(Action::KeyframeAdd,"add");
 ACTION_SET_CATEGORY(Action::KeyframeAdd,Action::CATEGORY_KEYFRAME);
 ACTION_SET_PRIORITY(Action::KeyframeAdd,0);
 ACTION_SET_VERSION(Action::KeyframeAdd,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeAdd,"$Id: keyframeadd.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::KeyframeAdd,"$Id: keyframeadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
