@@ -2,7 +2,7 @@
 /*!	\file keyframeset.cpp
 **	\brief Template File
 **
-**	$Id: keyframeset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframeset.cpp 1205 2007-12-17 09:43:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -36,6 +36,8 @@
 #include "activepointsetsmart.h"
 #include "waypointsetsmart.h"
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -48,12 +50,12 @@ using namespace Action;
 
 ACTION_INIT(Action::KeyframeSet);
 ACTION_SET_NAME(Action::KeyframeSet,"keyframe_set");
-ACTION_SET_LOCAL_NAME(Action::KeyframeSet,"Set Keyframe");
+ACTION_SET_LOCAL_NAME(Action::KeyframeSet,N_("Set Keyframe"));
 ACTION_SET_TASK(Action::KeyframeSet,"set");
 ACTION_SET_CATEGORY(Action::KeyframeSet,Action::CATEGORY_KEYFRAME|Action::CATEGORY_HIDDEN);
 ACTION_SET_PRIORITY(Action::KeyframeSet,0);
 ACTION_SET_VERSION(Action::KeyframeSet,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeSet,"$Id: keyframeset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::KeyframeSet,"$Id: keyframeset.cpp 1205 2007-12-17 09:43:41Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -145,7 +147,7 @@ Action::KeyframeSet::prepare()
 #define old_2_new(x)	(((x)-old_begin)/(old_end-old_begin)*(new_end-new_begin)+new_begin)
 
 int
-Action::KeyframeSet::scale_activepoints(const synfigapp::ValueDesc& value_desc,const Time& old_begin,const Time& old_end,const Time& new_begin,const Time& new_end)
+Action::KeyframeSet::scale_activepoints(const synfigapp::ValueDesc& value_desc,const synfig::Time& old_begin,const synfig::Time& old_end,const synfig::Time& new_begin,const synfig::Time& new_end)
 {
 	ValueNode_DynamicList::Handle value_node(ValueNode_DynamicList::Handle::cast_static(value_desc.get_parent_value_node()));
 	ValueNode_DynamicList::ListEntry& list_entry(value_node->list[value_desc.get_index()]);
@@ -203,7 +205,7 @@ Action::KeyframeSet::scale_activepoints(const synfigapp::ValueDesc& value_desc,c
 }
 
 int
-Action::KeyframeSet::scale_waypoints(const synfigapp::ValueDesc& value_desc,const Time& old_begin,const Time& old_end,const Time& new_begin,const Time& new_end)
+Action::KeyframeSet::scale_waypoints(const synfigapp::ValueDesc& value_desc,const synfig::Time& old_begin,const synfig::Time& old_end,const synfig::Time& new_begin,const synfig::Time& new_end)
 {
 	ValueNode_Animated::Handle value_node(ValueNode_Animated::Handle::cast_static(value_desc.get_value_node()));
 
@@ -375,7 +377,7 @@ Action::KeyframeSet::perform()
 		throw Error(_("Unable to find the given keyframe"));
 	}
 
-	// Check for colisions
+	// Check for collisions
 	if(old_time!=new_time)
 	{
 		try {
