@@ -2,7 +2,7 @@
 /*!	\file keyframesetdelta.cpp
 **	\brief Template File
 **
-**	$Id: keyframesetdelta.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframesetdelta.cpp 1338 2008-01-12 17:49:10Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -36,6 +36,8 @@
 #include "activepointsetsmart.h"
 #include "waypointsetsmart.h"
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -48,12 +50,12 @@ using namespace Action;
 
 ACTION_INIT(Action::KeyframeSetDelta);
 ACTION_SET_NAME(Action::KeyframeSetDelta,"keyframe_set_delta");
-ACTION_SET_LOCAL_NAME(Action::KeyframeSetDelta,"Set Keyframe Delta");
+ACTION_SET_LOCAL_NAME(Action::KeyframeSetDelta,N_("Set Keyframe Delta"));
 ACTION_SET_TASK(Action::KeyframeSetDelta,"set");
 ACTION_SET_CATEGORY(Action::KeyframeSetDelta,Action::CATEGORY_KEYFRAME|Action::CATEGORY_HIDDEN);
 ACTION_SET_PRIORITY(Action::KeyframeSetDelta,0);
 ACTION_SET_VERSION(Action::KeyframeSetDelta,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeSetDelta,"$Id: keyframesetdelta.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::KeyframeSetDelta,"$Id: keyframesetdelta.cpp 1338 2008-01-12 17:49:10Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -125,7 +127,6 @@ Action::KeyframeSetDelta::prepare()
 	Time time(get_canvas()->keyframe_list().find(keyframe)->get_time());
 
 	std::vector<synfigapp::ValueDesc>::iterator iter;
-		DEBUGPOINT();
 	for(iter=value_desc_list.begin();iter!=value_desc_list.end();++iter)
 	{
 		ValueDesc& value_desc(*iter);
