@@ -2,7 +2,7 @@
 /*!	\file keyframewaypointset.cpp
 **	\brief Template File
 **
-**	$Id: keyframewaypointset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframewaypointset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -36,6 +36,8 @@
 #include "activepointsetsmart.h"
 #include "waypointsetsmart.h"
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -48,12 +50,12 @@ using namespace Action;
 
 ACTION_INIT(Action::KeyframeWaypointSet);
 ACTION_SET_NAME(Action::KeyframeWaypointSet,"keyframe_waypoint_set");
-ACTION_SET_LOCAL_NAME(Action::KeyframeWaypointSet,"Set Waypoints at Keyframe");
+ACTION_SET_LOCAL_NAME(Action::KeyframeWaypointSet,N_("Set Waypoints at Keyframe"));
 ACTION_SET_TASK(Action::KeyframeWaypointSet,"set");
 ACTION_SET_CATEGORY(Action::KeyframeWaypointSet,Action::CATEGORY_KEYFRAME);
 ACTION_SET_PRIORITY(Action::KeyframeWaypointSet,0);
 ACTION_SET_VERSION(Action::KeyframeWaypointSet,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeWaypointSet,"$Id: keyframewaypointset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::KeyframeWaypointSet,"$Id: keyframewaypointset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
