@@ -2,10 +2,11 @@
 /*!	\file layeractivate.cpp
 **	\brief Template File
 **
-**	$Id: layeractivate.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layeractivate.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "layeractivate.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -41,18 +44,15 @@ using namespace synfigapp;
 using namespace Action;
 
 /* === M A C R O S ========================================================= */
-#define ACTION_INIT2(class) \
-	Action::Base* class::create() { return new class(); }	\
-	synfig::String class::get_name()const { return name__; }
 
-ACTION_INIT2(Action::LayerActivate);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerActivate);
 ACTION_SET_NAME(Action::LayerActivate,"layer_activate");
-ACTION_SET_LOCAL_NAME(Action::LayerActivate,_("Activate Layer"));
+ACTION_SET_LOCAL_NAME(Action::LayerActivate,N_("Activate Layer"));
 ACTION_SET_TASK(Action::LayerActivate,"activate");
 ACTION_SET_CATEGORY(Action::LayerActivate,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerActivate,0);
 ACTION_SET_VERSION(Action::LayerActivate,"0.0");
-ACTION_SET_CVS_ID(Action::LayerActivate,"$Id: layeractivate.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerActivate,"$Id: layeractivate.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -69,13 +69,12 @@ Action::LayerActivate::get_local_name()const
 {
 	if(!layer)
 		return _("Activate Layer");
-	String name;
-	if(layer->get_description().empty())
-		name=layer->get_local_name();
-	else
-		name=layer->get_description();
 
-	return (new_status?_("Activate "):_("Deactivate "))+name;
+	return strprintf("%s '%s'",
+					 new_status
+					 ? _("Activate Layer")
+					 : _("Deactivate Layer"),
+					 layer->get_non_empty_description().c_str());
 }
 
 Action::ParamVocab
