@@ -2,10 +2,11 @@
 /*!	\file layeradd.cpp
 **	\brief Template File
 **
-**	$Id: layeradd.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layeradd.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "layeradd.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -42,14 +45,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::LayerAdd);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerAdd);
 ACTION_SET_NAME(Action::LayerAdd,"layer_add");
-ACTION_SET_LOCAL_NAME(Action::LayerAdd,"Add Layer");
+ACTION_SET_LOCAL_NAME(Action::LayerAdd,N_("Add Layer"));
 ACTION_SET_TASK(Action::LayerAdd,"add");
 ACTION_SET_CATEGORY(Action::LayerAdd,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerAdd,0);
 ACTION_SET_VERSION(Action::LayerAdd,"0.0");
-ACTION_SET_CVS_ID(Action::LayerAdd,"$Id: layeradd.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerAdd,"$Id: layeradd.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -61,6 +64,15 @@ Action::LayerAdd::LayerAdd()
 {
 }
 
+synfig::String
+Action::LayerAdd::get_local_name()const
+{
+	if (layer)
+		return strprintf("%s '%s'", _("Add Layer"), layer->get_local_name().c_str());
+	else
+		return _("Add Layer");
+}
+
 Action::ParamVocab
 Action::LayerAdd::get_param_vocab()
 {
