@@ -2,10 +2,11 @@
 /*!	\file layerduplicate.cpp
 **	\brief Template File
 **
-**	$Id: layerduplicate.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerduplicate.cpp 1711 2008-02-16 04:56:38Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -31,8 +32,11 @@
 
 #include "layerduplicate.h"
 #include "layeradd.h"
+#include <synfig/context.h>
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -43,14 +47,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::LayerDuplicate);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerDuplicate);
 ACTION_SET_NAME(Action::LayerDuplicate,"layer_duplicate");
-ACTION_SET_LOCAL_NAME(Action::LayerDuplicate,"Duplicate Layer");
+ACTION_SET_LOCAL_NAME(Action::LayerDuplicate,N_("Duplicate Layer"));
 ACTION_SET_TASK(Action::LayerDuplicate,"duplicate");
 ACTION_SET_CATEGORY(Action::LayerDuplicate,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerDuplicate,0);
 ACTION_SET_VERSION(Action::LayerDuplicate,"0.0");
-ACTION_SET_CVS_ID(Action::LayerDuplicate,"$Id: layerduplicate.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerDuplicate,"$Id: layerduplicate.cpp 1711 2008-02-16 04:56:38Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -62,6 +66,12 @@ Action::LayerDuplicate::LayerDuplicate()
 {
 }
 
+synfig::String
+Action::LayerDuplicate::get_local_name()const
+{
+	return get_layer_descriptions(layers, _("Duplicate Layer"), _("Duplicate Layers"));
+}
+
 Action::ParamVocab
 Action::LayerDuplicate::get_param_vocab()
 {
@@ -151,5 +161,62 @@ Action::LayerDuplicate::prepare()
 
 			add_action_front(action);
 		}
+
+		// automatically export the Index parameter of Duplicate layers when duplicating
+		int index = 1;
+		export_dup_nodes(new_layer, subcanvas, index);
+	}
+}
+
+void
+Action::LayerDuplicate::export_dup_nodes(synfig::Layer::Handle layer, Canvas::Handle canvas, int &index)
+{
+	// automatically export the Index parameter of Duplicate layers when duplicating
+	if (layer->get_name() == "duplicate")
+		while (true)
+		{
+			String name = strprintf(_("Index %d"), index++);
+			try
+			{
+				canvas->find_value_node(name);
+			}
+			catch (Exception::IDNotFound x)
+			{
+				Action::Handle action(Action::create("value_node_add"));
+
+				action->set_param("canvas",canvas);
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("new",layer->dynamic_param_list().find("index")->second);
+				action->set_param("name",name);
+
+				add_action_front(action);
+
+				break;
+			}
+		}
+	else
+	{
+		Layer::ParamList param_list(layer->get_param_list());
+		for (Layer::ParamList::const_iterator iter(param_list.begin())
+				 ; iter != param_list.end()
+				 ; iter++)
+			if (layer->dynamic_param_list().count(iter->first)==0 && iter->second.get_type()==ValueBase::TYPE_CANVAS)
+			{
+				Canvas::Handle subcanvas(iter->second.get(Canvas::Handle()));
+				if (subcanvas && subcanvas->is_inline())
+					for (Context iter = subcanvas->get_context(); iter != subcanvas->end(); iter++)
+						export_dup_nodes(*iter, canvas, index);
+			}
+
+		for (Layer::DynamicParamList::const_iterator iter(layer->dynamic_param_list().begin())
+				 ; iter != layer->dynamic_param_list().end()
+				 ; iter++)
+			if (iter->second->get_type()==ValueBase::TYPE_CANVAS)
+			{
+				Canvas::Handle canvas((*iter->second)(0).get(Canvas::Handle()));
+				if (canvas->is_inline())
+					//! \todo do we need to implement this?  and if so, shouldn't we check all canvases, not just the one at t=0s?
+					warning("%s:%d not yet implemented - do we need to export duplicate valuenodes in dynamic canvas parameters?", __FILE__, __LINE__);
+			}
 	}
 }
