@@ -2,10 +2,11 @@
 /*!	\file layerlower.cpp
 **	\brief Template File
 **
-**	$Id: layerlower.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerlower.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -33,6 +34,8 @@
 #include "layermove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -43,14 +46,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::LayerLower);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerLower);
 ACTION_SET_NAME(Action::LayerLower,"layer_lower");
-ACTION_SET_LOCAL_NAME(Action::LayerLower,"Lower Layer");
+ACTION_SET_LOCAL_NAME(Action::LayerLower,N_("Lower Layer"));
 ACTION_SET_TASK(Action::LayerLower,"lower");
 ACTION_SET_CATEGORY(Action::LayerLower,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerLower,10);
 ACTION_SET_VERSION(Action::LayerLower,"0.0");
-ACTION_SET_CVS_ID(Action::LayerLower,"$Id: layerlower.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerLower,"$Id: layerlower.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -62,6 +65,12 @@ Action::LayerLower::LayerLower()
 {
 }
 
+synfig::String
+Action::LayerLower::get_local_name()const
+{
+	return get_layer_descriptions(layers, _("Lower Layer"), _("Lower Layers"));
+}
+
 Action::ParamVocab
 Action::LayerLower::get_param_vocab()
 {
