@@ -2,7 +2,7 @@
 /*!	\file layerparamconnect.cpp
 **	\brief Template File
 **
-**	$Id: layerparamconnect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerparamconnect.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "layerparamconnect.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::LayerParamConnect);
 ACTION_SET_NAME(Action::LayerParamConnect,"layer_param_connect");
-ACTION_SET_LOCAL_NAME(Action::LayerParamConnect,_("Connect Layer Parameter"));
+ACTION_SET_LOCAL_NAME(Action::LayerParamConnect,N_("Connect Layer Parameter"));
 ACTION_SET_TASK(Action::LayerParamConnect,"connect");
 ACTION_SET_CATEGORY(Action::LayerParamConnect,Action::CATEGORY_LAYER|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::LayerParamConnect,0);
 ACTION_SET_VERSION(Action::LayerParamConnect,"0.0");
-ACTION_SET_CVS_ID(Action::LayerParamConnect,"$Id: layerparamconnect.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerParamConnect,"$Id: layerparamconnect.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -142,7 +144,7 @@ Action::LayerParamConnect::perform()
 
 	old_value=layer->get_param(param_name);
 	if(!old_value.is_valid())
-		throw Error(_("Layer did not recognise parameter name"));
+		throw Error(_("Layer did not recognize parameter name"));
 
 	if(!layer->set_param(param_name,(*value_node)(0)))
 		throw Error(_("Bad connection"));
