@@ -2,7 +2,7 @@
 /*!	\file layerparamdisconnect.cpp
 **	\brief Template File
 **
-**	$Id: layerparamdisconnect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerparamdisconnect.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,6 +33,8 @@
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenode_dynamiclist.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -45,12 +47,12 @@ using namespace Action;
 
 ACTION_INIT(Action::LayerParamDisconnect);
 ACTION_SET_NAME(Action::LayerParamDisconnect,"layer_param_disconnect");
-ACTION_SET_LOCAL_NAME(Action::LayerParamDisconnect,_("Disconnect Layer Parameter"));
+ACTION_SET_LOCAL_NAME(Action::LayerParamDisconnect,N_("Disconnect Layer Parameter"));
 ACTION_SET_TASK(Action::LayerParamDisconnect,"disconnect");
 ACTION_SET_CATEGORY(Action::LayerParamDisconnect,Action::CATEGORY_LAYER|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::LayerParamDisconnect,0);
 ACTION_SET_VERSION(Action::LayerParamDisconnect,"0.0");
-ACTION_SET_CVS_ID(Action::LayerParamDisconnect,"$Id: layerparamdisconnect.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerParamDisconnect,"$Id: layerparamdisconnect.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
