@@ -2,7 +2,7 @@
 /*!	\file layerparamset.cpp
 **	\brief Template File
 **
-**	$Id: layerparamset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerparamset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "layerparamset.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::LayerParamSet);
 ACTION_SET_NAME(Action::LayerParamSet,"layer_param_set");
-ACTION_SET_LOCAL_NAME(Action::LayerParamSet,_("Set Layer Parameter"));
+ACTION_SET_LOCAL_NAME(Action::LayerParamSet,N_("Set Layer Parameter"));
 ACTION_SET_TASK(Action::LayerParamSet,"set");
 ACTION_SET_CATEGORY(Action::LayerParamSet,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerParamSet,0);
 ACTION_SET_VERSION(Action::LayerParamSet,"0.0");
-ACTION_SET_CVS_ID(Action::LayerParamSet,"$Id: layerparamset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerParamSet,"$Id: layerparamset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
