@@ -2,10 +2,11 @@
 /*!	\file layerremove.cpp
 **	\brief Template File
 **
-**	$Id: layerremove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layerremove.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "layerremove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -42,14 +45,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::LayerRemove);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerRemove);
 ACTION_SET_NAME(Action::LayerRemove,"layer_remove");
-ACTION_SET_LOCAL_NAME(Action::LayerRemove,"Remove Layer");
+ACTION_SET_LOCAL_NAME(Action::LayerRemove,N_("Remove Layer"));
 ACTION_SET_TASK(Action::LayerRemove,"remove");
 ACTION_SET_CATEGORY(Action::LayerRemove,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerRemove,0);
 ACTION_SET_VERSION(Action::LayerRemove,"0.0");
-ACTION_SET_CVS_ID(Action::LayerRemove,"$Id: layerremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerRemove,"$Id: layerremove.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -61,6 +64,12 @@ Action::LayerRemove::LayerRemove()
 {
 }
 
+synfig::String
+Action::LayerRemove::get_local_name()const
+{
+	return get_layer_descriptions(layer_list, _("Remove Layer"), _("Remove Layers"));
+}
+
 Action::ParamVocab
 Action::LayerRemove::get_param_vocab()
 {
@@ -120,7 +129,7 @@ Action::LayerRemove::perform()
 		// If we couldn't find the layer in the canvas, then bail
 		if(*iter2!=layer)
 		{
-			/*!	\fixme We should really undo all prior removals
+			/*!	\todo We should really undo all prior removals
 			**	before we go throwing shit around */
 			throw Error(_("This layer doesn't exist anymore."));
 		}
@@ -130,7 +139,7 @@ Action::LayerRemove::perform()
 		// bail
 		if(get_canvas()!=subcanvas && !subcanvas->is_inline())
 		{
-			/*!	\fixme We should really undo all prior removals
+			/*!	\todo We should really undo all prior removals
 			**	before we go throwing shit around */
 			throw Error(_("This layer doesn't belong to this canvas anymore"));
 		}
