@@ -2,10 +2,11 @@
 /*!	\file layersetdesc.cpp
 **	\brief Template File
 **
-**	$Id: layersetdesc.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: layersetdesc.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "layersetdesc.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -42,14 +45,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::LayerSetDesc);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::LayerSetDesc);
 ACTION_SET_NAME(Action::LayerSetDesc,"layer_set_desc");
-ACTION_SET_LOCAL_NAME(Action::LayerSetDesc,_("Set Layer Description"));
+ACTION_SET_LOCAL_NAME(Action::LayerSetDesc,N_("Set Layer Description"));
 ACTION_SET_TASK(Action::LayerSetDesc,"set_desc");
 ACTION_SET_CATEGORY(Action::LayerSetDesc,Action::CATEGORY_LAYER);
 ACTION_SET_PRIORITY(Action::LayerSetDesc,0);
 ACTION_SET_VERSION(Action::LayerSetDesc,"0.0");
-ACTION_SET_CVS_ID(Action::LayerSetDesc,"$Id: layersetdesc.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::LayerSetDesc,"$Id: layersetdesc.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -63,6 +66,16 @@ Action::LayerSetDesc::LayerSetDesc()
 {
 }
 
+synfig::String
+Action::LayerSetDesc::get_local_name()const
+{
+	return strprintf("%s: '%s' -> '%s'",
+					 _("Set Layer Description"),
+					 /* TRANSLATORS: this is the string used in the history dialog when renaming a layer to/from its default name */
+					 old_description.empty() ? _("[default]") : old_description.c_str(),
+					 new_description.empty() ? _("[default]") : new_description.c_str());
+}
+
 Action::ParamVocab
 Action::LayerSetDesc::get_param_vocab()
 {
