@@ -2,7 +2,7 @@
 /*!	\file timepointsmove.cpp
 **	\brief Move the Time Points File
 **
-**	$Id: timepointsmove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: timepointsmove.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -41,6 +41,8 @@
 
 #include <typeinfo>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -53,12 +55,12 @@ using namespace Action;
 
 ACTION_INIT(Action::TimepointsMove);
 ACTION_SET_NAME(Action::TimepointsMove,"timepoint_move");
-ACTION_SET_LOCAL_NAME(Action::TimepointsMove,"Move Time Points");
+ACTION_SET_LOCAL_NAME(Action::TimepointsMove,N_("Move Time Points"));
 ACTION_SET_TASK(Action::TimepointsMove,"move");
 ACTION_SET_CATEGORY(Action::TimepointsMove,Action::CATEGORY_WAYPOINT|Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::TimepointsMove,0);
 ACTION_SET_VERSION(Action::TimepointsMove,"0.0");
-ACTION_SET_CVS_ID(Action::TimepointsMove,"$Id: timepointsmove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::TimepointsMove,"$Id: timepointsmove.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
