@@ -2,10 +2,11 @@
 /*!	\file valuedescconnect.cpp
 **	\brief Template File
 **
-**	$Id: valuedescconnect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuedescconnect.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -36,6 +37,8 @@
 #include "valuedescconnect.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -46,14 +49,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::ValueDescConnect);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescConnect);
 ACTION_SET_NAME(Action::ValueDescConnect,"value_desc_connect");
-ACTION_SET_LOCAL_NAME(Action::ValueDescConnect,"Connect");
+ACTION_SET_LOCAL_NAME(Action::ValueDescConnect,N_("Connect"));
 ACTION_SET_TASK(Action::ValueDescConnect,"connect");
 ACTION_SET_CATEGORY(Action::ValueDescConnect,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueDescConnect,0);
 ACTION_SET_VERSION(Action::ValueDescConnect,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescConnect,"$Id: valuedescconnect.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescConnect,"$Id: valuedescconnect.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -65,6 +68,15 @@ Action::ValueDescConnect::ValueDescConnect()
 {
 }
 
+synfig::String
+Action::ValueDescConnect::get_local_name()const
+{
+	// TRANSLATORS: This is used in the 'history' dialog when a connection is made.
+	return strprintf(_("Connect '%s' to '%s'"),
+					 value_desc.get_description(false).c_str(),
+					 value_node->get_id().c_str());
+}
+
 Action::ParamVocab
 Action::ValueDescConnect::get_param_vocab()
 {
@@ -93,6 +105,17 @@ Action::ValueDescConnect::is_candidate(const ParamList &x)
 {
 	if(candidate_check(get_param_vocab(),x))
 	{
+		// don't show the option of connecting to an existing Index parameter of the Duplicate layer
+		if(x.count("dest"))
+		{
+			ValueDesc value_desc=x.find("dest")->second.get_value_desc();
+
+			if (value_desc.parent_is_layer_param() &&
+				value_desc.get_layer()->get_name() == "duplicate" &&
+				value_desc.get_param_name() == "index")
+				return false;
+		}
+
 		if(x.count("src"))
 		{
 			ValueDesc value_desc=x.find("dest")->second.get_value_desc();
@@ -213,5 +236,5 @@ Action::ValueDescConnect::prepare()
 		return;
 	}
 
-	throw Error(_("ValueDesc is not recognised or supported."));
+	throw Error(_("ValueDesc is not recognized or supported."));
 }
