@@ -2,10 +2,11 @@
 /*!	\file valuedescconvert.cpp
 **	\brief Template File
 **
-**	$Id: valuedescconvert.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuedescconvert.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,6 +43,8 @@
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenode_const.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -52,14 +55,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::ValueDescConvert);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescConvert);
 ACTION_SET_NAME(Action::ValueDescConvert,"value_desc_convert");
-ACTION_SET_LOCAL_NAME(Action::ValueDescConvert,"Convert");
+ACTION_SET_LOCAL_NAME(Action::ValueDescConvert,N_("Convert"));
 ACTION_SET_TASK(Action::ValueDescConvert,"convert");
 ACTION_SET_CATEGORY(Action::ValueDescConvert,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ValueDescConvert,0);
 ACTION_SET_VERSION(Action::ValueDescConvert,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescConvert,"$Id: valuedescconvert.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescConvert,"$Id: valuedescconvert.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -69,6 +72,16 @@ ACTION_SET_CVS_ID(Action::ValueDescConvert,"$Id: valuedescconvert.cpp 336 2007-0
 
 Action::ValueDescConvert::ValueDescConvert()
 {
+	time=(Time::begin()-1);
+}
+
+synfig::String
+Action::ValueDescConvert::get_local_name()const
+{
+	// TRANSLATORS: This is used in the 'history' dialog when a ValueNode is converted.  The first %s is what is converted, the 2nd is the local name of the ValueNode's type.
+	return strprintf(_("Convert '%s' to ValueNode type '%s'"),
+					 value_desc.get_description().c_str(),
+					 LinkableValueNode::book()[type].local_name.c_str());
 }
 
 Action::ParamVocab
@@ -85,6 +98,10 @@ Action::ValueDescConvert::get_param_vocab()
 		.set_desc(_("The type of ValueNode that you want to be converted to"))
 	);
 
+	ret.push_back(ParamDesc("time",Param::TYPE_TIME)
+		.set_local_name(_("Time"))
+	);
+
 	return ret;
 }
 
@@ -111,6 +128,13 @@ Action::ValueDescConvert::set_param(const synfig::String& name, const Action::Pa
 		return true;
 	}
 
+	if(name=="time" && param.get_type()==Param::TYPE_TIME)
+	{
+		time=param.get_time();
+
+		return true;
+	}
+
 	return Action::CanvasSpecific::set_param(name,param);
 }
 
@@ -119,6 +143,11 @@ Action::ValueDescConvert::is_ready()const
 {
 	if(!value_desc || type.empty())
 		return false;
+	if(time==(Time::begin()-1))
+	{
+		synfig::error("Missing time");
+		return false;
+	}
 	return Action::CanvasSpecific::is_ready();
 }
 
@@ -132,7 +161,7 @@ Action::ValueDescConvert::prepare()
 	if(value_desc.is_const())
 		value=value_desc.get_value();
 	else if(value_desc.is_value_node())
-		value=(*value_desc.get_value_node())(0);
+		value=(*value_desc.get_value_node())(time);
 	else
 		throw Error(_("Unable to decipher ValueDesc (Bug?)"));
 
@@ -220,6 +249,6 @@ Action::ValueDescConvert::prepare()
 
 
 
-	throw Error(_("ValueDesc is not recognised or supported."));
+	throw Error(_("ValueDesc is not recognized or supported."));
 */
 }
