@@ -2,10 +2,11 @@
 /*!	\file valuedescdisconnect.cpp
 **	\brief Template File
 **
-**	$Id: valuedescdisconnect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuedescdisconnect.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -36,6 +37,9 @@
 #include "valuedescdisconnect.h"
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenode_const.h>
+#include <synfig/valuenode_duplicate.h>
+
+#include <synfigapp/general.h>
 
 #endif
 
@@ -47,14 +51,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::ValueDescDisconnect);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescDisconnect);
 ACTION_SET_NAME(Action::ValueDescDisconnect,"value_desc_disconnect");
-ACTION_SET_LOCAL_NAME(Action::ValueDescDisconnect,"Disconnect");
+ACTION_SET_LOCAL_NAME(Action::ValueDescDisconnect,N_("Disconnect"));
 ACTION_SET_TASK(Action::ValueDescDisconnect,"disconnect");
 ACTION_SET_CATEGORY(Action::ValueDescDisconnect,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ValueDescDisconnect,-100);
 ACTION_SET_VERSION(Action::ValueDescDisconnect,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescDisconnect,"$Id: valuedescdisconnect.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescDisconnect,"$Id: valuedescdisconnect.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -67,6 +71,16 @@ Action::ValueDescDisconnect::ValueDescDisconnect():
 {
 }
 
+synfig::String
+Action::ValueDescDisconnect::get_local_name()const
+{
+  // TRANSLATORS: This is used in the History dialog when a ValueNode is disconnected.
+  return strprintf(_("Disconnect %s"),
+                   value_desc
+                   ? value_desc.get_description().c_str()
+                   : _("ValueDesc"));
+}
+
 Action::ParamVocab
 Action::ValueDescDisconnect::get_param_vocab()
 {
@@ -90,12 +104,22 @@ Action::ValueDescDisconnect::is_candidate(const ParamList &x)
 	if(candidate_check(get_param_vocab(),x))
 	{
 		ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
+
+		// don't allow the Index parameter of the Duplicate layer to be disconnected
+		if(value_desc.parent_is_layer_param() && value_desc.get_layer()->get_name() == "duplicate" && value_desc.get_param_name() == "index")
+			return false;
 		if(!value_desc.parent_is_canvas() && value_desc.is_value_node() && value_desc.get_value_node()->rcount()>1)
 			return true;
 		if(value_desc.is_const())
 			return false;
 		if(value_desc.is_value_node() && ValueNode_Const::Handle::cast_dynamic(value_desc.get_value_node()))
 			return false;
+		// don't allow Duplicate ValueNodes in the Children dialog to be disconnected
+		if(value_desc.is_value_node() &&
+		   ValueNode_Duplicate::Handle::cast_dynamic(value_desc.get_value_node()) &&
+		   !value_desc.parent_is_layer_param() &&
+		   !value_desc.parent_is_value_node())
+			return false;
 		return true;
 	}
 	return false;
@@ -190,5 +214,5 @@ Action::ValueDescDisconnect::prepare()
 		return;
 	}
 
-	throw Error(_("ValueDesc is not recognised or supported."));
+	throw Error(_("ValueDesc is not recognized or supported."));
 }
