@@ -2,10 +2,11 @@
 /*!	\file valuedesclink.h
 **	\brief Template File
 **
-**	$Id: valuedesclink.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuedesclink.h 848 2007-10-06 02:25:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -49,6 +50,8 @@ private:
 	std::list<ValueDesc> value_desc_list;
 	synfig::ValueNode::Handle link_value_node;
 	bool poison;
+	int status_level;
+	synfig::String status_message;
 	synfig::Time time;
 public:
 
