@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistinsert.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistinsert.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodedynamiclistinsert.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "valuenodedynamiclistinsert.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeDynamicListInsert);
 ACTION_SET_NAME(Action::ValueNodeDynamicListInsert,"value_node_dynamic_list_insert");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListInsert,"Insert Item");
+ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListInsert,N_("Insert Item"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListInsert,"insert");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListInsert,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE|Action::CATEGORY_HIDDEN);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListInsert,-20);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListInsert,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListInsert,"$Id: valuenodedynamiclistinsert.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListInsert,"$Id: valuenodedynamiclistinsert.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
