@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistloop.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistloop.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodedynamiclistloop.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "valuenodedynamiclistloop.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeDynamicListLoop);
 ACTION_SET_NAME(Action::ValueNodeDynamicListLoop,"value_node_dynamic_list_loop");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListLoop,"Loop");
+ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListLoop,N_("Loop"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListLoop,"loop");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListLoop,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListLoop,0);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListLoop,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListLoop,"$Id: valuenodedynamiclistloop.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListLoop,"$Id: valuenodedynamiclistloop.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
