@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistremovesmart.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistremovesmart.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodedynamiclistremovesmart.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,6 +33,8 @@
 #include "valuenodedynamiclistremove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -45,12 +47,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeDynamicListRemoveSmart);
 ACTION_SET_NAME(Action::ValueNodeDynamicListRemoveSmart,"value_node_dynamic_list_remove_smart");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListRemoveSmart,"Remove Item (Smart)");
+ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListRemoveSmart,N_("Remove Item (Smart)"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListRemoveSmart,"remove");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListRemoveSmart,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListRemoveSmart,-19);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListRemoveSmart,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemoveSmart,"$Id: valuenodedynamiclistremovesmart.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRemoveSmart,"$Id: valuenodedynamiclistremovesmart.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
