@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistrotateorder.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistrotateorder.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodedynamiclistrotateorder.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "valuenodedynamiclistrotateorder.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeDynamicListRotateOrder);
 ACTION_SET_NAME(Action::ValueNodeDynamicListRotateOrder,"value_node_dynamic_list_rotate_order");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListRotateOrder,"Rotate Order");
+ACTION_SET_LOCAL_NAME(Action::ValueNodeDynamicListRotateOrder,N_("Rotate Order"));
 ACTION_SET_TASK(Action::ValueNodeDynamicListRotateOrder,"rotate");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListRotateOrder,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListRotateOrder,0);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListRotateOrder,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRotateOrder,"$Id: valuenodedynamiclistrotateorder.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListRotateOrder,"$Id: valuenodedynamiclistrotateorder.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
