@@ -2,7 +2,7 @@
 /*!	\file valuenodelinkconnect.cpp
 **	\brief Template File
 **
-**	$Id: valuenodelinkconnect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodelinkconnect.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "valuenodelinkconnect.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeLinkConnect);
 ACTION_SET_NAME(Action::ValueNodeLinkConnect,"value_node_link_connect");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeLinkConnect,_("Connect ValueNode Link"));
+ACTION_SET_LOCAL_NAME(Action::ValueNodeLinkConnect,N_("Connect ValueNode Link"));
 ACTION_SET_TASK(Action::ValueNodeLinkConnect,"connect");
 ACTION_SET_CATEGORY(Action::ValueNodeLinkConnect,Action::CATEGORY_LAYER|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeLinkConnect,0);
 ACTION_SET_VERSION(Action::ValueNodeLinkConnect,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeLinkConnect,"$Id: valuenodelinkconnect.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeLinkConnect,"$Id: valuenodelinkconnect.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
