@@ -2,7 +2,7 @@
 /*!	\file valuenodelinkdisconnect.cpp
 **	\brief Template File
 **
-**	$Id: valuenodelinkdisconnect.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodelinkdisconnect.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,6 +33,8 @@
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenode_const.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -45,12 +47,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeLinkDisconnect);
 ACTION_SET_NAME(Action::ValueNodeLinkDisconnect,"value_node_link_disconnect");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeLinkDisconnect,_("Disconnect ValueNode Link"));
+ACTION_SET_LOCAL_NAME(Action::ValueNodeLinkDisconnect,N_("Disconnect ValueNode Link"));
 ACTION_SET_TASK(Action::ValueNodeLinkDisconnect,"disconnect");
 ACTION_SET_CATEGORY(Action::ValueNodeLinkDisconnect,Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeLinkDisconnect,0);
 ACTION_SET_VERSION(Action::ValueNodeLinkDisconnect,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeLinkDisconnect,"$Id: valuenodelinkdisconnect.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeLinkDisconnect,"$Id: valuenodelinkdisconnect.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
