@@ -2,10 +2,11 @@
 /*!	\file valuenoderemove.cpp
 **	\brief Template File
 **
-**	$Id: valuenoderemove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenoderemove.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "valuenoderemove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -42,14 +45,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::ValueNodeRemove);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueNodeRemove);
 ACTION_SET_NAME(Action::ValueNodeRemove,"value_node_remove");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeRemove,_("Unexport"));
+ACTION_SET_LOCAL_NAME(Action::ValueNodeRemove,N_("Unexport"));
 ACTION_SET_TASK(Action::ValueNodeRemove,"remove");
 ACTION_SET_CATEGORY(Action::ValueNodeRemove,Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeRemove,0);
 ACTION_SET_VERSION(Action::ValueNodeRemove,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeRemove,"$Id: valuenoderemove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeRemove,"$Id: valuenoderemove.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -61,6 +64,13 @@ Action::ValueNodeRemove::ValueNodeRemove()
 {
 }
 
+synfig::String
+Action::ValueNodeRemove::get_local_name()const
+{
+	// TRANSLATORS: This is used in the 'history' dialog when a ValueNode is unexported.
+	return strprintf(_("Unexport '%s'"), old_name.c_str());
+}
+
 Action::ParamVocab
 Action::ValueNodeRemove::get_param_vocab()
 {
