@@ -2,10 +2,11 @@
 /*!	\file valuenoderename.cpp
 **	\brief Template File
 **
-**	$Id: valuenoderename.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenoderename.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -32,6 +33,8 @@
 #include "valuenoderename.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -42,14 +45,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::ValueNodeRename);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueNodeRename);
 ACTION_SET_NAME(Action::ValueNodeRename,"value_node_rename");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeRename,_("Rename ValueNode"));
+ACTION_SET_LOCAL_NAME(Action::ValueNodeRename,N_("Rename ValueNode"));
 ACTION_SET_TASK(Action::ValueNodeRename,"rename");
 ACTION_SET_CATEGORY(Action::ValueNodeRename,Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeRename,0);
 ACTION_SET_VERSION(Action::ValueNodeRename,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeRename,"$Id: valuenoderename.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeRename,"$Id: valuenoderename.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -61,6 +64,15 @@ Action::ValueNodeRename::ValueNodeRename()
 {
 }
 
+synfig::String
+Action::ValueNodeRename::get_local_name()const
+{
+	// TRANSLATORS: This is used in the 'history' dialog when a ValueNode is renamed.
+	return strprintf(_("Rename ValueNode from '%s' to '%s'"),
+					 old_name.c_str(),
+					 new_name.c_str());
+}
+
 Action::ParamVocab
 Action::ValueNodeRename::get_param_vocab()
 {
@@ -144,7 +156,7 @@ Action::ValueNodeRename::perform()
 
 	if(get_canvas_interface())
 	{
-		get_canvas_interface()->signal_value_node_changed()(value_node);
+		get_canvas_interface()->signal_value_node_renamed()(value_node);
 	}
 }
 
@@ -160,6 +172,6 @@ Action::ValueNodeRename::undo()
 
 	if(get_canvas_interface())
 	{
-		get_canvas_interface()->signal_value_node_changed()(value_node);
+		get_canvas_interface()->signal_value_node_renamed()(value_node);
 	}
 }
