@@ -2,7 +2,7 @@
 /*!	\file waypointadd.cpp
 **	\brief Template File
 **
-**	$Id: waypointadd.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: waypointadd.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,6 +33,8 @@
 #include <synfigapp/canvasinterface.h>
 #include <synfigapp/main.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -45,12 +47,12 @@ using namespace Action;
 
 ACTION_INIT(Action::WaypointAdd);
 ACTION_SET_NAME(Action::WaypointAdd,"waypoint_add");
-ACTION_SET_LOCAL_NAME(Action::WaypointAdd,"Add Waypoint");
+ACTION_SET_LOCAL_NAME(Action::WaypointAdd,N_("Add Waypoint"));
 ACTION_SET_TASK(Action::WaypointAdd,"add");
 ACTION_SET_CATEGORY(Action::WaypointAdd,Action::CATEGORY_WAYPOINT);
 ACTION_SET_PRIORITY(Action::WaypointAdd,0);
 ACTION_SET_VERSION(Action::WaypointAdd,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointAdd,"$Id: waypointadd.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::WaypointAdd,"$Id: waypointadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
