@@ -2,7 +2,7 @@
 /*!	\file waypointremove.cpp
 **	\brief Template File
 **
-**	$Id: waypointremove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: waypointremove.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "waypointremove.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::WaypointRemove);
 ACTION_SET_NAME(Action::WaypointRemove,"waypoint_remove");
-ACTION_SET_LOCAL_NAME(Action::WaypointRemove,"Remove Waypoint");
+ACTION_SET_LOCAL_NAME(Action::WaypointRemove,N_("Remove Waypoint"));
 ACTION_SET_TASK(Action::WaypointRemove,"remove");
 ACTION_SET_CATEGORY(Action::WaypointRemove,Action::CATEGORY_WAYPOINT);
 ACTION_SET_PRIORITY(Action::WaypointRemove,0);
 ACTION_SET_VERSION(Action::WaypointRemove,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointRemove,"$Id: waypointremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::WaypointRemove,"$Id: waypointremove.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
