@@ -2,7 +2,7 @@
 /*!	\file waypointset.cpp
 **	\brief Template File
 **
-**	$Id: waypointset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: waypointset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "waypointset.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::WaypointSet);
 ACTION_SET_NAME(Action::WaypointSet,"waypoint_set");
-ACTION_SET_LOCAL_NAME(Action::WaypointSet,"Set Waypoint");
+ACTION_SET_LOCAL_NAME(Action::WaypointSet,N_("Set Waypoint"));
 ACTION_SET_TASK(Action::WaypointSet,"set");
 ACTION_SET_CATEGORY(Action::WaypointSet,Action::CATEGORY_WAYPOINT);
 ACTION_SET_PRIORITY(Action::WaypointSet,0);
 ACTION_SET_VERSION(Action::WaypointSet,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointSet,"$Id: waypointset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::WaypointSet,"$Id: waypointset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -172,7 +174,7 @@ Action::WaypointSet::perform()
 		}
 	}
 
-	//remove all the points we're supposed to be overwritting
+	//remove all the points we're supposed to be overwriting
 	{
 		vector<Waypoint>::iterator 	oi = overwritten_waypoints.begin(),
 									oend = overwritten_waypoints.end();
