@@ -2,7 +2,7 @@
 /*!	\file waypointsimpleadd.cpp
 **	\brief Simple add waypoint File
 **
-**	$Id: waypointsimpleadd.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: waypointsimpleadd.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -32,6 +32,8 @@
 #include "waypointsimpleadd.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::WaypointSimpleAdd);
 ACTION_SET_NAME(Action::WaypointSimpleAdd,"waypoint_simpleadd");
-ACTION_SET_LOCAL_NAME(Action::WaypointSimpleAdd,"Simply Add Waypoint");
+ACTION_SET_LOCAL_NAME(Action::WaypointSimpleAdd,N_("Simply Add Waypoint"));
 ACTION_SET_TASK(Action::WaypointSimpleAdd,"add");
 ACTION_SET_CATEGORY(Action::WaypointSimpleAdd,Action::CATEGORY_WAYPOINT);
 ACTION_SET_PRIORITY(Action::WaypointSimpleAdd,0);
 ACTION_SET_VERSION(Action::WaypointSimpleAdd,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointSimpleAdd,"$Id: waypointsimpleadd.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::WaypointSimpleAdd,"$Id: waypointsimpleadd.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
