@@ -2,7 +2,7 @@
 /*!	\file blineconvert.h
 **	\brief Template Header
 **
-**	$Id: blineconvert.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: blineconvert.h 1688 2008-02-13 11:52:59Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -57,7 +57,7 @@ public:
 		:curind(o.curind), tangentscale(o.tangentscale), error(o.error)
 		{}
 
-		const cpindex & operator = (const cpindex & rhs)
+		const cpindex & operator=(const cpindex & rhs)
 		{
 			curind = rhs.curind;
 			tangentscale = rhs.tangentscale;
@@ -65,7 +65,7 @@ public:
 			return *this;
 		}
 
-		bool operator < (const cpindex &rhs) const
+		bool operator<(const cpindex &rhs) const
 		{
 			return curind < rhs.curind;
 		}
@@ -76,19 +76,19 @@ public:
 
 private:
 	//cached data
-	std::vector<synfig::Point>	f;	//the preprocessed input cache
-	std::vector<synfig::Real>	f_w;
+	std::vector<synfig::Point>	point_cache;	//the preprocessed input cache
+	std::vector<synfig::Real>	width_cache;
 
 	//temporary point storage for vector calc
 	std::vector<synfig::Point>	ftemp;
 
-	std::vector<synfig::Vector>	df; //the derivative cache
-	std::vector<synfig::Real>	cvt; //the curvature cache
+	std::vector<synfig::Vector>	deriv; //the derivative cache
+	std::vector<synfig::Real>	curvature; //the curvature cache
 
-	std::vector<int>			brk; //the break point cache
+	std::vector<int>			break_tangents; //the break point cache
 
-	std::vector<synfig::Real> 	di,	//cumulative distance
-								d_i; //distance between adjacent segments
+	std::vector<synfig::Real> 	cum_dist,	//cumulative distance
+								this_dist; //distance between adjacent segments
 
 	std::vector<synfig::Point>	work; //the working point cache for the entire curve
 	std::vector<cpindex> 		curind;
@@ -106,7 +106,7 @@ public:
 	BLineConverter();
 
 	static void EnforceMinWidth(std::list<synfig::BLinePoint> &bline, synfig::Real min_pressure);
-	void operator ()(std::list<synfig::BLinePoint> &out, const std::list<synfig::Point> &in,const std::list<synfig::Real> &in_w);
+	void operator()(std::list<synfig::BLinePoint> &out, const std::list<synfig::Point> &in,const std::list<synfig::Real> &in_w);
 };
 
 }; // END of namespace synfigapp
