@@ -2,11 +2,11 @@
 /*!	\file canvasinterface.cpp
 **	\brief Template File
 **
-**	$Id: canvasinterface.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: canvasinterface.cpp 1764 2008-02-19 18:51:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -41,6 +41,7 @@
 #include <synfig/valuenode_reference.h>
 #include <synfig/valuenode_twotone.h>
 #include <synfig/valuenode_stripes.h>
+#include <synfig/valuenode_bline.h>
 
 #include <synfig/waypoint.h>
 #include <synfig/loadcanvas.h>
@@ -60,6 +61,8 @@
 
 #include <synfig/gradient.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -77,7 +80,7 @@ using namespace synfigapp;
 
 /* === M E T H O D S ======================================================= */
 
-CanvasInterface::CanvasInterface(loose_handle<Instance> instance,handle<Canvas> canvas):
+CanvasInterface::CanvasInterface(etl::loose_handle<Instance> instance,etl::handle<synfig::Canvas> canvas):
 	instance_(instance),
 	canvas_(canvas),
 	cur_time_(canvas->rend_desc().get_frame_start()),
@@ -89,7 +92,8 @@ CanvasInterface::CanvasInterface(loose_handle<Instance> instance,handle<Canvas>
 
 CanvasInterface::~CanvasInterface()
 {
-	synfig::info("synfigapp::CanvasInterface::~CanvasInterface(): Deleted");
+	if (getenv("SYNFIG_DEBUG_DESTRUCTORS"))
+		synfig::info("CanvasInterface::~CanvasInterface(): Deleted");
 }
 
 void
@@ -108,8 +112,9 @@ CanvasInterface::set_time(synfig::Time x)
 
 	// update the time in all the child canvases
 	Canvas::Children children = get_canvas()->get_root()->children();
+	handle<CanvasInterface> interface;
 	for (Canvas::Children::iterator iter = children.begin(); iter != children.end(); iter++)
-		if (handle<CanvasInterface> interface = get_instance()->find_canvas_interface(*iter))
+		if ((interface = get_instance()->find_canvas_interface(*iter)) != this)
 			interface->set_time(interface->get_canvas()->get_time());
 
 	signal_time_changed()();
@@ -131,7 +136,7 @@ CanvasInterface::refresh_current_values()
 }
 
 etl::handle<CanvasInterface>
-CanvasInterface::create(loose_handle<Instance> instance,handle<Canvas> canvas)
+CanvasInterface::create(etl::loose_handle<Instance> instance, etl::handle<synfig::Canvas> canvas)
 {
 	etl::handle<CanvasInterface> intrfc;
 	intrfc=new CanvasInterface(instance,canvas);
@@ -173,7 +178,7 @@ CanvasInterface::get_mode()const
 
 
 Layer::Handle
-CanvasInterface::add_layer_to(String name, Canvas::Handle canvas, int depth)
+CanvasInterface::add_layer_to(synfig::String name, synfig::Canvas::Handle canvas, int depth)
 {
 	synfigapp::Action::PassiveGrouper group(get_instance().get(),_("Add Layer To"));
 
@@ -190,6 +195,22 @@ CanvasInterface::add_layer_to(String name, Canvas::Handle canvas, int depth)
 		return 0;
 	}
 
+	// automatically export the Index parameter of new Duplicate layers
+	if (name == "duplicate")
+		for (int i = 1; ; i++)
+		{
+			String name = strprintf(_("Index %d"), i);
+			try
+			{
+				canvas->find_value_node(name);
+			}
+			catch (Exception::IDNotFound x)
+			{
+				add_value_node(layer->dynamic_param_list().find("index")->second, name);
+				break;
+			}
+		}
+
 	layer->set_canvas(canvas);
 
 	// Apply some defaults
@@ -205,18 +226,45 @@ CanvasInterface::add_layer_to(String name, Canvas::Handle canvas, int depth)
 	layer->set_param("blend_method",synfigapp::Main::get_blend_method());
 
 	{
-		// Grab the layer's list pf parameters
+		// Grab the layer's list of parameters
 		Layer::ParamList paramlist=layer->get_param_list();
 		Layer::ParamList::iterator iter;
+
+		// loop through the static parameters
 		for(iter=paramlist.begin();iter!=paramlist.end();++iter)
 		{
 			ValueNode::Handle value_node;
 
+			// if we find any which are list values then make them
+			// into dynamic list valuenodes, unless every element of
+			// the list is a blinepoint, in which case convert it to a
+			// bline
 			if(iter->second.get_type()==ValueBase::TYPE_LIST)
-				value_node=LinkableValueNode::create("dynamic_list",iter->second);
+			{
+				// check whether it's a list of blinepoints only
+				vector<ValueBase> list(iter->second.get_list());
+				if (list.size())
+				{
+					vector<ValueBase>::iterator iter2;
+					for (iter2 = list.begin(); iter2 != list.end(); iter2++)
+						if (iter2->get_type() != ValueBase::TYPE_BLINEPOINT)
+							break;
+					if (iter2 == list.end())
+					{
+						value_node=LinkableValueNode::create("bline",iter->second);
+						ValueNode_BLine::Handle::cast_dynamic(value_node)->set_member_canvas(canvas);
+					}
+				}
+
+				if (!value_node)
+					value_node=LinkableValueNode::create("dynamic_list",iter->second);
+			}
+			// otherwise, if it's a type that can be converted to
+			// 'composite' (other than the types that can be radial
+			// composite) then do so
 			else if(LinkableValueNode::check_type("composite",iter->second.get_type()) &&
-				(iter->second.get_type()!=ValueBase::TYPE_COLOR && iter->second.get_type()!=ValueBase::TYPE_VECTOR)
-			)
+					 (iter->second.get_type()!=ValueBase::TYPE_COLOR &&
+					  iter->second.get_type()!=ValueBase::TYPE_VECTOR))
 				value_node=LinkableValueNode::create("composite",iter->second);
 
 			if(value_node)
@@ -247,7 +295,8 @@ CanvasInterface::add_layer_to(String name, Canvas::Handle canvas, int depth)
 		return 0;
 	}
 
-	synfig::info("DEPTH=%d",depth);
+	// synfig::info("DEPTH=%d",depth);
+
 	// Action to move the layer (if necessary)
 	if(depth>0)
 	{
@@ -281,7 +330,7 @@ CanvasInterface::add_layer_to(String name, Canvas::Handle canvas, int depth)
 
 
 bool
-CanvasInterface::convert(ValueDesc value_desc, String type)
+CanvasInterface::convert(ValueDesc value_desc, synfig::String type)
 {
 	Action::Handle 	action(Action::ValueDescConvert::create());
 
@@ -293,6 +342,7 @@ CanvasInterface::convert(ValueDesc value_desc, String type)
 	action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
 	action->set_param("value_desc",value_desc);
 	action->set_param("type",type);
+	action->set_param("time",get_time());
 
 	if(!action->is_ready())
 	{
@@ -357,7 +407,18 @@ CanvasInterface::generate_param_list(const ValueDesc &value_desc)
 		param_list.add("value_node",value_desc.get_value_node());
 
 	if(value_desc.is_const())
-		param_list.add("value",value_desc.get_value());
+	{
+		// Fix 1868911: if we put a ValueBase holding a Canvas handle
+		// into the param_list and then export the canvas, the handle
+		// will miss out of having its reference count reduced,
+		// because by the time the handle is destructed the canvas
+		// will no longer be inline.  So let's not propogate that
+		// ValueBase any further than here.
+		if (value_desc.get_value_type() == ValueBase::TYPE_CANVAS)
+			param_list.add("value",Canvas::LooseHandle(value_desc.get_value().get(Canvas::LooseHandle())));
+		else
+			param_list.add("value",value_desc.get_value());
+	}
 
 	if(value_desc.parent_is_layer_param())
 	{
@@ -417,7 +478,7 @@ CanvasInterface::set_rend_desc(const synfig::RendDesc &rend_desc)
 }
 
 bool
-CanvasInterface::set_name(const String &x)
+CanvasInterface::set_name(const synfig::String &x)
 {
 	//! \todo This needs to be converted into an action
 	get_canvas()->set_name(x);
@@ -426,7 +487,7 @@ CanvasInterface::set_name(const String &x)
 }
 
 bool
-CanvasInterface::set_description(const String &x)
+CanvasInterface::set_description(const synfig::String &x)
 {
 	//! \todo This needs to be converted into an action
 	get_canvas()->set_description(x);
@@ -434,7 +495,7 @@ CanvasInterface::set_description(const String &x)
 }
 
 bool
-CanvasInterface::set_id(const String &x)
+CanvasInterface::set_id(const synfig::String &x)
 {
 	//! \todo This needs to be converted into an action
 	get_canvas()->set_id(x);
@@ -476,14 +537,14 @@ CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 
 	synfig::info("Attempting to import "+filename);
 
-
-	if(find(filename.begin(),filename.end(),'.')==filename.end())
+	if (filename_extension(filename) == "")
 	{
-		get_ui_interface()->error("Filename must have an extension!");
+		get_ui_interface()->error(_("Filename must have an extension!"));
 		return false;
 	}
 
-	String ext(String(filename.begin()+filename.find_last_of('.')+1,filename.end()));
+	String ext(filename_extension(filename));
+	if (ext.size()) ext = ext.substr(1); // skip initial '.'
 	std::transform(ext.begin(),ext.end(),ext.begin(),&::tolower);
 
 	// If this is a SIF file, then we need to do things slightly differently
@@ -539,14 +600,14 @@ CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 			{
 				x[0]=size[0];
 				x[1]=size[0]/w*h;
-				if(size[0]<0 ^ size[1]<0)
+				if((size[0]<0) ^ (size[1]<0))
 					x[1]=-x[1];
 			}
 			else
 			{
 				x[1]=size[1];
 				x[0]=size[1]/h*w;
-				if(size[0]<0 ^ size[1]<0)
+				if((size[0]<0) ^ (size[1]<0))
 					x[0]=-x[0];
 			}
 			if(!layer->set_param("tl",ValueBase(-x/2)))
@@ -578,6 +639,13 @@ CanvasInterface::import(const synfig::String &filename, bool /*copy*/)
 
 void
 CanvasInterface::waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint)
+{
+	ValueNode::Handle value_node();
+	waypoint_duplicate(value_desc.get_value_node(), waypoint);
+}
+
+void
+CanvasInterface::waypoint_duplicate(ValueNode::Handle value_node,synfig::Waypoint waypoint)
 {
 	Action::Handle 	action(Action::create("waypoint_set_smart"));
 
@@ -588,8 +656,6 @@ CanvasInterface::waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Wayp
 	waypoint.make_unique();
 	waypoint.set_time(get_time());
 
-	ValueNode::Handle value_node(value_desc.get_value_node());
-
 	action->set_param("canvas",get_canvas());
 	action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
 	action->set_param("waypoint",waypoint);
@@ -602,6 +668,13 @@ CanvasInterface::waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Wayp
 
 void
 CanvasInterface::waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint)
+{
+	ValueNode::Handle value_node();
+	waypoint_remove(value_desc.get_value_node(), waypoint);
+}
+
+void
+CanvasInterface::waypoint_remove(ValueNode::Handle value_node,synfig::Waypoint waypoint)
 {
 	Action::Handle 	action(Action::create("waypoint_remove"));
 
@@ -609,8 +682,6 @@ CanvasInterface::waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoin
 	if(!action)
 		return;
 
-	ValueNode::Handle value_node(value_desc.get_value_node());
-
 	action->set_param("canvas",get_canvas());
 	action->set_param("canvas_interface",etl::loose_handle<CanvasInterface>(this));
 	action->set_param("waypoint",waypoint);
@@ -622,7 +693,7 @@ CanvasInterface::waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoin
 
 
 void
-CanvasInterface::auto_export(ValueNode::Handle /*value_node*/)
+CanvasInterface::auto_export(synfig::ValueNode::Handle /*value_node*/)
 {
 /*
 	// Check to see if we are already exported.
@@ -682,19 +753,22 @@ CanvasInterface::change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase
 		return true;
 
 	// If this change needs to take place elsewhere, then so be it.
-	if(value_desc.get_canvas() && value_desc.get_canvas()->get_root()!=get_canvas()->get_root())do
+	if(value_desc.get_canvas())
 	{
-		etl::handle<Instance> instance;
-		instance=find_instance(value_desc.get_canvas()->get_root());
-
-		if(instance)
-			return instance->find_canvas_interface(value_desc.get_canvas())->change_value(value_desc,new_value);
-		else
+		if (value_desc.get_canvas()->get_root() != get_canvas()->get_root())
 		{
-			get_ui_interface()->error(_("The value you are trying to edit is in a composition\nwhich doesn't seem to be open. Open that composition and you\nshould be able to edit this value as normal."));
-			return false;
+			etl::handle<Instance> instance;
+			instance=find_instance(value_desc.get_canvas()->get_root());
+
+			if(instance)
+				return instance->find_canvas_interface(value_desc.get_canvas())->change_value(value_desc,new_value);
+			else
+			{
+				get_ui_interface()->error(_("The value you are trying to edit is in a composition\nwhich doesn't seem to be open. Open that composition and you\nshould be able to edit this value as normal."));
+				return false;
+			}
 		}
-	}while(0);
+	}
 #ifdef _DEBUG
 	else
 	{ synfig::warning("Can't get canvas from value desc...?"); }
