@@ -2,10 +2,11 @@
 /*!	\file canvasinterface.h
 **	\brief Template Header
 **
-**	$Id: canvasinterface.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: canvasinterface.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -85,7 +86,6 @@ private:
 
 	sigc::signal<void,synfig::ValueNode::Handle> signal_value_node_added_;
 	sigc::signal<void,synfig::ValueNode::Handle> signal_value_node_deleted_;
-	sigc::signal<void,synfig::ValueNode::Handle> signal_value_node_changed_;
 	sigc::signal<void,synfig::ValueNode::Handle,synfig::ValueNode::Handle> signal_value_node_replaced_;
 
 	sigc::signal<void,synfig::Keyframe> signal_keyframe_added_;
@@ -151,7 +151,9 @@ public:	// Signal Interface
 
 	//! Signal called when a ValueNode has been changed
 	sigc::signal<void,etl::handle<synfig::ValueNode> >& signal_value_node_changed() { return get_canvas()->signal_value_node_changed(); }
-	//sigc::signal<void,etl::handle<synfig::ValueNode> >& signal_value_node_changed() { return signal_value_node_changed_; }
+
+	//! Signal called when a ValueNode has been renamed
+	sigc::signal<void,etl::handle<synfig::ValueNode> >& signal_value_node_renamed() { return get_canvas()->signal_value_node_renamed(); }
 
 	//! Signal called when the mode has changed
 	sigc::signal<void,Mode> signal_mode_changed() { return signal_mode_changed_; }
@@ -217,13 +219,13 @@ public:
 	//! Changes the ID of the canvas. Undoable.
 	bool set_id(const synfig::String &x);
 
-	//! Convience function to retrieve the name of the canvas
+	//! Convenience function to retrieve the name of the canvas
 	synfig::String get_name()const { return get_canvas()->get_name(); }
 
-	//! Convience function to retrieve the description of the canvas
+	//! Convenience function to retrieve the description of the canvas
 	synfig::String get_description()const { return get_canvas()->get_description(); }
 
-	//! Convience function to retrieve the ID of the canvas
+	//! Convenience function to retrieve the ID of the canvas
 	synfig::String get_id()const { return get_canvas()->get_id(); }
 
 	//! Sets the current time
@@ -273,8 +275,10 @@ public:
 
 
 	void waypoint_duplicate(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint);
+	void waypoint_duplicate(synfig::ValueNode::Handle value_node,synfig::Waypoint waypoint);
 
 	void waypoint_remove(synfigapp::ValueDesc value_desc,synfig::Waypoint waypoint);
+	void waypoint_remove(synfig::ValueNode::Handle value_node,synfig::Waypoint waypoint);
 
 	bool change_value(synfigapp::ValueDesc value_desc,synfig::ValueBase new_value);
 
