@@ -2,7 +2,7 @@
 /*!	\file editmode.h
 **	\brief Template Header
 **
-**	$Id: editmode.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: editmode.h 1481 2008-01-25 15:41:45Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -74,9 +74,9 @@ operator&(const EditMode& lhs, const EditMode& rhs)
 //!	Flag Comparison. THIS IS NOT LESS-THAN-OR-EQUAL-TO.
 /*!	This function will return true of all of the flags
 **	in the \a rhs are set in the \a lhs */
-inline bool
-operator<=(const EditMode& lhs, const EditMode& rhs)
-{ return lhs&rhs==int(rhs); }
+// inline bool
+// operator<=(const EditMode& lhs, const EditMode& rhs)
+// { return (lhs&rhs)==int(rhs); }
 
 }; // END if namespace synfigapp
 /* === E N D =============================================================== */
