@@ -2,10 +2,11 @@
 /*!	\file value_desc.h
 **	\brief Template Header
 **
-**	$Id: value_desc.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: value_desc.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -143,7 +144,7 @@ public:
 		if(parent_is_layer_param() && layer->dynamic_param_list().count(name))
 			return layer->dynamic_param_list().find(name)->second;
 		if(parent_is_linkable_value_node())
-			return synfig::LinkableValueNode::Handle::cast_reinterpret(parent_value_node)->get_link(index);
+			return (synfig::LinkableValueNode::Handle::cast_reinterpret(parent_value_node))->get_link(index);
 //			return reinterpret_cast<synfig::LinkableValueNode*>(parent_value_node.get())->get_link(index);
 		return 0;
 	}
@@ -151,7 +152,8 @@ public:
 	synfig::ValueBase
 	get_value(synfig::Time time=0)const
 	{
-		if(parent_is_value_node_const() && parent_value_node)
+		// if the value is constant, return that constant value (at *any* time, it doesn't matter which)
+		if(parent_is_value_node_const())
 			return (*parent_value_node)(0);
 		if(is_value_node() && get_value_node())
 			return (*get_value_node())(time);
@@ -174,6 +176,9 @@ public:
 	{
 		return is_value_node() && get_value_node()->is_exported();
 	}
+
+	synfig::String
+	get_description(bool show_exported_name = true)const;
 }; // END of class ValueDesc
 
 }; // END of namespace synfigapp_instance
